CREATE TABLE B_BP_WORKFLOW_TEMPLATE (
	ID int NOT NULL IDENTITY (1, 1),
	MODULE_ID varchar(32) NULL,
	ENTITY varchar(64) NOT NULL,
	DOCUMENT_TYPE varchar(128) NOT NULL,
	AUTO_EXECUTE int NOT NULL DEFAULT 0,
	NAME varchar(255) NULL,
	DESCRIPTION text NULL,
	TEMPLATE image NULL,
	PARAMETERS image NULL,
	VARIABLES image NULL,
	MODIFIED datetime NOT NULL,
	USER_ID int NULL,
	SYSTEM_CODE varchar(50) NULL,
	ACTIVE char(1) NOT NULL default 'Y'
)
GO
ALTER TABLE B_BP_WORKFLOW_TEMPLATE ADD CONSTRAINT PK_B_BP_WORKFLOW_TEMPLATE PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_WF_TEMPLATE_MO ON B_BP_WORKFLOW_TEMPLATE(MODULE_ID, ENTITY, DOCUMENT_TYPE)
GO

CREATE TABLE B_BP_WORKFLOW_STATE (
	ID varchar(32) NOT NULL,
	MODULE_ID varchar(32) NULL,
	ENTITY varchar(64) NOT NULL,
	DOCUMENT_ID varchar(128) NOT NULL,
	DOCUMENT_ID_INT int NOT NULL,
	WORKFLOW_TEMPLATE_ID int NOT NULL,
	STATE varchar(128) NULL,
	STATE_TITLE varchar(255) NULL,
	STATE_PARAMETERS text NULL,
	MODIFIED datetime NOT NULL,
	STARTED datetime NULL,
	STARTED_BY int NULL
)
GO
ALTER TABLE B_BP_WORKFLOW_STATE ADD CONSTRAINT PK_B_BP_WORKFLOW_STATE PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_WS_DOCUMENT_ID ON B_BP_WORKFLOW_STATE(DOCUMENT_ID, ENTITY, MODULE_ID)
GO
CREATE INDEX IX_BP_WS_DOCUMENT_ID1 ON B_BP_WORKFLOW_STATE(DOCUMENT_ID_INT, ENTITY, MODULE_ID, STATE)
GO


CREATE TABLE B_BP_WORKFLOW_PERMISSIONS (
	ID int NOT NULL IDENTITY (1, 1),
	WORKFLOW_ID varchar(32) NOT NULL,
	OBJECT_ID varchar(64) NOT NULL,
	PERMISSION varchar(64) NOT NULL
)
GO
ALTER TABLE B_BP_WORKFLOW_PERMISSIONS ADD CONSTRAINT PK_B_BP_WORKFLOW_PERMISSIONS PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_WF_PERMISSIONS_WT ON B_BP_WORKFLOW_PERMISSIONS(WORKFLOW_ID)
GO


CREATE TABLE B_BP_WORKFLOW_INSTANCE (
	ID varchar(32) NOT NULL,
	WORKFLOW image NULL,
	STATUS int NULL,
	MODIFIED datetime NOT NULL,
	OWNER_ID varchar(32) NULL,
	OWNED_UNTIL datetime NULL
)
GO
ALTER TABLE B_BP_WORKFLOW_INSTANCE ADD CONSTRAINT PK_B_BP_WORKFLOW_INSTANCE PRIMARY KEY (ID)
GO


CREATE TABLE B_BP_TRACKING (
	ID int NOT NULL IDENTITY (1, 1),
	WORKFLOW_ID varchar(32) NOT NULL,
	TYPE int NOT NULL,
	MODIFIED datetime NOT NULL,
	ACTION_NAME varchar(128) NOT NULL,
	ACTION_TITLE varchar(255) NULL,
	EXECUTION_STATUS int NOT NULL default 0,
	EXECUTION_RESULT int NOT NULL default 0,
	ACTION_NOTE text NULL,
	MODIFIED_BY int NULL
)
GO
ALTER TABLE B_BP_TRACKING ADD CONSTRAINT PK_B_BP_TRACKING PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_TRACKING_WF ON B_BP_TRACKING(WORKFLOW_ID)
GO


CREATE TABLE B_BP_TASK (
	ID int NOT NULL IDENTITY (1, 1),
	WORKFLOW_ID varchar(32) NOT NULL,
	ACTIVITY varchar(128) NOT NULL,
	ACTIVITY_NAME varchar(128) NOT NULL,
	MODIFIED datetime NOT NULL,
	OVERDUE_DATE datetime NULL,
	NAME varchar(128) NOT NULL,
	DESCRIPTION text NULL,
	PARAMETERS text NULL
)
GO
ALTER TABLE B_BP_TASK ADD CONSTRAINT PK_B_BP_TASK PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_TASKS_SORT ON B_BP_TASK(OVERDUE_DATE, MODIFIED)
GO
CREATE INDEX IX_BP_TASKS_WF ON B_BP_TASK(WORKFLOW_ID)
GO


CREATE TABLE B_BP_TASK_USER (
	ID int NOT NULL IDENTITY (1, 1),
	USER_ID int NOT NULL,
	TASK_ID int NOT NULL
)
GO
ALTER TABLE B_BP_TASK_USER ADD CONSTRAINT PK_B_BP_TASK_USER PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BP_TASK_USER ON B_BP_TASK_USER(USER_ID, TASK_ID)
GO


CREATE TABLE B_BP_HISTORY (
	ID int NOT NULL IDENTITY (1, 1),
	MODULE_ID varchar(32) NULL,
	ENTITY varchar(64) NOT NULL,
	DOCUMENT_ID varchar(128) NOT NULL,
	NAME varchar(255) NOT NULL,
	DOCUMENT image NULL,
	MODIFIED datetime NOT NULL,
	USER_ID int NULL
)
GO
ALTER TABLE B_BP_HISTORY ADD CONSTRAINT PK_B_BP_HISTORY PRIMARY KEY (ID)
GO
CREATE INDEX IX_BP_HISTORY_DOC ON B_BP_HISTORY(DOCUMENT_ID, ENTITY, MODULE_ID)
GO
