create table B_BLOG_SITE_PATH
(
  ID int not null IDENTITY (1, 1)
,  SITE_ID char(2) not null
,  PATH varchar(255) not null
,  TYPE char(1) null
)
GO
ALTER TABLE B_BLOG_SITE_PATH ADD CONSTRAINT PK_B_BLOG_SITE_PATH PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_SITE_PATH_2 ON B_BLOG_SITE_PATH(SITE_ID, TYPE)
GO

create table B_BLOG
(
  ID int not null IDENTITY (1, 1)
,  NAME varchar(255) not null
,  DESCRIPTION text null
,  DATE_CREATE datetime not null
,  DATE_UPDATE datetime not null
,  ACTIVE char(1) not null default 'Y'
,  OWNER_ID int null
,  SOCNET_GROUP_ID int null
,  URL varchar(255) not null
,  REAL_URL varchar(255) null
,  GROUP_ID int not null
,  ENABLE_COMMENTS char(1) not null default 'Y'
,  ENABLE_IMG_VERIF char(1) not null default 'N'
,  ENABLE_RSS char(1) not null default 'Y'
,  LAST_POST_ID int null
,  LAST_POST_DATE datetime null
,  AUTO_GROUPS varchar(255) null
,  EMAIL_NOTIFY CHAR( 1 ) NOT NULL DEFAULT 'Y'
,  ALLOW_HTML CHAR(1) NOT NULL DEFAULT 'N'
,  SEARCH_INDEX CHAR(1) NOT NULL DEFAULT 'Y'
,  USE_SOCNET CHAR(1) NOT NULL DEFAULT 'N'
)
GO
ALTER TABLE B_BLOG ADD CONSTRAINT PK_B_BLOG PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_BLOG_1 ON B_BLOG(GROUP_ID, ACTIVE)
GO
CREATE INDEX IX_BLOG_BLOG_2 ON B_BLOG(OWNER_ID)
GO
CREATE UNIQUE INDEX IX_BLOG_BLOG_4 ON B_BLOG(URL)
GO
CREATE INDEX IX_BLOG_BLOG_5 ON B_BLOG(LAST_POST_DATE)
GO
CREATE INDEX IX_BLOG_BLOG_6 ON B_BLOG(SOCNET_GROUP_ID)
GO

create table B_BLOG_GROUP
(
  ID int not null IDENTITY (1, 1)
,  NAME varchar(255) not null
,  SITE_ID char(2) not null
)
GO
ALTER TABLE B_BLOG_GROUP ADD CONSTRAINT PK_BLG_GROUP PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_GROUP_1 ON B_BLOG_GROUP(SITE_ID)
GO

create table B_BLOG_POST
(
  ID int not null IDENTITY (1, 1)
,  TITLE varchar(255) not null
,  BLOG_ID int not null
,  AUTHOR_ID int not null
,  PREVIEW_TEXT text null
,  PREVIEW_TEXT_TYPE char(4) not null default 'text'
,  DETAIL_TEXT text not null
,  DETAIL_TEXT_TYPE char(4) not null default 'text'
,  DATE_CREATE datetime not null
,  DATE_PUBLISH datetime not null
,  KEYWORDS varchar(255) null
,  PUBLISH_STATUS char(1) not null default 'P'
,  CATEGORY_ID char(100)
,  ATRIBUTE varchar(255) null
,  ENABLE_TRACKBACK char(1) not null default 'Y'
,  ENABLE_COMMENTS char(1) not null default 'Y'
,  ATTACH_IMG int null
,  NUM_COMMENTS int not null default '0'
,  NUM_TRACKBACKS int not null default '0'
,  VIEWS int null
,  FAVORITE_SORT int null
,  PATH varchar(255) null
,  CODE varchar(255) null
,  MICRO char(1) not null default 'N'
,  HAS_IMAGES char(1) null
,  HAS_PROPS char(1) null
,  HAS_TAGS char(1) null
,  HAS_COMMENT_IMAGES char(1) null
,  HAS_SOCNET_ALL char(1) null
)
GO
ALTER TABLE B_BLOG_POST ADD CONSTRAINT PK_BLG_POST PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_POST_1 ON B_BLOG_POST(BLOG_ID, PUBLISH_STATUS, DATE_PUBLISH)
GO
CREATE INDEX IX_BLOG_POST_2 ON B_BLOG_POST(BLOG_ID, DATE_PUBLISH, PUBLISH_STATUS)
GO
CREATE INDEX IX_BLOG_POST_3 ON B_BLOG_POST(BLOG_ID, CATEGORY_ID)
GO
CREATE INDEX IX_BLOG_POST_4 ON B_BLOG_POST(PUBLISH_STATUS, DATE_PUBLISH)
GO
CREATE INDEX IX_BLOG_POST_5 ON B_BLOG_POST(DATE_PUBLISH, AUTHOR_ID)
GO
CREATE INDEX IX_BLOG_POST_CODE ON B_BLOG_POST(BLOG_ID, CODE)
GO
CREATE INDEX IX_BLOG_POST_6 ON B_BLOG_POST(CODE)
GO

create table B_BLOG_CATEGORY
(
  ID int not null IDENTITY (1, 1)
,  BLOG_ID int not null
,  NAME varchar(255) not null
)
GO
ALTER TABLE B_BLOG_CATEGORY ADD CONSTRAINT PK_BLG_CATEGORY PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_CAT_1 ON B_BLOG_CATEGORY(BLOG_ID, NAME)
GO


create table B_BLOG_COMMENT
(
  ID int not null IDENTITY (1, 1)
,  BLOG_ID int not null
,  POST_ID int not null
,  PARENT_ID int null
,  AUTHOR_ID int null
,  ICON_ID int null
,  AUTHOR_NAME varchar(255) null
,  AUTHOR_EMAIL varchar(255) null
,  AUTHOR_IP varchar(20) null
,  AUTHOR_IP1 varchar(20) null
,  DATE_CREATE datetime not null
,  TITLE varchar(255) null
,  POST_TEXT text not null
,  PUBLISH_STATUS char(1) not null default 'P'
,  PATH varchar(255) null
,  HAS_PROPS char(1) null
)
GO
ALTER TABLE B_BLOG_COMMENT ADD CONSTRAINT PK_BLG_COMMENT PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_COMM_1 ON B_BLOG_COMMENT(BLOG_ID, POST_ID)
GO
CREATE INDEX IX_BLOG_COMM_2 ON B_BLOG_COMMENT(AUTHOR_ID)
GO
CREATE INDEX IX_BLOG_COMM_3 ON B_BLOG_COMMENT(DATE_CREATE, AUTHOR_ID)
GO


create table B_BLOG_USER
(
  ID int not null IDENTITY (1, 1)
,  USER_ID int not null
,  ALIAS varchar(255) null
,  DESCRIPTION text null
,  AVATAR int null
,  INTERESTS varchar(255) null
,  LAST_VISIT datetime null
,  DATE_REG datetime not null
,  ALLOW_POST char(1) not null default 'Y'
)
GO
ALTER TABLE B_BLOG_USER ADD CONSTRAINT PK_BLG_USER PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_USER_1 ON B_BLOG_USER(USER_ID)
GO
CREATE INDEX IX_BLOG_USER_2 ON B_BLOG_USER(ALIAS)
GO

create table B_BLOG_USER_GROUP
(
  ID int not null IDENTITY (1, 1)
,  BLOG_ID int null
,  NAME varchar(255) not null
)
GO
ALTER TABLE B_BLOG_USER_GROUP ADD CONSTRAINT PK_BLG_USER_GROUP PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_USER_GROUP_1 ON B_BLOG_USER_GROUP(BLOG_ID)
GO

ALTER TABLE b_blog_user_group NOCHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_user_group DISABLE TRIGGER ALL
GO

SET IDENTITY_INSERT B_BLOG_USER_GROUP ON

INSERT INTO b_blog_user_group(ID, BLOG_ID, NAME) VALUES(1, null, 'all')
GO
INSERT INTO b_blog_user_group(ID, BLOG_ID, NAME) VALUES(2, null, 'registered')
GO

SET IDENTITY_INSERT B_BLOG_USER_GROUP OFF

ALTER TABLE b_blog_user_group CHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_user_group ENABLE TRIGGER ALL
GO

create table B_BLOG_USER2USER_GROUP
(
  ID int not null IDENTITY (1, 1)
,  USER_ID int not null
,  BLOG_ID int not null
,  USER_GROUP_ID int not null
)
GO
ALTER TABLE B_BLOG_USER2USER_GROUP ADD CONSTRAINT PK_BLG_USER2USER_GROUP PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_USER2GROUP_1 ON B_BLOG_USER2USER_GROUP(USER_ID, BLOG_ID, USER_GROUP_ID)
GO

create table B_BLOG_USER_GROUP_PERMS
(
  ID int not null IDENTITY (1, 1)
,  BLOG_ID int not null
,  USER_GROUP_ID int not null
,  PERMS_TYPE char(1) not null default 'P'
,  POST_ID int null
,  PERMS char(1) not null default 'D'
,  AUTOSET char(1) not null default 'N'
)
GO
ALTER TABLE B_BLOG_USER_GROUP_PERMS ADD CONSTRAINT PK_BLG_USER_GROUP_PERMS PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_UG_PERMS_1 ON B_BLOG_USER_GROUP_PERMS(BLOG_ID, USER_GROUP_ID, PERMS_TYPE, POST_ID)
GO
CREATE INDEX IX_BLOG_UG_PERMS_2 ON B_BLOG_USER_GROUP_PERMS(USER_GROUP_ID, PERMS_TYPE, POST_ID)
GO
CREATE INDEX IX_BLOG_UG_PERMS_3 ON B_BLOG_USER_GROUP_PERMS(POST_ID, USER_GROUP_ID, PERMS_TYPE)
GO

create table B_BLOG_USER2BLOG
(
  ID int not null IDENTITY (1, 1)
,  USER_ID int not null
,  BLOG_ID int not null
)
GO
ALTER TABLE B_BLOG_USER2BLOG ADD CONSTRAINT PK_BLG_USER2BLOG PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_USER2BLOG_1 ON B_BLOG_USER2BLOG(BLOG_ID, USER_ID)
GO

create table B_BLOG_TRACKBACK
(
  ID int not null IDENTITY (1, 1)
,  TITLE varchar(255) not null
,  URL varchar(255) not null
,  PREVIEW_TEXT text not null
,  BLOG_NAME varchar(255) null
,  POST_DATE datetime not null
,  BLOG_ID int not null
,  POST_ID int not null
)
GO
ALTER TABLE B_BLOG_TRACKBACK ADD CONSTRAINT PK_BLG_TRACKBACK PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_TRBK_1 ON B_BLOG_TRACKBACK(BLOG_ID, POST_ID)
GO
CREATE INDEX IX_BLOG_TRBK_2 ON B_BLOG_TRACKBACK(POST_ID)
GO

create table B_BLOG_SMILE (
   ID int not null IDENTITY (1, 1),
   SMILE_TYPE char(1) not null default 'S',
   TYPING varchar(100) null,
   IMAGE varchar(128) not null,
   DESCRIPTION varchar(50),
   CLICKABLE char(1) not null default 'Y',
   SORT int not null default 150,
   IMAGE_WIDTH int not null default 0,
   IMAGE_HEIGHT int not null default 0
)
GO
ALTER TABLE B_BLOG_SMILE ADD CONSTRAINT PK_BLG_SMILE PRIMARY KEY (ID)
GO

ALTER TABLE b_blog_smile NOCHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_smile DISABLE TRIGGER ALL
GO

ALTER TABLE b_blog_smile CHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_smile ENABLE TRIGGER ALL
GO

create table B_BLOG_SMILE_LANG (
   ID int not null IDENTITY (1, 1),
   SMILE_ID int not null default 0,
   LID char(2) not null,
   NAME varchar(255) not null,
)
GO
ALTER TABLE B_BLOG_SMILE_LANG ADD CONSTRAINT PK_BLG_SMILE_LANG PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_SMILE_K ON B_BLOG_SMILE_LANG(SMILE_ID, LID)
GO


ALTER TABLE b_blog_smile_lang NOCHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_smile_lang DISABLE TRIGGER ALL
GO

ALTER TABLE b_blog_smile_lang CHECK CONSTRAINT ALL
GO
ALTER TABLE b_blog_smile_lang ENABLE TRIGGER ALL
GO

CREATE TABLE B_BLOG_IMAGE (
  ID INT NOT NULL IDENTITY(1,1),
  FILE_ID INT NULL,
  BLOG_ID INT NULL,
  POST_ID INT NULL,
  USER_ID INT NULL,
  TIMESTAMP_X DATETIME NULL,
  TITLE VARCHAR(255) NULL,
  IMAGE_SIZE INT NULL,
  IS_COMMENT VARCHAR(1) NOT NULL DEFAULT 'N',
  COMMENT_ID INTEGER DEFAULT NULL
)
GO
ALTER TABLE B_BLOG_IMAGE ADD CONSTRAINT PK_B_B_BLOG_IMAGE PRIMARY KEY (ID)
GO

CREATE TABLE B_BLOG_POST_CATEGORY(  
	ID INT NOT NULL IDENTITY(1,1),  
	BLOG_ID INT NOT NULL,  
	POST_ID INT NOT NULL,  
	CATEGORY_ID INT NOT NULL
)
GO
ALTER TABLE B_BLOG_POST_CATEGORY ADD CONSTRAINT PK_B_BLOG_POST_CATEGORY PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_BLOG_POST_CATEGORY ON B_BLOG_POST_CATEGORY(POST_ID, CATEGORY_ID)
GO

CREATE TABLE B_BLOG_SOCNET (
  ID int not null IDENTITY (1, 1),
  BLOG_ID  int not null
);
GO
ALTER TABLE B_BLOG_SOCNET ADD CONSTRAINT PK_B_BLOG_SOCNET PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_B_BLOG_SOCNET ON B_BLOG_SOCNET(BLOG_ID)
GO

CREATE TABLE B_BLOG_SOCNET_RIGHTS (
	ID  int not null IDENTITY (1, 1),
	POST_ID int NOT NULL,
	ENTITY_TYPE varchar(45) NOT NULL,
	ENTITY_ID int NOT NULL,
	ENTITY varchar(45) NOT NULL
)
GO
ALTER TABLE B_BLOG_SOCNET_RIGHTS ADD CONSTRAINT PK_B_BLOG_SOCNET_RIGHTS PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_SR_1 ON B_BLOG_SOCNET_RIGHTS(POST_ID)
GO
CREATE TABLE B_BLOG_POST_PARAM (
	ID  int not null IDENTITY (1, 1),
	POST_ID int,
	USER_ID int,
	NAME varchar(50) NOT NULL,
	VALUE varchar(255) NOT NULL
)
ALTER TABLE B_BLOG_POST_PARAM ADD CONSTRAINT PK_B_BLOG_POST_PARAM PRIMARY KEY (ID)
GO
CREATE INDEX IX_BLOG_PP_1 ON B_BLOG_POST_PARAM(POST_ID, USER_ID)
GO
CREATE INDEX IX_BLOG_PP_2 ON B_BLOG_POST_PARAM(USER_ID)
GO