CREATE TABLE B_CONTROLLER_GROUP
(
	ID INT NOT NULL IDENTITY(1,1),
	TIMESTAMP_X DATETIME NOT NULL,
	NAME VARCHAR(255) NOT NULL,
	UPDATE_PERIOD INT NOT NULL,
	DISABLE_DEACTIVATED CHAR(1) NOT NULL,
	DESCRIPTION TEXT,
	MODIFIED_BY INT,
	DATE_CREATE DATETIME NOT NULL,
	CREATED_BY INT,
	INSTALL_INFO TEXT,
	UNINSTALL_INFO TEXT,
	INSTALL_PHP TEXT,
	UNINSTALL_PHP TEXT,
	TRIAL_PERIOD INT,
	COUNTER_UPDATE_PERIOD INT,
	CHECK_COUNTER_FREE_SPACE CHAR(1),
	CHECK_COUNTER_SITES CHAR(1),
	CHECK_COUNTER_USERS CHAR(1),
	CHECK_COUNTER_LAST_AUTH CHAR(1)
)
GO
ALTER TABLE B_CONTROLLER_GROUP ADD CONSTRAINT PK_B_CONTROLLER_GROUP PRIMARY KEY (ID)
GO
ALTER TABLE B_CONTROLLER_GROUP ADD CONSTRAINT DF_B_CONTROLLER_GROUP_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO
ALTER TABLE B_CONTROLLER_GROUP ADD CONSTRAINT DF_B_CONTROLLER_GROUP_UPDATE_PERIOD DEFAULT -1 FOR UPDATE_PERIOD
GO
ALTER TABLE B_CONTROLLER_GROUP ADD CONSTRAINT DF_B_CONTROLLER_GROUP_DISABLE_DEACTIVATED DEFAULT 'N' FOR DISABLE_DEACTIVATED
GO

SET IDENTITY_INSERT B_CONTROLLER_GROUP ON
GO
INSERT INTO B_CONTROLLER_GROUP(ID, NAME, DATE_CREATE, CREATED_BY, MODIFIED_BY) VALUES(1, '(default)', GETDATE(), 1, 1)
GO
SET IDENTITY_INSERT B_CONTROLLER_GROUP OFF
GO

CREATE TABLE B_CONTROLLER_MEMBER
(
	ID INT NOT NULL IDENTITY(1,1),
	MEMBER_ID VARCHAR(32) NOT NULL,
	SECRET_ID VARCHAR(32) NOT NULL,
	NAME VARCHAR(255) NOT NULL,
	URL VARCHAR(255) NOT NULL,
	EMAIL VARCHAR(255),
	CONTACT_PERSON VARCHAR(255),
	CONTROLLER_GROUP_ID INT NOT NULL,
	DISCONNECTED CHAR(1) NOT NULL,
	SHARED_KERNEL CHAR(1) NOT NULL,
	ACTIVE CHAR(1) NOT NULL,
	DATE_ACTIVE_FROM DATETIME,
	DATE_ACTIVE_TO DATETIME,
	SITE_ACTIVE CHAR(1) NOT NULL,
	TIMESTAMP_X DATETIME NOT NULL,
	MODIFIED_BY INT,
	DATE_CREATE DATETIME NOT NULL,
	CREATED_BY INT,
	IN_GROUP_FROM DATETIME,
	NOTES TEXT,
	COUNTER_FREE_SPACE FLOAT,
	COUNTER_SITES INT,
	COUNTER_USERS INT,
	COUNTER_LAST_AUTH DATETIME,
	COUNTERS_UPDATED DATETIME
)
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT PK_B_CONTROLLER_MEMBER PRIMARY KEY (ID)
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT DF_B_CONTROLLER_MEMBER_DISCONNECTED DEFAULT 'N' FOR DISCONNECTED
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT DF_B_CONTROLLER_MEMBER_SHARED_KERNEL DEFAULT 'N' FOR SHARED_KERNEL
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT DF_B_CONTROLLER_MEMBER_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT DF_B_CONTROLLER_MEMBER_SITE_ACTIVE DEFAULT 'Y' FOR SITE_ACTIVE
GO
ALTER TABLE B_CONTROLLER_MEMBER ADD CONSTRAINT DF_B_CONTROLLER_MEMBER_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO
CREATE UNIQUE INDEX UX_CONTROLLER_MEMBER_MEMBER_ID ON B_CONTROLLER_MEMBER(MEMBER_ID)
GO
CREATE INDEX IX_CONTR_MEMBER_ACTIVE_GROUP ON B_CONTROLLER_MEMBER(ACTIVE, CONTROLLER_GROUP_ID)
GO

CREATE TABLE B_CONTROLLER_MEMBER_LOG
(
	ID INT NOT NULL IDENTITY(1,1),
	CONTROLLER_MEMBER_ID INT NOT NULL,
	USER_ID INT NOT NULL,
	CREATED_DATE DATETIME NOT NULL,
	FIELD VARCHAR(50) NOT NULL,
	FROM_VALUE VARCHAR(8000),
	TO_VALUE VARCHAR(8000),
	NOTES VARCHAR(8000)
)
GO
ALTER TABLE B_CONTROLLER_MEMBER_LOG ADD CONSTRAINT PK_B_CONTROLLER_MEMBER_LOG PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_CONTROLLER_MEMBER_LOG ON B_CONTROLLER_MEMBER_LOG(CONTROLLER_MEMBER_ID, FIELD, CREATED_DATE)
GO

CREATE TABLE B_CONTROLLER_COMMAND
(
	ID INT NOT NULL IDENTITY(1,1),
	MEMBER_ID VARCHAR(32) NOT NULL,
	COMMAND_ID VARCHAR(32) NOT NULL,
	DATE_INSERT DATETIME NOT NULL,
	COMMAND TEXT NOT NULL,
	DATE_EXEC DATETIME,
	TASK_ID INT,
	ADD_PARAMS TEXT
)
GO
ALTER TABLE B_CONTROLLER_COMMAND ADD CONSTRAINT PK_B_CONTROLLER_COMMAND PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX UX_CONTR_COMMAND_MEMBER_ID ON B_CONTROLLER_COMMAND(MEMBER_ID, COMMAND_ID)
GO

CREATE TABLE B_CONTROLLER_TASK
(
	ID INT NOT NULL IDENTITY(1,1),
	TIMESTAMP_X DATETIME NOT NULL,
	DATE_CREATE DATETIME NOT NULL,
	TASK_ID VARCHAR(50) NOT NULL,
	CONTROLLER_MEMBER_ID INT NOT NULL,
	DATE_EXECUTE DATETIME,
	INIT_EXECUTE TEXT,
	INIT_EXECUTE_PARAMS TEXT,
	INIT_CRC INT NOT NULL,
	UPDATE_PERIOD INT NOT NULL,
	RESULT_EXECUTE TEXT,
	STATUS CHAR(1) NOT NULL,
	INDEX_SALT INT NOT NULL
)
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT PK_B_CONTROLLER_TASK PRIMARY KEY (ID)
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT DF_B_CONTROLLER_TASK_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT DF_B_CONTROLLER_TASK_INIT_CRC DEFAULT 0 FOR INIT_CRC
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT DF_B_CONTROLLER_TASK_UPDATE_PERIOD DEFAULT 0 FOR UPDATE_PERIOD
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT DF_B_CONTROLLER_TASK_STATUS DEFAULT 'N' FOR STATUS
GO
ALTER TABLE B_CONTROLLER_TASK ADD CONSTRAINT DF_B_CONTROLLER_TASK_INDEX_SALT DEFAULT 0 FOR INDEX_SALT
GO
CREATE INDEX IX_CONTR_TASK_EXEC ON B_CONTROLLER_TASK(DATE_EXECUTE)
GO
CREATE UNIQUE INDEX UX_CONTR_TASK ON B_CONTROLLER_TASK(CONTROLLER_MEMBER_ID, TASK_ID, DATE_EXECUTE, INIT_CRC, INDEX_SALT)
GO

CREATE TABLE B_CONTROLLER_LOG
(
	ID INT NOT NULL IDENTITY(1,1),
	TIMESTAMP_X DATETIME NOT NULL,
	CONTROLLER_MEMBER_ID INT NOT NULL,
	NAME VARCHAR(255) NOT NULL,
	DESCRIPTION TEXT,
	TASK_ID INT,
	USER_ID INT,
	STATUS CHAR(1) NOT NULL
)
GO
ALTER TABLE B_CONTROLLER_LOG ADD CONSTRAINT PK_B_CONTROLLER_LOG PRIMARY KEY (ID)
GO
ALTER TABLE B_CONTROLLER_LOG ADD CONSTRAINT DF_B_CONTROLLER_LOG_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO
ALTER TABLE B_CONTROLLER_LOG ADD CONSTRAINT DF_B_CONTROLLER_LOG_STATUS DEFAULT 'Y' FOR STATUS
GO
CREATE INDEX IX_CONTR_LOG_MEMBER ON B_CONTROLLER_LOG(CONTROLLER_MEMBER_ID)
GO
CREATE INDEX IX_CONTR_LOG_TASK ON B_CONTROLLER_LOG(TASK_ID)
GO

CREATE TABLE B_CONTROLLER_COUNTER
(
	ID INT NOT NULL IDENTITY(1,1),
	TIMESTAMP_X DATETIME NOT NULL,
	COUNTER_TYPE CHAR(1) NOT NULL,
	COUNTER_FORMAT CHAR(1),
	NAME VARCHAR(255) NOT NULL,
	COMMAND TEXT NOT NULL
)
GO
ALTER TABLE B_CONTROLLER_COUNTER ADD CONSTRAINT PK_B_CONTROLLER_COUNTER PRIMARY KEY (ID)
GO
ALTER TABLE B_CONTROLLER_COUNTER ADD CONSTRAINT DF_B_CONTROLLER_COUNTER_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO

CREATE TABLE B_CONTROLLER_COUNTER_GROUP
(
	CONTROLLER_GROUP_ID INT NOT NULL,
	CONTROLLER_COUNTER_ID INT NOT NULL
)
GO
CREATE UNIQUE INDEX UX_B_CONTROLLER_COUNTER_GROUP_1 ON B_CONTROLLER_COUNTER_GROUP(CONTROLLER_GROUP_ID, CONTROLLER_COUNTER_ID)
GO
CREATE UNIQUE INDEX UX_B_CONTROLLER_COUNTER_GROUP_2 ON B_CONTROLLER_COUNTER_GROUP(CONTROLLER_COUNTER_ID, CONTROLLER_GROUP_ID)
GO

CREATE TABLE B_CONTROLLER_COUNTER_VALUE
(
	CONTROLLER_MEMBER_ID INT NOT NULL,
	CONTROLLER_COUNTER_ID INT NOT NULL,
	VALUE_INT INT,
	VALUE_FLOAT FLOAT,
	VALUE_DATE DATETIME,
	VALUE_STRING VARCHAR(255)
)
GO
ALTER TABLE B_CONTROLLER_COUNTER_VALUE ADD CONSTRAINT PK_B_CONTROLLER_COUNTER_VALUE PRIMARY KEY (CONTROLLER_MEMBER_ID, CONTROLLER_COUNTER_ID)
GO
CREATE UNIQUE INDEX UX_B_CONTROLLER_COUNTER_VALUE ON B_CONTROLLER_COUNTER_VALUE(CONTROLLER_COUNTER_ID, CONTROLLER_MEMBER_ID)
GO
