CREATE TABLE B_FORM
(
	ID int NOT NULL IDENTITY (1, 1),
	TIMESTAMP_X datetime NULL,
	NAME varchar(255) NOT NULL,
	SID varchar(50) NOT NULL,
	BUTTON varchar(255) NULL,
	C_SORT int NULL,
	FIRST_SITE_ID char(2) NULL,
	IMAGE_ID int NULL,
	USE_CAPTCHA char(1) NULL,
	DESCRIPTION varchar(8000) NULL,
	DESCRIPTION_TYPE varchar(4) NOT NULL,
	FORM_TEMPLATE text NULL,
	USE_DEFAULT_TEMPLATE char(1) NULL,
	SHOW_TEMPLATE varchar(255) NULL,
	MAIL_EVENT_TYPE varchar(50) NULL,
	SHOW_RESULT_TEMPLATE varchar(255) NULL,
	PRINT_RESULT_TEMPLATE varchar(255) NULL,
	EDIT_RESULT_TEMPLATE varchar(255) NULL,
	FILTER_RESULT_TEMPLATE varchar(8000) NULL,
	TABLE_RESULT_TEMPLATE varchar(8000) NULL,
	USE_RESTRICTIONS CHAR(1) NULL,
	RESTRICT_USER INT NULL,
	RESTRICT_TIME INT NULL,
	RESTRICT_STATUS VARCHAR(255) NULL,
	STAT_EVENT1 varchar(255) NULL,
	STAT_EVENT2 varchar(255) NULL,
	STAT_EVENT3 varchar(255) NULL
)
GO
ALTER TABLE B_FORM ADD CONSTRAINT PK_B_FORM PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_1 ON B_FORM (SID)
GO
ALTER TABLE B_FORM ADD CONSTRAINT DF_B_FORM_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_FORM ADD CONSTRAINT DF_B_FORM_USE_CAPTCHA DEFAULT 'N' FOR USE_CAPTCHA
GO
ALTER TABLE B_FORM ADD CONSTRAINT DF_B_FORM_USE_DEFAULT_TEMPLATE DEFAULT 'Y' FOR USE_DEFAULT_TEMPLATE
GO
ALTER TABLE B_FORM ADD CONSTRAINT DF_B_FORM_DESCRIPTION_TYPE DEFAULT 'html' FOR DESCRIPTION_TYPE
GO
ALTER TABLE B_FORM ADD CONSTRAINT DF_B_FORM_USE_RESTRICTIONS DEFAULT 'N' FOR USE_RESTRICTIONS
GO

CREATE TABLE B_FORM_2_MAIL_TEMPLATE
(
	FORM_ID int NOT NULL,
	MAIL_TEMPLATE_ID int NOT NULL
)
GO
ALTER TABLE B_FORM_2_MAIL_TEMPLATE ADD CONSTRAINT PK_B_FORM_2_MAIL_TEMPLATE PRIMARY KEY (FORM_ID, MAIL_TEMPLATE_ID)
GO


CREATE TABLE B_FORM_2_SITE
(
	FORM_ID int NOT NULL,
	SITE_ID char(2) NOT NULL
)
GO
ALTER TABLE B_FORM_2_SITE ADD CONSTRAINT PK_B_FORM_2_SITE PRIMARY KEY (FORM_ID, SITE_ID)
GO

CREATE TABLE B_FORM_ANSWER
(
	ID int NOT NULL IDENTITY (1, 1),
	FIELD_ID int NOT NULL,
	TIMESTAMP_X datetime NULL,
	MESSAGE varchar(8000) NULL,
	C_SORT int NOT NULL,
	ACTIVE char(1) NOT NULL,
	VALUE varchar(255) NULL,
	FIELD_TYPE varchar(255) NOT NULL,
	FIELD_WIDTH int NULL,
	FIELD_HEIGHT int NULL,
	FIELD_PARAM varchar(8000) NULL
)
GO
ALTER TABLE B_FORM_ANSWER ADD CONSTRAINT PK_B_FORM_ANSWER PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_ANSWER_1 ON B_FORM_ANSWER (FIELD_ID)
GO
ALTER TABLE B_FORM_ANSWER ADD CONSTRAINT DF_B_FORM_ANSWER_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_FORM_ANSWER ADD CONSTRAINT DF_B_FORM_ANSWER_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_FORM_ANSWER ADD CONSTRAINT DF_B_FORM_ANSWER_FIELD_TYPE DEFAULT 'text' FOR FIELD_TYPE
GO


CREATE TABLE B_FORM_FIELD
(
	ID int NOT NULL IDENTITY (1, 1),
	FORM_ID int NOT NULL,
	TIMESTAMP_X datetime NULL,
	ACTIVE char(1) NOT NULL,
	TITLE varchar(8000) NULL,
	TITLE_TYPE varchar(4) NOT NULL,
	SID varchar(50) NULL,
	C_SORT int NOT NULL,
	ADDITIONAL char(1) NOT NULL,
	REQUIRED char(1) NOT NULL,
	IN_FILTER char(1) NOT NULL,
	IN_RESULTS_TABLE char(1) NOT NULL,
	IN_EXCEL_TABLE char(1) NOT NULL,
	FIELD_TYPE varchar(50) NULL,
	IMAGE_ID int NULL,
	COMMENTS varchar(8000) NULL,
	FILTER_TITLE varchar(8000) NULL,
	RESULTS_TABLE_TITLE varchar(8000) NULL
)
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT PK_B_FORM_FIELD PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_FIELD_1 ON B_FORM_FIELD (FORM_ID)
GO
CREATE INDEX IX_B_FORM_FIELD_2 ON B_FORM_FIELD (SID)
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_TITLE_TYPE DEFAULT 'text' FOR TITLE_TYPE
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_ADDITIONAL DEFAULT 'N' FOR ADDITIONAL
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_REQUIRED DEFAULT 'N' FOR REQUIRED
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_IN_FILTER DEFAULT 'N' FOR IN_FILTER
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_IN_RESULTS_TABLE DEFAULT 'N' FOR IN_RESULTS_TABLE
GO
ALTER TABLE B_FORM_FIELD ADD CONSTRAINT DF_B_FORM_FIELD_IN_EXCEL_TABLE DEFAULT 'Y' FOR IN_EXCEL_TABLE
GO


CREATE TABLE B_FORM_FIELD_FILTER
(
	ID int NOT NULL IDENTITY (1, 1),
	FIELD_ID int NOT NULL,
	PARAMETER_NAME varchar(50) NOT NULL,
	FILTER_TYPE varchar(50) NOT NULL
)
GO
ALTER TABLE B_FORM_FIELD_FILTER ADD CONSTRAINT PK_B_FORM_FIELD_FILTER PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_FIELD_FILTER_1 ON B_FORM_FIELD_FILTER (FIELD_ID)
GO

CREATE TABLE B_FORM_FIELD_VALIDATOR (
  ID int NOT NULL IDENTITY (1, 1),
  FORM_ID int NOT NULL,
  FIELD_ID int NOT NULL,
  TIMESTAMP_X datetime NULL,
  ACTIVE char(1) NULL,
  C_SORT int NULL,
  VALIDATOR_SID varchar(255) NOT NULL,
  PARAMS text NULL,
)
GO
ALTER TABLE B_FORM_FIELD_VALIDATOR ADD CONSTRAINT PK_B_FORM_FIELD_VALIDATOR PRIMARY KEY (ID)
GO
CREATE INDEX IX_FORM_ID ON B_FORM_FIELD_VALIDATOR (FORM_ID)
GO
CREATE INDEX IX_FIELD_ID ON B_FORM_FIELD_VALIDATOR (FIELD_ID)
GO
ALTER TABLE B_FORM_FIELD_VALIDATOR ADD CONSTRAINT DF_B_FORM_FIELD_VALIDATOR_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_FORM_FIELD_VALIDATOR ADD CONSTRAINT DF_B_FORM_FIELD_VALIDATOR_C_SORT DEFAULT '100' FOR C_SORT
GO

CREATE TABLE B_FORM_MENU
(
	ID int NOT NULL IDENTITY (1, 1),
	FORM_ID int NOT NULL,
	LID char(2) NOT NULL,
	MENU varchar(50) NULL
)
GO
ALTER TABLE B_FORM_MENU ADD CONSTRAINT PK_B_FORM_MENU PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_MENU_1 ON B_FORM_MENU (FORM_ID)
GO


CREATE TABLE B_FORM_RESULT
(
	ID int NOT NULL IDENTITY (1, 1),
	TIMESTAMP_X datetime NULL,
	DATE_CREATE datetime NULL,
	STATUS_ID int NOT NULL,
	FORM_ID int NOT NULL,
	USER_ID int NULL,
	USER_AUTH char(1) NOT NULL,
	STAT_GUEST_ID int NULL,
	STAT_SESSION_ID int NULL,
	SENT_TO_CRM char(1) NULL
)
GO
ALTER TABLE B_FORM_RESULT ADD CONSTRAINT PK_B_FORM_RESULT PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_RESULT_1 ON B_FORM_RESULT (FORM_ID)
GO
CREATE INDEX IX_B_FORM_RESULT_2 ON B_FORM_RESULT (STATUS_ID)
GO
CREATE INDEX IX_B_FORM_RESULT_3 ON B_FORM_RESULT (SENT_TO_CRM)
GO
ALTER TABLE B_FORM_RESULT ADD CONSTRAINT DF_B_FORM_RESULT_USER_AUTH DEFAULT 'N' FOR USER_AUTH
GO
ALTER TABLE B_FORM_RESULT ADD CONSTRAINT DF_B_FORM_RESULT_SENT_TO_CRM DEFAULT 'N' FOR SENT_TO_CRM
GO


CREATE TABLE B_FORM_RESULT_ANSWER
(
	ID int NOT NULL IDENTITY (1, 1),
	RESULT_ID int NOT NULL,
	FORM_ID int NOT NULL,
	FIELD_ID int NOT NULL,
	ANSWER_ID int NULL,
	ANSWER_TEXT varchar(8000) NULL,
	ANSWER_TEXT_SEARCH text NULL,
	ANSWER_VALUE varchar(255) NULL,
	ANSWER_VALUE_SEARCH text NULL,
	USER_TEXT text NULL,
	USER_TEXT_SEARCH text NULL,
	USER_DATE datetime NULL,
	USER_FILE_ID int NULL,
	USER_FILE_NAME varchar(255) NULL,
	USER_FILE_IS_IMAGE char(1) NULL,
	USER_FILE_HASH varchar(255) NULL,
	USER_FILE_SUFFIX varchar(255) NULL,
	USER_FILE_SIZE int NULL
)
GO
ALTER TABLE B_FORM_RESULT_ANSWER ADD CONSTRAINT PK_B_FORM_RESULT_ANSWER PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_RESULT_ANSWER_1 ON B_FORM_RESULT_ANSWER (FIELD_ID)
GO
CREATE INDEX IX_B_FORM_RESULT_ANSWER_2 ON B_FORM_RESULT_ANSWER (RESULT_ID)
GO
CREATE INDEX IX_ANSWER_ID ON B_FORM_RESULT_ANSWER (ANSWER_ID)
GO


CREATE TABLE B_FORM_2_GROUP
(
	ID int NOT NULL IDENTITY (1, 1),
	FORM_ID int NOT NULL,
	GROUP_ID int NOT NULL,
	PERMISSION tinyint NOT NULL
)
GO
ALTER TABLE B_FORM_2_GROUP ADD CONSTRAINT PK_B_FORM_2_GROUP PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_2_GROUP_1 ON B_FORM_2_GROUP (FORM_ID)
GO
ALTER TABLE B_FORM_2_GROUP ADD CONSTRAINT DF_B_FORM_2_GROUP_PERMISSION DEFAULT '1' FOR PERMISSION
GO


CREATE TABLE B_FORM_STATUS
(
	ID int NOT NULL IDENTITY (1, 1),
	FORM_ID int NOT NULL,
	TIMESTAMP_X datetime NULL,
	ACTIVE char(1) NOT NULL,
	C_SORT int NOT NULL,
	TITLE varchar(255) NOT NULL,
	DESCRIPTION varchar(8000) NULL,
	DEFAULT_VALUE char(1) NOT NULL,
	CSS varchar(255) NULL,
	HANDLER_OUT varchar(255) NULL,
	HANDLER_IN varchar(255) NULL,
	MAIL_EVENT_TYPE varchar(50) NULL DEFAULT NULL
)
GO
ALTER TABLE B_FORM_STATUS ADD CONSTRAINT PK_B_FORM_STATUS PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_STATUS_1 ON B_FORM_STATUS (FORM_ID)
GO
ALTER TABLE B_FORM_STATUS ADD CONSTRAINT DF_B_FORM_STATUS_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_FORM_STATUS ADD CONSTRAINT DF_B_FORM_STATUS_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_FORM_STATUS ADD CONSTRAINT DF_B_FORM_STATUS_DEFAULT_VALUE DEFAULT 'N' FOR DEFAULT_VALUE
GO
ALTER TABLE B_FORM_STATUS ADD CONSTRAINT DF_B_FORM_STATUS_CSS DEFAULT 'statusgreen' FOR CSS
GO


CREATE TABLE B_FORM_STATUS_2_GROUP
(
	ID int NOT NULL IDENTITY (1, 1),
	STATUS_ID int NOT NULL,
	GROUP_ID int NOT NULL,
	PERMISSION varchar(50) NOT NULL
)
GO
ALTER TABLE B_FORM_STATUS_2_GROUP ADD CONSTRAINT PK_B_FORM_STATUS_2_GROUP PRIMARY KEY (ID)
GO
CREATE INDEX IX_FORM_STATUS_GROUP ON B_FORM_STATUS_2_GROUP (STATUS_ID, GROUP_ID)
GO
CREATE TABLE B_FORM_STATUS_2_MAIL_TEMPLATE
(
	STATUS_ID int NOT NULL,
	MAIL_TEMPLATE_ID int NOT NULL
)
GO
ALTER TABLE B_FORM_STATUS_2_MAIL_TEMPLATE ADD CONSTRAINT PK_B_FORM_STATUS_2_MAIL_TEMPLATE PRIMARY KEY (STATUS_ID, MAIL_TEMPLATE_ID)
GO

CREATE FUNCTION dbo.CONVERT_TO_NUMBER(@sValue as varchar(8000))
RETURNS int AS
BEGIN
	DECLARE @iValue int

	SELECT @iValue = case when @sValue like '%[^0-9]%' then NULL else convert(int, @sValue) end

	RETURN @iValue
END
GO

CREATE TABLE B_FORM_CRM
(
	ID int NOT NULL IDENTITY (1, 1),
	NAME varchar(255) NOT NULL,
	ACTIVE char(1) NOT NULL,
	URL varchar(255) NOT NULL,
	AUTH_HASH varchar(32) NULL,
)
GO
ALTER TABLE B_FORM_CRM ADD CONSTRAINT PK_B_FORM_CRM PRIMARY KEY (ID)
GO
ALTER TABLE B_FORM_CRM ADD CONSTRAINT DF_B_FORM_CRM_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO

CREATE TABLE B_FORM_CRM_LINK
(
	ID int NOT NULL IDENTITY (1, 1),
	FORM_ID int NOT NULL,
	CRM_ID int NOT NULL,
	LINK_TYPE CHAR(1) NOT NULL
)
GO
ALTER TABLE B_FORM_CRM_LINK ADD CONSTRAINT PK_B_FORM_CRM_LINK PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX UX_B_FORM_CRM_LINK_1 ON B_FORM_CRM_LINK (FORM_ID,CRM_ID)
GO
ALTER TABLE B_FORM_CRM_LINK ADD CONSTRAINT DF_B_FORM_CRM_LINK_LINK_TYPE DEFAULT 'M' FOR LINK_TYPE
GO

CREATE TABLE B_FORM_CRM_FIELD
(
	ID int NOT NULL IDENTITY (1, 1),
	LINK_ID int NOT NULL,
	FIELD_ID int NULL,
	FIELD_ALT varchar(100) NULL,
	CRM_FIELD varchar(255) NOT NULL
)
GO
ALTER TABLE B_FORM_CRM_FIELD ADD CONSTRAINT PK_B_FORM_CRM_FIELD PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_FORM_CRM_FIELD_1 ON B_FORM_CRM_FIELD (LINK_ID)
GO

