CREATE TABLE B_FORM
(
	ID                     NUMBER(18)     NOT NULL,
	TIMESTAMP_X            DATE               NULL,
	NAME                   VARCHAR2(255 char)  NOT NULL,
	SID                    VARCHAR2(50 char)   NOT NULL,
	BUTTON                 VARCHAR2(255 char)      NULL,
	C_SORT                 NUMBER(18)     DEFAULT 100     NULL,
	FIRST_SITE_ID           CHAR(2 char)            NULL,
	IMAGE_ID               NUMBER(18)         NULL,
	USE_CAPTCHA            CHAR(1 char) DEFAULT 'N' NULL,
	DESCRIPTION            VARCHAR2(2000 char)     NULL,
	DESCRIPTION_TYPE       VARCHAR2(4 char)    DEFAULT 'html' NOT NULL,
	FORM_TEMPLATE          CLOB NULL,
	USE_DEFAULT_TEMPLATE   CHAR(1 char) DEFAULT 'Y' NULL,
	SHOW_TEMPLATE          VARCHAR2(255 char)      NULL,
	MAIL_EVENT_TYPE        VARCHAR2(50 char)       NULL,
	SHOW_RESULT_TEMPLATE   VARCHAR2(255 char)      NULL,
	PRINT_RESULT_TEMPLATE  VARCHAR2(255 char)      NULL,
	EDIT_RESULT_TEMPLATE   VARCHAR2(255 char)      NULL,
	FILTER_RESULT_TEMPLATE VARCHAR2(2000 char)     NULL,
	TABLE_RESULT_TEMPLATE  VARCHAR2(2000 char)     NULL,
	USE_RESTRICTIONS       CHAR(1 char) DEFAULT 'N' NULL,
	RESTRICT_USER          NUMBER(5,0) DEFAULT '0' NULL,
	RESTRICT_TIME          NUMBER(10,0) DEFAULT '0' NULL,
	RESTRICT_STATUS        VARCHAR2(255 char)      NULL,
	STAT_EVENT1            VARCHAR2(255 char)      NULL,
	STAT_EVENT2            VARCHAR2(255 char)      NULL,
	STAT_EVENT3            VARCHAR2(255 char)      NULL,
	PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_SID ON B_FORM(SID)
/
CREATE SEQUENCE SQ_B_FORM START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE B_FORM_2_MAIL_TEMPLATE
(
	FORM_ID          NUMBER(18) NOT NULL,
	MAIL_TEMPLATE_ID NUMBER(18) NOT NULL,
	PRIMARY KEY (FORM_ID,MAIL_TEMPLATE_ID)
)
/

CREATE TABLE B_FORM_2_SITE
(
	FORM_ID NUMBER(18) NOT NULL,
	SITE_ID CHAR(2 char)    NOT NULL,
	PRIMARY KEY (FORM_ID,SITE_ID)
)
/

CREATE TABLE B_FORM_ANSWER
(
	ID           NUMBER(18)     NOT NULL,
	FIELD_ID     NUMBER(18)     NOT NULL,
	TIMESTAMP_X  DATE               NULL,
	MESSAGE      VARCHAR2(2000 char)     NULL,
	C_SORT       NUMBER(18)     DEFAULT 100 NOT NULL,
	ACTIVE       CHAR(1 char)        DEFAULT 'Y' NOT NULL,
	VALUE        VARCHAR2(255 char)      NULL,
	FIELD_TYPE   VARCHAR2(255 char)  DEFAULT 'text' NOT NULL,
	FIELD_WIDTH  NUMBER(18)         NULL,
	FIELD_HEIGHT NUMBER(18)         NULL,
	FIELD_PARAM  VARCHAR2(2000 char)     NULL,
	PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_ANSWER_FIELD_ID ON B_FORM_ANSWER(FIELD_ID)
/
CREATE SEQUENCE SQ_B_FORM_ANSWER
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_FIELD
(
    ID                   NUMBER(18)     NOT NULL,
    FORM_ID              NUMBER(18)     NOT NULL,
    TIMESTAMP_X          DATE               NULL,
    ACTIVE               CHAR(1 char)        DEFAULT 'Y' NOT NULL,
    TITLE                VARCHAR2(2000 char)     NULL,
    TITLE_TYPE           VARCHAR2(4 char)    DEFAULT 'text' NOT NULL,
    SID                  VARCHAR2(50 char)       NULL,
    C_SORT               NUMBER(18)     DEFAULT 100 NOT NULL,
    ADDITIONAL           CHAR(1 char)        DEFAULT 'N' NOT NULL,
    REQUIRED             CHAR(1 char)        DEFAULT 'N' NOT NULL,
    IN_FILTER            CHAR(1 char)        DEFAULT 'N' NOT NULL,
    IN_RESULTS_TABLE     CHAR(1 char)        DEFAULT 'N' NOT NULL,
    IN_EXCEL_TABLE       CHAR(1 char)        DEFAULT 'Y' NOT NULL,
    FIELD_TYPE           VARCHAR2(50 char)       NULL,
    IMAGE_ID             NUMBER(18)         NULL,
    COMMENTS             VARCHAR2(2000 char)     NULL,
    FILTER_TITLE         VARCHAR2(2000 char)     NULL,
    RESULTS_TABLE_TITLE  VARCHAR2(2000 char)     NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_FIELD_FORM_ID ON B_FORM_FIELD(FORM_ID)
/
CREATE INDEX IX_B_FORM_FIELD_SID ON B_FORM_FIELD(SID)
/
CREATE SEQUENCE SQ_B_FORM_FIELD
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_FIELD_FILTER
(
    ID             NUMBER(18)   NOT NULL,
    FIELD_ID       NUMBER(18)   NOT NULL,
    PARAMETER_NAME VARCHAR2(50 char) NOT NULL,
    FILTER_TYPE    VARCHAR2(50 char) NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_FIELD_FILTER_FIELD_I ON B_FORM_FIELD_FILTER(FIELD_ID)
/
CREATE SEQUENCE SQ_B_FORM_FIELD_FILTER
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_FIELD_VALIDATOR (
  ID NUMBER (18) NOT NULL,
  FORM_ID NUMBER(18) DEFAULT 0 NOT NULL,
  FIELD_ID NUMBER(18) DEFAULT 0 NOT NULL,
  TIMESTAMP_X DATE NULL,
  ACTIVE CHAR(1 char) DEFAULT 'Y' NULL,
  C_SORT NUMBER(18) DEFAULT 100 NULL,
  VALIDATOR_SID VARCHAR2(255 char) default '' NOT NULL,
  PARAMS VARCHAR2(4000 char) default '' NULL,
  PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_FORM_FIELD_VALIDATOR START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/
CREATE INDEX IX_FORM_ID ON B_FORM_FIELD_VALIDATOR(FORM_ID)
/
CREATE INDEX IX_FIELD_ID ON B_FORM_FIELD_VALIDATOR(FIELD_ID)
/

CREATE TABLE B_FORM_MENU
(
    ID      NUMBER(18)   NOT NULL,
    FORM_ID NUMBER(18)   NOT NULL,
    LID     CHAR(2 char)      NOT NULL,
    MENU    VARCHAR2(50 char) NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_MENU_FORM_ID ON B_FORM_MENU(FORM_ID)
/
CREATE SEQUENCE SQ_B_FORM_MENU
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_RESULT
(
    ID              NUMBER(18) NOT NULL,
    TIMESTAMP_X     DATE           NULL,
    DATE_CREATE     DATE           NULL,
    STATUS_ID       NUMBER(18) NOT NULL,
    FORM_ID         NUMBER(18) NOT NULL,
    USER_ID         NUMBER(18)     NULL,
    USER_AUTH       CHAR(1 char)    DEFAULT 'N' NOT NULL,
    STAT_GUEST_ID   NUMBER(18)     NULL,
    STAT_SESSION_ID NUMBER(18)     NULL,
    SENT_TO_CRM     CHAR(1 char)    DEFAULT 'N' NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_RESULT_FORM_ID ON B_FORM_RESULT(FORM_ID)
/
CREATE INDEX IX_B_FORM_RESULT_STATUS_ID ON B_FORM_RESULT(STATUS_ID)
/
CREATE INDEX IX_B_FORM_RESULT_SENT_TO_CRM ON B_FORM_RESULT(SENT_TO_CRM)
/
CREATE SEQUENCE SQ_B_FORM_RESULT
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_RESULT_ANSWER
(
    ID                  NUMBER(18)     NOT NULL,
    RESULT_ID           NUMBER(18)     NOT NULL,
    FORM_ID             NUMBER(18)     NOT NULL,
    FIELD_ID            NUMBER(18)     NOT NULL,
    ANSWER_ID           NUMBER(18)         NULL,
    ANSWER_TEXT         VARCHAR2(2000 char)     NULL,
    ANSWER_TEXT_SEARCH  CLOB               NULL,
    ANSWER_VALUE        VARCHAR2(255 char)      NULL,
    ANSWER_VALUE_SEARCH CLOB               NULL,
    USER_TEXT           CLOB               NULL,
    USER_TEXT_SEARCH    CLOB               NULL,
    USER_DATE           DATE               NULL,
    USER_FILE_ID        NUMBER(18)         NULL,
    USER_FILE_NAME      VARCHAR2(255 char)      NULL,
    USER_FILE_IS_IMAGE  CHAR(1 char)            NULL,
    USER_FILE_HASH      VARCHAR2(255 char)      NULL,
    USER_FILE_SUFFIX    VARCHAR2(255 char)      NULL,
    USER_FILE_SIZE      NUMBER(18)         NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_RESULT_ANSWER_1 ON B_FORM_RESULT_ANSWER(FIELD_ID)
/
CREATE INDEX IX_B_FORM_RESULT_ANSWER_2 ON B_FORM_RESULT_ANSWER(RESULT_ID)
/
CREATE INDEX IX_ANSWER_ID ON B_FORM_RESULT_ANSWER(ANSWER_ID)
/
CREATE SEQUENCE SQ_B_FORM_RESULT_ANSWER
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_2_GROUP
(
    ID         NUMBER(18) NOT NULL,
    FORM_ID    NUMBER(18) NOT NULL,
    GROUP_ID   NUMBER(18) NOT NULL,
    PERMISSION NUMBER(5)  DEFAULT 1 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_2_GROUP_FORM_ID ON B_FORM_2_GROUP(FORM_ID)
/
CREATE SEQUENCE SQ_B_FORM_2_GROUP
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_STATUS
(
    ID            NUMBER(18)     NOT NULL,
    FORM_ID       NUMBER(18)     NOT NULL,
    TIMESTAMP_X   DATE               NULL,
    ACTIVE        CHAR(1 char)        DEFAULT 'Y' NOT NULL,
    C_SORT        NUMBER(18)     DEFAULT 100 NOT NULL,
    TITLE         VARCHAR2(255 char)  NOT NULL,
    DESCRIPTION   VARCHAR2(2000 char)     NULL,
    DEFAULT_VALUE CHAR(1 char)        DEFAULT 'N' NOT NULL,
    CSS           VARCHAR2(255 char)  DEFAULT 'statusgreen'     NULL,
    HANDLER_OUT   VARCHAR2(255 char)      NULL,
    HANDLER_IN    VARCHAR2(255 char)      NULL,
	MAIL_EVENT_TYPE varchar(50 char) DEFAULT NULL NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_FORM_STATUS_FORM_ID ON B_FORM_STATUS(FORM_ID)
/

CREATE SEQUENCE SQ_B_FORM_STATUS
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_STATUS_2_GROUP
(
    ID         NUMBER(18)   NOT NULL,
    STATUS_ID  NUMBER(18)   NOT NULL,
    GROUP_ID   NUMBER(18)   NOT NULL,
    PERMISSION VARCHAR2(50 char) NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_FORM_STATUS_GROUP ON B_FORM_STATUS_2_GROUP (STATUS_ID, GROUP_ID)
/
CREATE SEQUENCE SQ_B_FORM_STATUS_2_GROUP
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE
    NOCYCLE
    NOCACHE
    NOORDER
/

CREATE TABLE B_FORM_STATUS_2_MAIL_TEMPLATE
(
	STATUS_ID NUMBER(18) NOT NULL,
	MAIL_TEMPLATE_ID NUMBER(18) NOT NULL,
	PRIMARY KEY (STATUS_ID,MAIL_TEMPLATE_ID)
)
/

CREATE OR REPLACE FUNCTION CONVERT_TO_NUMBER
(
	pVALUE IN VARCHAR
)
RETURN NUMBER
IS
	vNUM NUMBER;
BEGIN
	BEGIN
		SELECT TO_NUMBER(pVALUE) INTO vNUM FROM DUAL;
		EXCEPTION
			WHEN OTHERS THEN
				vNUM := NULL;
	END;
 	RETURN vNUM;
END;
/

CREATE TABLE B_FORM_CRM (
  ID NUMBER(18) NOT NULL,
  NAME VARCHAR2(255 CHAR) DEFAULT '' NOT NULL,
  ACTIVE CHAR(1 CHAR) DEFAULT 'Y' NULL,
  URL VARCHAR2(255 CHAR) DEFAULT '' NOT NULL,
  AUTH_HASH VARCHAR2(32 CHAR) DEFAULT '' NULL,
  PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_FORM_CRM START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/


CREATE TABLE B_FORM_CRM_LINK (
  ID NUMBER(18) NOT NULL,
  FORM_ID NUMBER(18) DEFAULT 0 NOT NULL,
  CRM_ID NUMBER(18) DEFAULT 0 NOT NULL,
  LINK_TYPE CHAR(1 CHAR) DEFAULT 'M' NOT NULL,
  PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_FORM_CRM_LINK START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/
CREATE UNIQUE INDEX UX_B_FORM_CRM_LINK_1 ON B_FORM_CRM_LINK (FORM_ID,CRM_ID)
/

CREATE TABLE B_FORM_CRM_FIELD (
  ID NUMBER(18) NOT NULL,
  LINK_ID NUMBER(18) DEFAULT 0 NOT NULL,
  FIELD_ID NUMBER(18) DEFAULT 0 NULL,
  FIELD_ALT VARCHAR2(100 CHAR) DEFAULT '' NULL,
  CRM_FIELD VARCHAR2(255 CHAR) DEFAULT '' NOT NULL,
  PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_FORM_CRM_FIELD START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/
CREATE INDEX IX_B_FORM_CRM_FIELD_1 ON B_FORM_CRM_FIELD (LINK_ID)
/

