CREATE TABLE B_IM_CHAT
(
	ID int NOT NULL IDENTITY (1, 1),
	TITLE varchar(255) NULL,
	AUTHOR_ID int NOT NULL
)
ALTER TABLE B_IM_CHAT ADD CONSTRAINT PK_B_IMC PRIMARY KEY (ID)
GO
CREATE INDEX IX_IM_CHAT_1 ON B_IM_CHAT(AUTHOR_ID)
GO



CREATE TABLE B_IM_MESSAGE
(
	ID int NOT NULL IDENTITY (1, 1),
	CHAT_ID int NOT NULL,
	AUTHOR_ID int NOT NULL,
	MESSAGE text NULL,
	MESSAGE_OUT text NULL,
	DATE_CREATE datetime NOT NULL,
	EMAIL_TEMPLATE varchar(255) NULL,
	NOTIFY_TYPE tinyint,
	NOTIFY_MODULE varchar(255) NULL,
	NOTIFY_EVENT varchar(255) NULL,
	NOTIFY_TAG varchar(255) NULL,
	NOTIFY_SUB_TAG varchar(255) NULL,
	NOTIFY_TITLE varchar(255) NULL,
	NOTIFY_BUTTONS text NULL,
	NOTIFY_READ char(1),
	IMPORT_ID int NULL
)
ALTER TABLE B_IM_MESSAGE ADD CONSTRAINT PK_B_IMM PRIMARY KEY (ID)
GO
ALTER TABLE B_IM_MESSAGE ADD CONSTRAINT DF_B_IMM_NT DEFAULT '0' FOR NOTIFY_TYPE
GO
ALTER TABLE B_IM_MESSAGE ADD CONSTRAINT DF_B_IMM_NR DEFAULT 'N' FOR NOTIFY_READ
GO
CREATE INDEX IX_IM_MESS_1 ON B_IM_MESSAGE(CHAT_ID)
GO
CREATE INDEX IX_IM_MESS_2 ON B_IM_MESSAGE(NOTIFY_TAG, AUTHOR_ID)
GO
CREATE INDEX IX_IM_MESS_3 ON B_IM_MESSAGE(NOTIFY_SUB_TAG, AUTHOR_ID)
GO



CREATE TABLE B_IM_RELATION
(
	ID int NOT NULL IDENTITY (1, 1),
	CHAT_ID int NOT NULL,
	MESSAGE_TYPE char(2),
	USER_ID int NOT NULL,
	START_ID int,
	LAST_ID int,
	LAST_SEND_ID int,
	LAST_READ datetime null,
	STATUS tinyint
)
ALTER TABLE B_IM_RELATION ADD CONSTRAINT PK_B_IMR PRIMARY KEY (ID)
GO
ALTER TABLE B_IM_RELATION ADD CONSTRAINT DF_B_IMR_MT DEFAULT 'P' FOR MESSAGE_TYPE
GO
ALTER TABLE B_IM_RELATION ADD CONSTRAINT DF_B_IMR_SI DEFAULT '0' FOR START_ID
GO
ALTER TABLE B_IM_RELATION ADD CONSTRAINT DF_B_IMR_LI DEFAULT '0' FOR LAST_ID
GO
ALTER TABLE B_IM_RELATION ADD CONSTRAINT DF_B_IMR_LSI DEFAULT '0' FOR LAST_SEND_ID
GO
ALTER TABLE B_IM_RELATION ADD CONSTRAINT DF_B_IMR_S DEFAULT '0' FOR STATUS
GO
CREATE INDEX IX_IM_REL_1 ON B_IM_RELATION(CHAT_ID)
GO
CREATE INDEX IX_IM_REL_2 ON B_IM_RELATION(USER_ID, MESSAGE_TYPE, STATUS)
GO
CREATE INDEX IX_IM_REL_3 ON B_IM_RELATION(USER_ID, MESSAGE_TYPE, CHAT_ID)
GO
CREATE INDEX IX_IM_REL_4 ON B_IM_RELATION(USER_ID, STATUS)
GO
CREATE INDEX IX_IM_REL_5 ON B_IM_RELATION(MESSAGE_TYPE, STATUS)
GO

CREATE TABLE B_IM_RECENT
(
	USER_ID int not null,
	ITEM_TYPE char(2) not null,
	ITEM_ID int not null,
	ITEM_MID int not null
)
GO
ALTER TABLE B_IM_RECENT ADD CONSTRAINT PK_B_IM_RECENT PRIMARY KEY (USER_ID, ITEM_TYPE, ITEM_ID)
GO
ALTER TABLE B_IM_RECENT ADD CONSTRAINT DF_B_IMREC_IT DEFAULT 'P' FOR ITEM_TYPE
GO
CREATE INDEX IX_IM_REC_1 ON B_IM_RECENT(ITEM_TYPE, ITEM_ID)
GO
