CREATE TABLE B_SEC_FILTER_MASK
(
	ID int NOT NULL IDENTITY (1, 1),
	SORT int NOT NULL,
	SITE_ID char(2),
	FILTER_MASK varchar(250),
	LIKE_MASK varchar(250),
	PREG_MASK varchar(250)
)
GO
ALTER TABLE B_SEC_FILTER_MASK ADD CONSTRAINT PK_B_SEC_FILTER_MASK PRIMARY KEY (ID)
GO
ALTER TABLE B_SEC_FILTER_MASK ADD CONSTRAINT DF_B_SEC_FILTER_MASK_SORT DEFAULT '10' FOR SORT
GO

CREATE TABLE B_SEC_FRAME_MASK
(
	ID int NOT NULL IDENTITY (1, 1),
	SORT int NOT NULL,
	SITE_ID char(2),
	FRAME_MASK varchar(250),
	LIKE_MASK varchar(250),
	PREG_MASK varchar(250)
)
GO
ALTER TABLE B_SEC_FRAME_MASK ADD CONSTRAINT PK_B_SEC_FRAME_MASK PRIMARY KEY (ID)
GO
ALTER TABLE B_SEC_FRAME_MASK ADD CONSTRAINT DF_B_SEC_FRAME_MASK_SORT DEFAULT '10' FOR SORT
GO

CREATE TABLE B_SEC_IPRULE
(
	ID int NOT NULL IDENTITY (1, 1),
	RULE_TYPE char(1) NOT NULL,
	ACTIVE char(1) NOT NULL,
	ADMIN_SECTION char(1) NOT NULL,
	SITE_ID char(2),
	SORT int NOT NULL,
	ACTIVE_FROM datetime,
	ACTIVE_FROM_TIMESTAMP int,
	ACTIVE_TO datetime,
	ACTIVE_TO_TIMESTAMP int,
	NAME varchar(250)
)
GO
ALTER TABLE B_SEC_IPRULE ADD CONSTRAINT PK_B_SEC_IPRULE PRIMARY KEY (ID)
GO
ALTER TABLE B_SEC_IPRULE ADD CONSTRAINT DF_B_SEC_IPRULE_RULE_TYPE DEFAULT 'M' FOR RULE_TYPE
GO
ALTER TABLE B_SEC_IPRULE ADD CONSTRAINT DF_B_SEC_IPRULE_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_SEC_IPRULE ADD CONSTRAINT DF_B_SEC_IPRULE_ADMIN_SECTION DEFAULT 'Y' FOR ADMIN_SECTION
GO
ALTER TABLE B_SEC_IPRULE ADD CONSTRAINT DF_B_SEC_IPRULE_SORT DEFAULT '500' FOR SORT
GO
CREATE INDEX IX_B_SEC_IPRULE_ACTIVE_TO on B_SEC_IPRULE(ACTIVE_TO)
GO

CREATE TABLE B_SEC_IPRULE_INCL_MASK
(
	IPRULE_ID int NOT NULL,
	RULE_MASK varchar(250) NOT NULL,
	SORT int NOT NULL,
	LIKE_MASK varchar(250),
	PREG_MASK varchar(250)
)
GO
ALTER TABLE B_SEC_IPRULE_INCL_MASK ADD CONSTRAINT PK_B_SEC_IPRULE_INCL_MASK PRIMARY KEY (IPRULE_ID, RULE_MASK)
GO
ALTER TABLE B_SEC_IPRULE_INCL_MASK ADD CONSTRAINT DF_B_SEC_IPRULE_INCL_MASK_SORT DEFAULT '500' FOR SORT
GO
ALTER TABLE B_SEC_IPRULE_INCL_MASK ADD CONSTRAINT FK_B_SEC_IPRULE_INCL_MASK_IPRULE_ID FOREIGN KEY (IPRULE_ID) REFERENCES B_SEC_IPRULE(ID)
GO

CREATE TABLE B_SEC_IPRULE_EXCL_MASK
(
	IPRULE_ID int NOT NULL,
	RULE_MASK varchar(250) NOT NULL,
	SORT int NOT NULL,
	LIKE_MASK varchar(250),
	PREG_MASK varchar(250)
)
GO
ALTER TABLE B_SEC_IPRULE_EXCL_MASK ADD CONSTRAINT PK_B_SEC_IPRULE_EXCL_MASK PRIMARY KEY (IPRULE_ID, RULE_MASK)
GO
ALTER TABLE B_SEC_IPRULE_EXCL_MASK ADD CONSTRAINT DF_B_SEC_IPRULE_EXCL_MASK_SORT DEFAULT '500' FOR SORT
GO
ALTER TABLE B_SEC_IPRULE_EXCL_MASK ADD CONSTRAINT FK_B_SEC_IPRULE_EXCL_MASK_IPRULE_ID FOREIGN KEY (IPRULE_ID) REFERENCES B_SEC_IPRULE(ID)
GO

CREATE TABLE B_SEC_IPRULE_INCL_IP
(
	IPRULE_ID int NOT NULL,
	RULE_IP varchar(50) NOT NULL,
	SORT int NOT NULL,
	IP_START bigint,
	IP_END bigint,
)
GO
ALTER TABLE B_SEC_IPRULE_INCL_IP ADD CONSTRAINT PK_B_SEC_IPRULE_INCL_IP PRIMARY KEY (IPRULE_ID, RULE_IP)
GO
ALTER TABLE B_SEC_IPRULE_INCL_IP ADD CONSTRAINT DF_B_SEC_IPRULE_INCL_IP_SORT DEFAULT '500' FOR SORT
GO
ALTER TABLE B_SEC_IPRULE_INCL_IP ADD CONSTRAINT FK_B_SEC_IPRULE_INCL_IP_IPRULE_ID FOREIGN KEY (IPRULE_ID) REFERENCES B_SEC_IPRULE(ID)
GO

CREATE TABLE B_SEC_IPRULE_EXCL_IP
(
	IPRULE_ID int NOT NULL,
	RULE_IP varchar(50) NOT NULL,
	SORT int NOT NULL,
	IP_START bigint,
	IP_END bigint,
)
GO
ALTER TABLE B_SEC_IPRULE_EXCL_IP ADD CONSTRAINT PK_B_SEC_IPRULE_EXCL_IP PRIMARY KEY (IPRULE_ID, RULE_IP)
GO
ALTER TABLE B_SEC_IPRULE_EXCL_IP ADD CONSTRAINT DF_B_SEC_IPRULE_EXCL_IP_SORT DEFAULT '500' FOR SORT
GO
ALTER TABLE B_SEC_IPRULE_EXCL_IP ADD CONSTRAINT FK_B_SEC_IPRULE_EXCL_IP_IPRULE_ID FOREIGN KEY (IPRULE_ID) REFERENCES B_SEC_IPRULE(ID)
GO

CREATE TABLE B_SEC_SESSION
(
	SESSION_ID varchar(250) NOT NULL,
	TIMESTAMP_X datetime NOT NULL,
	SESSION_DATA text,
)
GO
ALTER TABLE B_SEC_SESSION ADD CONSTRAINT PK_B_SEC_SESSION PRIMARY KEY (SESSION_ID)
GO
CREATE INDEX IX_B_SEC_SESSION_1 ON B_SEC_SESSION (TIMESTAMP_X)
GO

CREATE TABLE B_SEC_USER
(
	USER_ID int NOT NULL,
	ACTIVE char(1) NOT NULL,
	SECRET varchar(64) NOT NULL,
	COUNTER int NOT NULL
)
GO
ALTER TABLE B_SEC_USER ADD CONSTRAINT PK_B_SEC_USER PRIMARY KEY (USER_ID)
GO
ALTER TABLE B_SEC_USER ADD CONSTRAINT DF_B_SEC_USER_ACTIVE DEFAULT 'N' FOR ACTIVE
GO
ALTER TABLE B_SEC_USER ADD CONSTRAINT FK_B_SEC_USER_USER_ID FOREIGN KEY (USER_ID) REFERENCES B_USER(ID)
GO

CREATE TABLE B_SEC_REDIRECT_URL
(
	IS_SYSTEM char(1) NOT NULL,
	SORT int NOT NULL,
	URL varchar(250) NOT NULL,
	PARAMETER_NAME varchar(250) NOT NULL
)
GO
ALTER TABLE B_SEC_REDIRECT_URL ADD CONSTRAINT DF_B_SEC_REDIRECT_URL_IS_SYSTEM DEFAULT 'Y' FOR IS_SYSTEM
GO
ALTER TABLE B_SEC_REDIRECT_URL ADD CONSTRAINT DF_B_SEC_REDIRECT_URL_SORT DEFAULT '500' FOR SORT
GO
insert into B_SEC_REDIRECT_URL values ('Y', 10, '/bitrix/redirect.php', 'goto')
GO
insert into B_SEC_REDIRECT_URL values ('Y', 20, '/bitrix/rk.php', 'goto')
GO
insert into B_SEC_REDIRECT_URL values ('Y', 30, '/bitrix/click.php', 'goto')
GO

CREATE TABLE B_SEC_WHITE_LIST
(
	ID int NOT NULL,
	WHITE_SUBSTR varchar(250) NOT NULL
)
GO
ALTER TABLE B_SEC_WHITE_LIST ADD CONSTRAINT PK_B_SEC_WHITE_LIST PRIMARY KEY (ID)
GO

CREATE TABLE B_SEC_VIRUS
(
	ID varchar(32) NOT NULL,
	TIMESTAMP_X datetime NOT NULL,
	SITE_ID char(2),
	SENT char(1) NOT NULL,
	INFO text NOT NULL
)
GO
ALTER TABLE B_SEC_VIRUS ADD CONSTRAINT PK_B_SEC_VIRUS PRIMARY KEY (ID)
GO
ALTER TABLE B_SEC_VIRUS ADD CONSTRAINT DF_B_SEC_VIRUS_SENT DEFAULT 'N' FOR SENT
GO
CREATE TABLE b_security_sitecheck
(
	ID int NOT NULL IDENTITY (1, 1),
	TEST_DATE datetime,
	RESULTS text,
	PRIMARY KEY (ID)
)
GO