create table B_SONET_GROUP_SUBJECT
(
  ID int not null IDENTITY (1, 1),
  SITE_ID char(2) not null,
  NAME varchar(255) not null,
  SORT int NOT NULL
)
GO
ALTER TABLE B_SONET_GROUP_SUBJECT ADD CONSTRAINT PK_B_SONET_GROUP_SUBJECT PRIMARY KEY (ID)
GO

CREATE TABLE B_SONET_GROUP_SUBJECT_SITE
(
	SUBJECT_ID int NOT NULL,
	SITE_ID char(2) NOT NULL
)
GO
ALTER TABLE B_SONET_GROUP_SUBJECT_SITE ADD CONSTRAINT PK_B_SONET_GROUP_SUBJECT_SITE PRIMARY KEY (SUBJECT_ID, SITE_ID)
GO

create table B_SONET_GROUP
(
  ID int not null IDENTITY (1, 1),
  SITE_ID char(2) not null,
  NAME varchar(255) not null,
  DESCRIPTION text null,
  DATE_CREATE datetime not null,
  DATE_UPDATE datetime not null,
  ACTIVE char(1) not null default 'Y',
  VISIBLE char(1) not null default 'Y',
  OPENED char(1) not null default 'N',
  SUBJECT_ID int not null,
  OWNER_ID int not null,
  KEYWORDS varchar(255) null,
  IMAGE_ID int null,
  NUMBER_OF_MEMBERS int not null default 0,
  NUMBER_OF_MODERATORS int not null,
  INITIATE_PERMS char(1) not null default 'K',
  SPAM_PERMS char(1) not null default 'K',
  DATE_ACTIVITY datetime not null,
  CLOSED char(1) not null default 'N'
)
GO
ALTER TABLE B_SONET_GROUP ADD CONSTRAINT PK_B_SONET_GROUP PRIMARY KEY (ID)
GO
ALTER TABLE B_SONET_GROUP ADD CONSTRAINT DF_B_SONET_GROUP_NUMBER_OF_MODERATORS DEFAULT 0 FOR NUMBER_OF_MODERATORS
GO
CREATE INDEX IX_B_SONET_GROUP_1 ON B_SONET_GROUP(OWNER_ID)
GO

CREATE TABLE B_SONET_GROUP_SITE
(
	GROUP_ID int NOT NULL,
	SITE_ID char(2) NOT NULL
)
GO
ALTER TABLE B_SONET_GROUP_SITE ADD CONSTRAINT PK_B_SONET_GROUP_SITE PRIMARY KEY (GROUP_ID, SITE_ID)
GO

create table B_SONET_USER2GROUP
(
  ID int not null IDENTITY (1, 1),
  USER_ID int not null,
  GROUP_ID int not null,
  ROLE char(1) not null default 'U',
  DATE_CREATE datetime not null,
  DATE_UPDATE datetime not null,
  INITIATED_BY_TYPE char(1) not null default 'U',
  INITIATED_BY_USER_ID int not null,
  MESSAGE text null
)
GO
ALTER TABLE B_SONET_USER2GROUP ADD CONSTRAINT PK_B_SONET_USER2GROUP PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_B_SONET_USER2GROUP_1 ON B_SONET_USER2GROUP(USER_ID, GROUP_ID)
GO
CREATE INDEX IX_B_SONET_USER2GROUP_2 ON B_SONET_USER2GROUP(USER_ID, GROUP_ID, ROLE)
GO
CREATE INDEX IX_B_SONET_USER2GROUP_3 ON B_SONET_USER2GROUP(GROUP_ID, USER_ID, ROLE)
GO


create table B_SONET_FEATURES
(
  ID int not null IDENTITY (1, 1),
  ENTITY_TYPE char(1) not null default 'G',
  ENTITY_ID int not null,
  FEATURE varchar(50) not null,
  FEATURE_NAME varchar(250) null,
  ACTIVE char(1) not null default 'Y',
  DATE_CREATE datetime not null,
  DATE_UPDATE datetime not null
)
GO
ALTER TABLE B_SONET_FEATURES ADD CONSTRAINT PK_B_SONET_FEATURES PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_SONET_GROUP_FEATURES_1 ON B_SONET_FEATURES(ENTITY_TYPE, ENTITY_ID, FEATURE)
GO



create table B_SONET_FEATURES2PERMS
(
  ID int not null IDENTITY (1, 1),
  FEATURE_ID int not null,
  OPERATION_ID varchar(50) not null,
  ROLE char(1) not null
)
GO
ALTER TABLE B_SONET_FEATURES2PERMS ADD CONSTRAINT PK_B_SONET_FEATURES2PERMS PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_SONET_GROUP_FEATURES2PERMS_1 ON B_SONET_FEATURES2PERMS(FEATURE_ID, OPERATION_ID)
GO
CREATE INDEX IX_SONET_GROUP_FEATURES2PERMS_2 ON B_SONET_FEATURES2PERMS(FEATURE_ID, ROLE, OPERATION_ID)
GO



create table B_SONET_USER_RELATIONS
(
  ID int not null IDENTITY (1, 1),
  FIRST_USER_ID int not null,
  SECOND_USER_ID int not null,
  RELATION char(1) not null default 'N',
  DATE_CREATE datetime not null,
  DATE_UPDATE datetime not null,
  MESSAGE text null,
  INITIATED_BY char(1) not null default 'F'
)
GO
ALTER TABLE B_SONET_USER_RELATIONS ADD CONSTRAINT PK_B_SONET_USER_RELATIONS PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_SONET_RELATIONS_1 ON B_SONET_USER_RELATIONS(FIRST_USER_ID, SECOND_USER_ID)
GO
CREATE INDEX IX_SONET_RELATIONS_2 ON B_SONET_USER_RELATIONS(FIRST_USER_ID, SECOND_USER_ID, RELATION)
GO



create table B_SONET_MESSAGES
(
  ID int not null IDENTITY (1, 1),
  FROM_USER_ID int not null,
  TO_USER_ID int not null,
  TITLE varchar(250) null,
  MESSAGE text null,
  DATE_CREATE datetime not null,
  DATE_VIEW datetime null,
  SEND_MAIL char(1) not null default 'N',
  MESSAGE_TYPE char(1) not null default 'P',
  FROM_DELETED char(1) not null default 'N',
  TO_DELETED char(1) not null default 'N',
  EMAIL_TEMPLATE varchar(250) null,
  IS_LOG char(1) null
)
GO
ALTER TABLE B_SONET_MESSAGES ADD CONSTRAINT PK_B_SONET_MESSAGES PRIMARY KEY (ID)
GO
CREATE INDEX IX_SONET_MESSAGES_1 ON B_SONET_MESSAGES(FROM_USER_ID)
GO
CREATE INDEX IX_SONET_MESSAGES_2 ON B_SONET_MESSAGES(TO_USER_ID)
GO

create table B_SONET_SMILE (
   ID int not null IDENTITY (1, 1),
   SMILE_TYPE char(1) not null default 'S',
   TYPING varchar(100) null,
   IMAGE varchar(128) not null,
   DESCRIPTION varchar(50),
   CLICKABLE char(1) not null default 'Y',
   SORT int not null default '150',
   IMAGE_WIDTH int not null default '0',
   IMAGE_HEIGHT int not null default '0'
)
GO
ALTER TABLE B_SONET_SMILE ADD CONSTRAINT PK_B_SONET_SMILE PRIMARY KEY (ID)
GO

create table B_SONET_SMILE_LANG (
   ID int not null IDENTITY (1, 1),
   SMILE_ID int not null default '0',
   LID char(2) not null,
   NAME varchar(255) not null
)
GO
ALTER TABLE B_SONET_SMILE_LANG ADD CONSTRAINT PK_B_SONET_SMILE_LANG PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_SONET_SMILE_K ON B_SONET_SMILE_LANG(SMILE_ID, LID)
GO



create table B_SONET_USER_PERMS
(
  ID int not null IDENTITY (1, 1),
  USER_ID int not null,
  OPERATION_ID varchar(50) not null,
  RELATION_TYPE char(1) not null
)
GO
ALTER TABLE B_SONET_USER_PERMS ADD CONSTRAINT PK_B_SONET_USER_PERMS PRIMARY KEY (ID)
GO
CREATE INDEX IX_SONET_USER_PERMS_1 ON B_SONET_USER_PERMS(USER_ID)
GO
CREATE UNIQUE INDEX IX_SONET_USER_PERMS_2 ON B_SONET_USER_PERMS(USER_ID, OPERATION_ID)
GO



create table B_SONET_USER_EVENTS
(
  ID int not null IDENTITY (1, 1),
  USER_ID int not null,
  EVENT_ID varchar(50) not null,
  ACTIVE char(1) not null default 'Y',
  SITE_ID char(2) not null
)
GO
ALTER TABLE B_SONET_USER_EVENTS ADD CONSTRAINT PK_B_SONET_USER_EVENTS PRIMARY KEY (ID)
GO
CREATE INDEX IX_SONET_USER_EVENTS_1 ON B_SONET_USER_EVENTS(USER_ID)
GO
CREATE UNIQUE INDEX IX_SONET_USER_EVENTS_2 ON B_SONET_USER_EVENTS(USER_ID, EVENT_ID)
GO

create table B_SONET_LOG
(
  ID int not null IDENTITY (1, 1),
  ENTITY_TYPE varchar(50) not null,
  ENTITY_ID int not null,
  EVENT_ID varchar(50) not null,
  USER_ID int null,
  LOG_DATE datetime not null,
  SITE_ID char(2) null,
  TITLE_TEMPLATE varchar(250) null,
  TITLE varchar(250) not null,
  MESSAGE text null,
  TEXT_MESSAGE text null,
  URL varchar(500) null,
  MODULE_ID varchar(50) null,
  CALLBACK_FUNC varchar(250) null,
  EXTERNAL_ID varchar(250) null,
  PARAMS text null,
  TMP_ID int null,
  SOURCE_ID int null,
  LOG_UPDATE datetime not null,
  COMMENTS_COUNT int null,
  ENABLE_COMMENTS char(1),
  RATING_TYPE_ID varchar(50) null,
  RATING_ENTITY_ID int null,
  SOURCE_TYPE varchar(50) null
)
GO
ALTER TABLE B_SONET_LOG ADD CONSTRAINT PK_B_SONET_LOG PRIMARY KEY (ID)
GO
CREATE INDEX IX_SONET_LOG_1 ON B_SONET_LOG(ENTITY_TYPE, ENTITY_ID, LOG_DATE)
GO
CREATE INDEX IX_SONET_LOG_2 ON B_SONET_LOG(USER_ID, LOG_DATE, EVENT_ID)
GO
CREATE INDEX IX_SONET_LOG_3 ON B_SONET_LOG(SOURCE_ID)
GO
ALTER TABLE B_SONET_LOG ADD CONSTRAINT DF_B_SONET_LOG_ENTITY_TYPE DEFAULT 'G' FOR ENTITY_TYPE
GO
ALTER TABLE B_SONET_LOG ADD CONSTRAINT DF_B_SONET_LOG_ENABLE_COMMENTS DEFAULT 'Y' FOR ENABLE_COMMENTS
GO
ALTER TABLE B_SONET_LOG ADD CONSTRAINT DF_B_SONET_LOG_LOG_UPDATE DEFAULT (('2001-01-01')) FOR LOG_UPDATE
GO

CREATE TABLE B_SONET_LOG_SITE
(
	LOG_ID int NOT NULL,
	SITE_ID char(2) NOT NULL
)
GO
ALTER TABLE B_SONET_LOG_SITE ADD CONSTRAINT PK_B_SONET_LOG_SITE PRIMARY KEY (LOG_ID, SITE_ID)
GO

CREATE TABLE B_SONET_LOG_COMMENT
(
	ID int not null IDENTITY (1, 1),
	LOG_ID int not null,
	ENTITY_TYPE varchar(50) not null,
	ENTITY_ID int not null,
	EVENT_ID varchar(50) not null,
	USER_ID int null,
	LOG_DATE datetime not null,
	MESSAGE text null,
	TEXT_MESSAGE text null,
	MODULE_ID varchar(50) null,
	SOURCE_ID int null,
	URL varchar(500) null,
	RATING_TYPE_ID varchar(50) null,
	RATING_ENTITY_ID int null
)
GO
ALTER TABLE B_SONET_LOG_COMMENT ADD CONSTRAINT PK_B_SONET_LOG_COMMENT PRIMARY KEY (ID)
GO
ALTER TABLE B_SONET_LOG_COMMENT ADD CONSTRAINT DF_B_SONET_LOG_COMMENT_ENTITY_TYPE DEFAULT 'G' FOR ENTITY_TYPE
GO
CREATE INDEX IX_SONET_LOG_COMMENT_1 ON B_SONET_LOG_COMMENT(ENTITY_TYPE, ENTITY_ID, EVENT_ID)
GO
CREATE INDEX IX_SONET_LOG_COMMENT_2 ON B_SONET_LOG_COMMENT(USER_ID, LOG_DATE, EVENT_ID)
GO

create table B_SONET_LOG_EVENTS
(
  ID int not null IDENTITY (1, 1),
  USER_ID int not null,
  ENTITY_TYPE varchar(50) not null,
  ENTITY_ID int not null,
  ENTITY_CB char(1) not null,
  ENTITY_MY char(1) not null,
  EVENT_ID varchar(50) not null,
  SITE_ID char(2) null,
  MAIL_EVENT char(1) not null default 'N',
  TRANSPORT char(1) not null,
  VISIBLE char(1) not null
)
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT PK_B_SONET_LOG_EVENTS PRIMARY KEY (ID)
GO
CREATE INDEX IX_SONET_LOG_EVENTS_1 ON B_SONET_LOG_EVENTS(USER_ID)
GO
CREATE INDEX IX_SONET_LOG_EVENTS_2 ON B_SONET_LOG_EVENTS(ENTITY_TYPE, ENTITY_ID, EVENT_ID)
GO
CREATE UNIQUE INDEX IX_SONET_LOG_EVENTS_3 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_TYPE, ENTITY_ID, ENTITY_CB, ENTITY_MY, EVENT_ID, SITE_ID)
GO
CREATE INDEX IX_SONET_LOG_EVENTS_4 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_CB, ENTITY_ID)
GO
CREATE INDEX IX_SONET_LOG_EVENTS_5 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_MY, ENTITY_TYPE, ENTITY_ID)
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT DF_B_SONET_LOG_EVENTS_ENTITY_CB DEFAULT 'N' FOR ENTITY_CB
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT DF_B_SONET_LOG_EVENTS_ENTITY_MY DEFAULT 'N' FOR ENTITY_MY
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT DF_B_SONET_LOG_EVENTS_TRANSPORT DEFAULT 'N' FOR TRANSPORT
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT DF_B_SONET_LOG_EVENTS_VISIBLE DEFAULT 'Y' FOR VISIBLE
GO
ALTER TABLE B_SONET_LOG_EVENTS ADD CONSTRAINT DF_B_SONET_LOG_EVENTS_ENTITY_TYPE DEFAULT 'G' FOR ENTITY_TYPE
GO

CREATE TABLE B_SONET_EVENT_USER_VIEW
(
	ENTITY_TYPE varchar(50) NOT NULL,
	ENTITY_ID int NOT NULL,
	EVENT_ID varchar(50) NOT NULL,
	USER_ID int NOT NULL,
	USER_IM_ID int NOT NULL,
	USER_ANONYMOUS char(1) NOT NULL
)
GO
ALTER TABLE B_SONET_EVENT_USER_VIEW ADD CONSTRAINT PK_B_SONET_EVENT_USER_VIEW PRIMARY KEY (ENTITY_TYPE,ENTITY_ID,EVENT_ID,USER_ID,USER_IM_ID)
GO
CREATE INDEX IX_SONET_EVENT_USER_VIEW_1 ON B_SONET_EVENT_USER_VIEW(USER_ID, EVENT_ID, ENTITY_TYPE, USER_ANONYMOUS)
GO
ALTER TABLE B_SONET_EVENT_USER_VIEW ADD CONSTRAINT DF_B_SONET_EVENT_USER_VIEW_ENTITY_TYPE DEFAULT 'G' FOR ENTITY_TYPE
GO
ALTER TABLE B_SONET_EVENT_USER_VIEW ADD CONSTRAINT DF_B_SONET_EVENT_USER_VIEW_USER_ID DEFAULT 0 FOR USER_ID
GO
ALTER TABLE B_SONET_EVENT_USER_VIEW ADD CONSTRAINT DF_B_SONET_EVENT_USER_VIEW_USER_IM_ID DEFAULT 0 FOR USER_IM_ID
GO
ALTER TABLE B_SONET_EVENT_USER_VIEW ADD CONSTRAINT DF_B_SONET_EVENT_USER_VIEW_USER_ANONYMOUS DEFAULT 'N' FOR USER_ANONYMOUS
GO

CREATE TABLE B_SONET_LOG_RIGHT
(
	ID int not null IDENTITY (1, 1),
	LOG_ID int not null,
	GROUP_CODE varchar(50) not null
)
GO
ALTER TABLE B_SONET_LOG_RIGHT ADD CONSTRAINT PK_B_SONET_LOG_RIGHT PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_SONET_LOG_RIGHT_GROUP_CODE ON B_SONET_LOG_RIGHT(LOG_ID, GROUP_CODE)
GO

CREATE TABLE B_SONET_LOG_COUNTER
(
	USER_ID int not null,
	SITE_ID char(2) not null,
	CODE varchar(50) not null,
	CNT int not null,
	LAST_DATE datetime,
	PAGE_SIZE int null,
	PAGE_LAST_DATE_1 datetime null
)
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT PK_B_SONET_LOG_COUNTER PRIMARY KEY (USER_ID, SITE_ID, CODE)
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT DF_B_SONET_LOG_COUNTER_CNT DEFAULT 0 FOR CNT
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT DF_B_SONET_LOG_COUNTER_SITE_ID DEFAULT '**' FOR SITE_ID
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT DF_B_SONET_LOG_COUNTER_CODE DEFAULT '**' FOR CODE
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT DF_B_SONET_LOG_COUNTER_PAGE_SIZE DEFAULT NULL FOR PAGE_SIZE
GO
ALTER TABLE B_SONET_LOG_COUNTER ADD CONSTRAINT DF_B_SONET_LOG_COUNTER_PAGE_LAST_DATE_1 DEFAULT NULL FOR PAGE_LAST_DATE_1
GO

CREATE TABLE B_SONET_LOG_PAGE
(
	USER_ID int not null,
	SITE_ID char(2) not null,
	PAGE_SIZE int not null,
	PAGE_NUM int not null,
	PAGE_LAST_DATE datetime null
)
GO
ALTER TABLE B_SONET_LOG_PAGE ADD CONSTRAINT PK_B_SONET_LOG_PAGE PRIMARY KEY (USER_ID, SITE_ID, PAGE_SIZE, PAGE_NUM)
GO
ALTER TABLE B_SONET_LOG_PAGE ADD CONSTRAINT DF_B_SONET_LOG_PAGE_SITE_ID DEFAULT '**' FOR SITE_ID
GO
ALTER TABLE B_SONET_LOG_PAGE ADD CONSTRAINT DF_B_SONET_LOG_PAGE_PAGE_NUM DEFAULT 1 FOR PAGE_NUM
GO

CREATE TABLE B_SONET_LOG_FOLLOW
(
	USER_ID int not null,
	CODE varchar(50) not null,
	TYPE char(1) not null,
	FOLLOW_DATE datetime null
)
GO
ALTER TABLE B_SONET_LOG_FOLLOW ADD CONSTRAINT PK_B_SONET_LOG_FOLLOW PRIMARY KEY (USER_ID, CODE)
GO
ALTER TABLE B_SONET_LOG_FOLLOW ADD CONSTRAINT DF_B_SONET_LOG_FOLLOW_CODE DEFAULT '**' FOR CODE
GO
ALTER TABLE B_SONET_LOG_FOLLOW ADD CONSTRAINT DF_B_SONET_LOG_FOLLOW_TYPE DEFAULT 'Y' FOR TYPE
GO

CREATE TABLE B_SONET_LOG_SMARTFILTER
(
	USER_ID int not null,
	TYPE char(1) not null
)
GO
ALTER TABLE B_SONET_LOG_SMARTFILTER ADD CONSTRAINT PK_B_SONET_LOG_SMARTFILTER PRIMARY KEY (USER_ID)
GO
ALTER TABLE B_SONET_LOG_SMARTFILTER ADD CONSTRAINT DF_B_SONET_LOG_SMARTFILTER_TYPE DEFAULT 'N' FOR TYPE
GO

CREATE TABLE B_SONET_LOG_FAVORITES
(
	USER_ID int not null,
	LOG_ID int not null
)
GO
ALTER TABLE B_SONET_LOG_FAVORITES ADD CONSTRAINT PK_B_SONET_LOG_FAVORITES PRIMARY KEY (USER_ID, LOG_ID)
GO
