create table B_SONET_GROUP_SUBJECT
(
  ID int not null,
  SITE_ID char(2 CHAR) not null,
  NAME varchar2(255 CHAR) not null,
  SORT int default '100' not null,
  primary key (ID)
)
/
CREATE SEQUENCE SQ_B_SONET_GROUP_SUBJECT INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE B_SONET_GROUP_SUBJECT_SITE
(
	SUBJECT_ID NUMBER(18) NOT NULL,
	SITE_ID CHAR(2 CHAR) NOT NULL,
	CONSTRAINT PK_B_SONET_GROUP_SUBJECT_SITE PRIMARY KEY (SUBJECT_ID, SITE_ID)
)
/

create table B_SONET_GROUP
(
  ID int not null,
  SITE_ID char(2 CHAR) not null,
  NAME varchar2(255 CHAR) not null,
  DESCRIPTION clob null,
  DATE_CREATE date not null,
  DATE_UPDATE date not null,
  ACTIVE char(1 CHAR) default 'Y' not null,
  VISIBLE char(1 CHAR) default 'Y' not null,
  OPENED char(1 CHAR) default 'N' not null,
  SUBJECT_ID int not null,
  OWNER_ID int not null,
  KEYWORDS varchar2(255 CHAR) null,
  IMAGE_ID int null,
  NUMBER_OF_MEMBERS int default 0 not null,
  NUMBER_OF_MODERATORS int default 0 not null,
  INITIATE_PERMS char(1 CHAR) default 'K' not null,
  DATE_ACTIVITY date not null,
  CLOSED char(1 CHAR) default 'N' not null,
  SPAM_PERMS char(1 CHAR) default 'K' not null,
  primary key (ID)
)
/
CREATE INDEX IX_B_SONET_GROUP_1 ON B_SONET_GROUP(OWNER_ID)
/
CREATE SEQUENCE SQ_B_SONET_GROUP INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE B_SONET_GROUP_SITE
(
	GROUP_ID NUMBER(18) NOT NULL,
	SITE_ID CHAR(2 CHAR) NOT NULL,
	CONSTRAINT PK_B_SONET_GROUP_SITE PRIMARY KEY (GROUP_ID, SITE_ID)
)
/

create table B_SONET_USER2GROUP
(
  ID int not null,
  USER_ID int not null,
  GROUP_ID int not null,
  ROLE char(1 CHAR) default 'U' not null,
  DATE_CREATE date not null,
  DATE_UPDATE date not null,
  INITIATED_BY_TYPE char(1 CHAR) default 'U' not null,
  INITIATED_BY_USER_ID int not null,
  MESSAGE clob null,
  primary key (ID)
)
/
CREATE UNIQUE INDEX IX_B_SONET_USER2GROUP_1 ON B_SONET_USER2GROUP(USER_ID, GROUP_ID)
/
CREATE INDEX IX_B_SONET_USER2GROUP_2 ON B_SONET_USER2GROUP(USER_ID, GROUP_ID, ROLE)
/
CREATE INDEX IX_B_SONET_USER2GROUP_3 ON B_SONET_USER2GROUP(GROUP_ID, USER_ID, ROLE)
/
CREATE SEQUENCE SQ_B_SONET_USER2GROUP INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_FEATURES
(
  ID int not null,
  ENTITY_TYPE char(1 CHAR) default 'G' not null,
  ENTITY_ID int not null,
  FEATURE varchar2(50 CHAR) not null,
  FEATURE_NAME varchar2(250 CHAR) null,
  ACTIVE char(1 CHAR) default 'Y' not null,
  DATE_CREATE date not null,
  DATE_UPDATE date not null,
  primary key (ID)
)
/
CREATE UNIQUE INDEX IX_SONET_GROUP_FEATURES_1 ON B_SONET_FEATURES(ENTITY_TYPE, ENTITY_ID, FEATURE)
/
CREATE SEQUENCE SQ_B_SONET_FEATURES INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_FEATURES2PERMS
(
  ID int not null,
  FEATURE_ID int not null,
  OPERATION_ID varchar2(50 CHAR) not null,
  ROLE char(1 CHAR) not null,
  primary key (ID)
)
/
CREATE UNIQUE INDEX IX_SONET_FE2PERMS_1 ON B_SONET_FEATURES2PERMS(FEATURE_ID, OPERATION_ID)
/
CREATE INDEX IX_SONET_FE2PERMS_2 ON B_SONET_FEATURES2PERMS(FEATURE_ID, ROLE, OPERATION_ID)
/
CREATE SEQUENCE SQ_B_SONET_FEATURES2PERMS INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_USER_RELATIONS
(
  ID int not null,
  FIRST_USER_ID int not null,
  SECOND_USER_ID int not null,
  RELATION char(1 CHAR) default 'N' not null,
  DATE_CREATE date not null,
  DATE_UPDATE date not null,
  MESSAGE clob null,
  INITIATED_BY char(1 CHAR) default 'F' not null,
  primary key (ID)
)
/
CREATE UNIQUE INDEX IX_SONET_RELATIONS_1 ON B_SONET_USER_RELATIONS(FIRST_USER_ID, SECOND_USER_ID)
/
CREATE INDEX IX_SONET_RELATIONS_2 ON B_SONET_USER_RELATIONS(FIRST_USER_ID, SECOND_USER_ID, RELATION)
/
CREATE SEQUENCE SQ_B_SONET_USER_RELATIONS INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_MESSAGES
(
  ID int not null,
  FROM_USER_ID int not null,
  TO_USER_ID int not null,
  TITLE varchar2(250 CHAR) null,
  MESSAGE clob null,
  DATE_CREATE date not null,
  DATE_VIEW date null,
  MESSAGE_TYPE char(1 CHAR) default 'P' not null,
  FROM_DELETED char(1 CHAR) default 'N' not null,
  TO_DELETED char(1 CHAR) default 'N' not null,
  SEND_MAIL char(1 CHAR) default 'N' not null,
  EMAIL_TEMPLATE varchar2(250 CHAR) null,
  IS_LOG char(1 CHAR) null,
  primary key (ID)
)
/
CREATE INDEX IX_SONET_MESSAGES_1 ON B_SONET_MESSAGES(FROM_USER_ID)
/
CREATE INDEX IX_SONET_MESSAGES_2 ON B_SONET_MESSAGES(TO_USER_ID)
/
CREATE SEQUENCE SQ_B_SONET_MESSAGES INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_SMILE
(
   ID int not null,
   SMILE_TYPE char(1 CHAR) default 'S' not null,
   TYPING varchar2(100 CHAR) null,
   IMAGE varchar2(128 CHAR) not null,
   DESCRIPTION varchar2(50 CHAR),
   CLICKABLE char(1 CHAR) default 'Y' not null,
   SORT int default '150' not null,
   IMAGE_WIDTH int default '0' not null,
   IMAGE_HEIGHT int default '0' not null,
   primary key (ID)
)
/
CREATE SEQUENCE SQ_B_SONET_SMILE INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE OR REPLACE TRIGGER B_SONET_SMILE_INSERT
BEFORE INSERT
ON B_SONET_SMILE
FOR EACH ROW
BEGIN
	IF :NEW.ID IS NULL THEN
 		SELECT SQ_B_SONET_SMILE.NEXTVAL INTO :NEW.ID FROM dual;
	END IF;
END;
/

create table B_SONET_SMILE_LANG
(
   ID int not null,
   SMILE_ID int default '0' not null,
   LID char(2 CHAR) not null,
   NAME varchar2(255 CHAR) not null,
   primary key (ID)
)
/
CREATE UNIQUE INDEX IX_SONET_SMILE_K ON B_SONET_SMILE_LANG(SMILE_ID, LID)
/
CREATE SEQUENCE SQ_B_SONET_SMILE_LANG INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE OR REPLACE TRIGGER B_SONET_SMILE_LANG_INSERT
BEFORE INSERT
ON B_SONET_SMILE_LANG
FOR EACH ROW
BEGIN
	IF :NEW.ID IS NULL THEN
 		SELECT SQ_B_SONET_SMILE_LANG.NEXTVAL INTO :NEW.ID FROM dual;
	END IF;
END;
/

create table B_SONET_USER_PERMS
(
  ID int not null,
  USER_ID int not null,
  OPERATION_ID varchar2(50 CHAR) not null,
  RELATION_TYPE char(1 CHAR) not null,
  primary key (ID)
)
/
CREATE INDEX IX_SONET_USER_PERMS_1 ON B_SONET_USER_PERMS(USER_ID)
/
CREATE UNIQUE INDEX IX_SONET_USER_PERMS_2 ON B_SONET_USER_PERMS(USER_ID, OPERATION_ID)
/
CREATE SEQUENCE SQ_B_SONET_USER_PERMS INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_USER_EVENTS
(
  ID int not null,
  USER_ID int not null,
  EVENT_ID varchar2(50 CHAR) not null,
  ACTIVE char(1 CHAR) default 'Y' not null,
  SITE_ID char(2 CHAR) not null,
  primary key (ID)
)
/
CREATE INDEX IX_SONET_USER_EVENTS_1 ON B_SONET_USER_EVENTS(USER_ID)
/
CREATE UNIQUE INDEX IX_SONET_USER_EVENTS_2 ON B_SONET_USER_EVENTS(USER_ID, EVENT_ID)
/
CREATE SEQUENCE SQ_B_SONET_USER_EVENTS INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_LOG
(
  ID int not null,
  ENTITY_TYPE varchar2(50 CHAR) default 'G' not null,
  ENTITY_ID int not null,
  EVENT_ID varchar2(50 CHAR) not null,
  USER_ID int null,
  LOG_DATE date not null,
  TITLE_TEMPLATE varchar2(250 CHAR) null,
  TITLE varchar2(250 CHAR) not null,
  SITE_ID char(2 char) null,
  MESSAGE clob null,
  TEXT_MESSAGE clob null,
  URL varchar2(500 CHAR) null,
  MODULE_ID varchar2(50 CHAR) null,
  CALLBACK_FUNC varchar2(250 CHAR) null,
  EXTERNAL_ID varchar2(250 CHAR) null,
  PARAMS clob null,
  TMP_ID int null,
  SOURCE_ID int null,
  LOG_UPDATE date default sysdate not null,
  COMMENTS_COUNT int null,
  ENABLE_COMMENTS char(1 char) default 'Y',
  RATING_TYPE_ID VARCHAR2(50 CHAR) null,
  RATING_ENTITY_ID number(11) null,
  SOURCE_TYPE VARCHAR2(50 CHAR) null,
  primary key (ID)
)
/
CREATE INDEX IX_SONET_LOG_1 ON B_SONET_LOG(ENTITY_TYPE, ENTITY_ID, LOG_DATE)
/
CREATE INDEX IX_SONET_LOG_2 ON B_SONET_LOG(USER_ID, LOG_DATE, EVENT_ID)
/
CREATE INDEX IX_SONET_LOG_3 ON B_SONET_LOG(SOURCE_ID)
/
CREATE SEQUENCE SQ_B_SONET_LOG INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE B_SONET_LOG_SITE
(
	LOG_ID NUMBER(18) NOT NULL,
	SITE_ID CHAR(2 CHAR) NOT NULL,
	CONSTRAINT PK_B_SONET_LOG_SITE PRIMARY KEY (LOG_ID, SITE_ID)
)
/

CREATE TABLE B_SONET_LOG_COMMENT
(
	ID int not null,
	LOG_ID int not null,
	ENTITY_TYPE varchar2(50 CHAR) default 'G' not null,
	ENTITY_ID int not null,
	EVENT_ID varchar2(50 char) not null,
	USER_ID int null,
	LOG_DATE date not null,
	MESSAGE clob null,
	TEXT_MESSAGE clob null,
	MODULE_ID varchar2(50 char) null,
	SOURCE_ID int null,
	URL varchar2(500 char) null,
	RATING_TYPE_ID VARCHAR2(50 CHAR) null,
	RATING_ENTITY_ID number(11) null,
	primary key (ID)
)
/
CREATE INDEX IX_SONET_LOG_COMMENT_1 ON B_SONET_LOG_COMMENT(ENTITY_TYPE, ENTITY_ID, EVENT_ID)
/
CREATE INDEX IX_SONET_LOG_COMMENT_2 ON B_SONET_LOG_COMMENT(USER_ID, LOG_DATE, EVENT_ID)
/
CREATE SEQUENCE SQ_B_SONET_LOG_COMMENT INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

create table B_SONET_LOG_EVENTS
(
  ID int not null,
  USER_ID int not null,
  ENTITY_TYPE varchar2(50 CHAR) default 'G' not null,
  ENTITY_ID int not null,
  ENTITY_CB char(1 CHAR) default 'N' not null,
  ENTITY_MY char(1 CHAR) default 'N' not null,
  EVENT_ID varchar2(50 CHAR) not null,
  SITE_ID char(2 CHAR) null,
  MAIL_EVENT char(1 CHAR) default 'N' not null,
  TRANSPORT char(1 CHAR) default 'N' not null,
  VISIBLE char(1 CHAR) default 'Y' not null,
  primary key (ID)
)
/
CREATE INDEX IX_SONET_LOG_EVENTS_1 ON B_SONET_LOG_EVENTS(USER_ID)
/
CREATE INDEX IX_SONET_LOG_EVENTS_2 ON B_SONET_LOG_EVENTS(ENTITY_TYPE, ENTITY_ID, EVENT_ID)
/
CREATE UNIQUE INDEX IX_SONET_LOG_EVENTS_3 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_TYPE, ENTITY_ID, ENTITY_CB, ENTITY_MY, EVENT_ID, SITE_ID)
/
CREATE INDEX IX_SONET_LOG_EVENTS_4 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_CB, ENTITY_ID)
/
CREATE INDEX IX_SONET_LOG_EVENTS_5 ON B_SONET_LOG_EVENTS(USER_ID, ENTITY_MY, ENTITY_TYPE, ENTITY_ID)
/
CREATE SEQUENCE SQ_B_SONET_LOG_EVENTS INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE b_sonet_event_user_view
(
	ENTITY_TYPE varchar2(50 CHAR) DEFAULT ('G') NOT NULL,
	ENTITY_ID NUMBER(18) NOT NULL,
	EVENT_ID VARCHAR2(50 CHAR) NOT NULL,
	USER_ID NUMBER(18) DEFAULT ('0') NOT NULL,
	USER_IM_ID NUMBER(18) DEFAULT ('0') NOT NULL,
	USER_ANONYMOUS char(1 CHAR) DEFAULT ('N') NOT NULL,
	constraint pk_b_sonet_event_user_view PRIMARY KEY (ENTITY_TYPE,ENTITY_ID,EVENT_ID,USER_ID,USER_IM_ID)
)
/
CREATE INDEX IX_SONET_EVENT_USER_VIEW_1 ON B_SONET_EVENT_USER_VIEW(USER_ID, EVENT_ID, ENTITY_TYPE, USER_ANONYMOUS)
/

CREATE TABLE B_SONET_LOG_RIGHT
(
	ID int not null,
	LOG_ID int not null,
	GROUP_CODE varchar2(50 CHAR) not null,
	primary key (ID)
)
/
CREATE INDEX IX_SONET_LOG_RIGHT_GROUP_CODE ON B_SONET_LOG_RIGHT(LOG_ID, GROUP_CODE)
/
CREATE SEQUENCE SQ_B_SONET_LOG_RIGHT INCREMENT BY 1 NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE B_SONET_LOG_COUNTER
(
	USER_ID int not null,
	SITE_ID char(2 CHAR) default ('**') not null,
	CODE varchar2(50 CHAR) default ('**') not null,
	CNT int default ('0') not null,
	LAST_DATE date,
	PAGE_SIZE int null,	
	PAGE_LAST_DATE_1 date null,	
	CONSTRAINT PK_B_SONET_LOG_COUNTER PRIMARY KEY (USER_ID, SITE_ID, CODE)
)
/

CREATE TABLE b_sonet_log_page
(
	USER_ID NUMBER(18) NOT NULL,
	SITE_ID char(2 CHAR) default ('**') NOT NULL,
	PAGE_SIZE NUMBER(18) NOT NULL,
	PAGE_NUM NUMBER(18) default (1) NOT NULL,
	PAGE_LAST_DATE date,
	CONSTRAINT pk_b_sonet_log_page PRIMARY KEY (USER_ID, SITE_ID, PAGE_SIZE, PAGE_NUM)
)
/

CREATE TABLE b_sonet_log_follow
(
	USER_ID NUMBER(18) NOT NULL,
	CODE varchar2(50 CHAR) default ('**') not null,
	TYPE CHAR(1 CHAR) default ('Y') not null,
	FOLLOW_DATE date,
	CONSTRAINT pk_b_sonet_log_follow PRIMARY KEY (USER_ID, CODE)
)
/

CREATE TABLE b_sonet_log_smartfilter
(
	USER_ID NUMBER(18) NOT NULL,
	TYPE CHAR(1 CHAR) default ('N') not null,
	CONSTRAINT pk_b_sonet_log_smartfilter PRIMARY KEY (USER_ID)
)
/

CREATE TABLE B_SONET_LOG_FAVORITES
(
	USER_ID int not null,
	LOG_ID int not null,
	CONSTRAINT PK_B_SONET_LOG_FAVORITES PRIMARY KEY (USER_ID, LOG_ID)
)
/