CREATE TABLE B_STAT_ADV_SEARCHER
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NOT NULL,
	SEARCHER_ID int NOT NULL
)
GO
ALTER TABLE B_STAT_ADV_SEARCHER ADD CONSTRAINT PK_B_STAT_ADV_SEARCHER PRIMARY KEY (ID)
GO


CREATE TABLE B_STAT_ADV
(
	ID int NOT NULL IDENTITY (1, 1),
	REFERER1 varchar(255) NULL,
	REFERER2 varchar(255) NULL,
	COST decimal(18,4) NOT NULL,
	REVENUE decimal(18,4) NOT NULL,
	EVENTS_VIEW varchar(255),
	GUESTS int NOT NULL,
	NEW_GUESTS int NOT NULL,
	FAVORITES int NOT NULL,
	C_HOSTS int NOT NULL,
	SESSIONS int NOT NULL,
	HITS int NOT NULL,
	DATE_FIRST datetime,
	DATE_LAST datetime,
	GUESTS_BACK int NOT NULL,
	FAVORITES_BACK int NOT NULL,
	HOSTS_BACK int NOT NULL,
	SESSIONS_BACK int NOT NULL,
	HITS_BACK int NOT NULL,
	DESCRIPTION varchar(8000),
	PRIORITY int NOT NULL
)
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT PK_B_STAT_ADV PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_COST DEFAULT '0.0000' FOR COST
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_REVENUE DEFAULT '0.0000' FOR REVENUE
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_GUESTS DEFAULT '0' FOR GUESTS
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_FAVORITES DEFAULT '0' FOR FAVORITES
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_C_HOSTS DEFAULT '0' FOR C_HOSTS
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_GUESTS_BACK DEFAULT '0' FOR GUESTS_BACK
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_FAVORITES_BACK DEFAULT '0' FOR FAVORITES_BACK
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_HOSTS_BACK DEFAULT '0' FOR HOSTS_BACK
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_SESSIONS_BACK DEFAULT '0' FOR SESSIONS_BACK
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_HITS_BACK DEFAULT '0' FOR HITS_BACK
GO
ALTER TABLE B_STAT_ADV ADD CONSTRAINT DF_B_STAT_ADV_PRIORITY DEFAULT '100' FOR PRIORITY
GO
CREATE INDEX IX_B_STAT_ADV_1 ON B_STAT_ADV(REFERER1)
GO


CREATE TABLE B_STAT_ADV_EVENT
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NULL,
	EVENT_ID int NULL,
	COUNTER int NOT NULL,
	COUNTER_BACK int NOT NULL,
	MONEY decimal(18,4) NOT NULL,
	MONEY_BACK decimal(18,4) NOT NULL
)
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT PK_B_STAT_ADV_EVENT PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_EVENT_ID DEFAULT '0' FOR EVENT_ID
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_COUNTER_BACK DEFAULT '0' FOR COUNTER_BACK
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_MONEY DEFAULT '0.0000' FOR MONEY
GO
ALTER TABLE B_STAT_ADV_EVENT ADD CONSTRAINT DF_B_STAT_ADV_EVENT_MONEY_BACK DEFAULT '0.0000' FOR MONEY_BACK
GO
CREATE INDEX IX_B_STAT_ADV_EVENT_1 ON B_STAT_ADV_EVENT (ADV_ID, EVENT_ID)
GO


CREATE TABLE B_STAT_ADV_GUEST
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NOT NULL,
	BACK char(1) NOT NULL,
	GUEST_ID int NOT NULL,
	DATE_GUEST_HIT datetime NULL,
	DATE_HOST_HIT datetime NULL,
	SESSION_ID int NOT NULL,
	IP varchar(15) NULL,
	IP_NUMBER bigint NULL
)
GO
ALTER TABLE B_STAT_ADV_GUEST ADD CONSTRAINT PK_B_STAT_ADV_GUEST PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV_GUEST ADD CONSTRAINT DF_B_STAT_ADV_GUEST_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_ADV_GUEST ADD CONSTRAINT DF_B_STAT_ADV_GUEST_BACK DEFAULT 'N' FOR BACK
GO
ALTER TABLE B_STAT_ADV_GUEST ADD CONSTRAINT DF_B_STAT_ADV_GUEST_GUEST_ID DEFAULT '0' FOR GUEST_ID
GO
ALTER TABLE B_STAT_ADV_GUEST ADD CONSTRAINT DF_B_STAT_ADV_GUEST_SESSION_ID DEFAULT '0' FOR SESSION_ID
GO
CREATE INDEX IX_B_STAT_ADV_GUEST_1 ON B_STAT_ADV_GUEST (ADV_ID, GUEST_ID)
GO
CREATE INDEX IX_B_STAT_ADV_GUEST_2 ON B_STAT_ADV_GUEST (ADV_ID, IP_NUMBER)
GO


CREATE TABLE B_STAT_ADV_PAGE
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NOT NULL,
	PAGE varchar(255) NOT NULL,
	C_TYPE varchar(5) NOT NULL
)
GO
ALTER TABLE B_STAT_ADV_PAGE ADD CONSTRAINT PK_B_STAT_ADV_PAGE PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV_PAGE ADD CONSTRAINT DF_B_STAT_ADV_PAGE_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_ADV_PAGE ADD CONSTRAINT DF_B_STAT_ADV_PAGE_C_TYPE DEFAULT 'TO' FOR C_TYPE
GO
CREATE INDEX IX_B_STAT_ADV_PAGE_1 ON B_STAT_ADV_PAGE (ADV_ID, C_TYPE)
GO


CREATE TABLE B_STAT_DAY
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_STAT datetime NOT NULL,
	HITS int NOT NULL,
	C_HOSTS int NOT NULL,
	SESSIONS int NOT NULL,
	C_EVENTS int NOT NULL,
	GUESTS int NOT NULL,
	NEW_GUESTS int NOT NULL,
	FAVORITES int NOT NULL,
	TOTAL_HOSTS int NOT NULL,
	AM_AVERAGE_TIME decimal(18,2) NOT NULL,
	AM_1 int NOT NULL,
	AM_1_3 int NOT NULL,
	AM_3_6 int NOT NULL,
	AM_6_9 int NOT NULL,
	AM_9_12 int NOT NULL,
	AM_12_15 int NOT NULL,
	AM_15_18 int NOT NULL,
	AM_18_21 int NOT NULL,
	AM_21_24 int NOT NULL,
	AM_24 int NOT NULL,
	AH_AVERAGE_HITS decimal(18,2) NOT NULL,
	AH_1 int NOT NULL,
	AH_2_5 int NOT NULL,
	AH_6_9 int NOT NULL,
	AH_10_13 int NOT NULL,
	AH_14_17 int NOT NULL,
	AH_18_21 int NOT NULL,
	AH_22_25 int NOT NULL,
	AH_26_29 int NOT NULL,
	AH_30_33 int NOT NULL,
	AH_34 int NOT NULL,
	HOUR_HOST_0 int NOT NULL,
	HOUR_HOST_1 int NOT NULL,
	HOUR_HOST_2 int NOT NULL,
	HOUR_HOST_3 int NOT NULL,
	HOUR_HOST_4 int NOT NULL,
	HOUR_HOST_5 int NOT NULL,
	HOUR_HOST_6 int NOT NULL,
	HOUR_HOST_7 int NOT NULL,
	HOUR_HOST_8 int NOT NULL,
	HOUR_HOST_9 int NOT NULL,
	HOUR_HOST_10 int NOT NULL,
	HOUR_HOST_11 int NOT NULL,
	HOUR_HOST_12 int NOT NULL,
	HOUR_HOST_13 int NOT NULL,
	HOUR_HOST_14 int NOT NULL,
	HOUR_HOST_15 int NOT NULL,
	HOUR_HOST_16 int NOT NULL,
	HOUR_HOST_17 int NOT NULL,
	HOUR_HOST_18 int NOT NULL,
	HOUR_HOST_19 int NOT NULL,
	HOUR_HOST_20 int NOT NULL,
	HOUR_HOST_21 int NOT NULL,
	HOUR_HOST_22 int NOT NULL,
	HOUR_HOST_23 int NOT NULL,
	HOUR_GUEST_0 int NOT NULL,
	HOUR_GUEST_1 int NOT NULL,
	HOUR_GUEST_2 int NOT NULL,
	HOUR_GUEST_3 int NOT NULL,
	HOUR_GUEST_4 int NOT NULL,
	HOUR_GUEST_5 int NOT NULL,
	HOUR_GUEST_6 int NOT NULL,
	HOUR_GUEST_7 int NOT NULL,
	HOUR_GUEST_8 int NOT NULL,
	HOUR_GUEST_9 int NOT NULL,
	HOUR_GUEST_10 int NOT NULL,
	HOUR_GUEST_11 int NOT NULL,
	HOUR_GUEST_12 int NOT NULL,
	HOUR_GUEST_13 int NOT NULL,
	HOUR_GUEST_14 int NOT NULL,
	HOUR_GUEST_15 int NOT NULL,
	HOUR_GUEST_16 int NOT NULL,
	HOUR_GUEST_17 int NOT NULL,
	HOUR_GUEST_18 int NOT NULL,
	HOUR_GUEST_19 int NOT NULL,
	HOUR_GUEST_20 int NOT NULL,
	HOUR_GUEST_21 int NOT NULL,
	HOUR_GUEST_22 int NOT NULL,
	HOUR_GUEST_23 int NOT NULL,
	HOUR_NEW_GUEST_0 int NOT NULL,
	HOUR_NEW_GUEST_1 int NOT NULL,
	HOUR_NEW_GUEST_2 int NOT NULL,
	HOUR_NEW_GUEST_3 int NOT NULL,
	HOUR_NEW_GUEST_4 int NOT NULL,
	HOUR_NEW_GUEST_5 int NOT NULL,
	HOUR_NEW_GUEST_6 int NOT NULL,
	HOUR_NEW_GUEST_7 int NOT NULL,
	HOUR_NEW_GUEST_8 int NOT NULL,
	HOUR_NEW_GUEST_9 int NOT NULL,
	HOUR_NEW_GUEST_10 int NOT NULL,
	HOUR_NEW_GUEST_11 int NOT NULL,
	HOUR_NEW_GUEST_12 int NOT NULL,
	HOUR_NEW_GUEST_13 int NOT NULL,
	HOUR_NEW_GUEST_14 int NOT NULL,
	HOUR_NEW_GUEST_15 int NOT NULL,
	HOUR_NEW_GUEST_16 int NOT NULL,
	HOUR_NEW_GUEST_17 int NOT NULL,
	HOUR_NEW_GUEST_18 int NOT NULL,
	HOUR_NEW_GUEST_19 int NOT NULL,
	HOUR_NEW_GUEST_20 int NOT NULL,
	HOUR_NEW_GUEST_21 int NOT NULL,
	HOUR_NEW_GUEST_22 int NOT NULL,
	HOUR_NEW_GUEST_23 int NOT NULL,
	HOUR_SESSION_0 int NOT NULL,
	HOUR_SESSION_1 int NOT NULL,
	HOUR_SESSION_2 int NOT NULL,
	HOUR_SESSION_3 int NOT NULL,
	HOUR_SESSION_4 int NOT NULL,
	HOUR_SESSION_5 int NOT NULL,
	HOUR_SESSION_6 int NOT NULL,
	HOUR_SESSION_7 int NOT NULL,
	HOUR_SESSION_8 int NOT NULL,
	HOUR_SESSION_9 int NOT NULL,
	HOUR_SESSION_10 int NOT NULL,
	HOUR_SESSION_11 int NOT NULL,
	HOUR_SESSION_12 int NOT NULL,
	HOUR_SESSION_13 int NOT NULL,
	HOUR_SESSION_14 int NOT NULL,
	HOUR_SESSION_15 int NOT NULL,
	HOUR_SESSION_16 int NOT NULL,
	HOUR_SESSION_17 int NOT NULL,
	HOUR_SESSION_18 int NOT NULL,
	HOUR_SESSION_19 int NOT NULL,
	HOUR_SESSION_20 int NOT NULL,
	HOUR_SESSION_21 int NOT NULL,
	HOUR_SESSION_22 int NOT NULL,
	HOUR_SESSION_23 int NOT NULL,
	HOUR_HIT_0 int NOT NULL,
	HOUR_HIT_1 int NOT NULL,
	HOUR_HIT_2 int NOT NULL,
	HOUR_HIT_3 int NOT NULL,
	HOUR_HIT_4 int NOT NULL,
	HOUR_HIT_5 int NOT NULL,
	HOUR_HIT_6 int NOT NULL,
	HOUR_HIT_7 int NOT NULL,
	HOUR_HIT_8 int NOT NULL,
	HOUR_HIT_9 int NOT NULL,
	HOUR_HIT_10 int NOT NULL,
	HOUR_HIT_11 int NOT NULL,
	HOUR_HIT_12 int NOT NULL,
	HOUR_HIT_13 int NOT NULL,
	HOUR_HIT_14 int NOT NULL,
	HOUR_HIT_15 int NOT NULL,
	HOUR_HIT_16 int NOT NULL,
	HOUR_HIT_17 int NOT NULL,
	HOUR_HIT_18 int NOT NULL,
	HOUR_HIT_19 int NOT NULL,
	HOUR_HIT_20 int NOT NULL,
	HOUR_HIT_21 int NOT NULL,
	HOUR_HIT_22 int NOT NULL,
	HOUR_HIT_23 int NOT NULL,
	HOUR_EVENT_0 int NOT NULL,
	HOUR_EVENT_1 int NOT NULL,
	HOUR_EVENT_2 int NOT NULL,
	HOUR_EVENT_3 int NOT NULL,
	HOUR_EVENT_4 int NOT NULL,
	HOUR_EVENT_5 int NOT NULL,
	HOUR_EVENT_6 int NOT NULL,
	HOUR_EVENT_7 int NOT NULL,
	HOUR_EVENT_8 int NOT NULL,
	HOUR_EVENT_9 int NOT NULL,
	HOUR_EVENT_10 int NOT NULL,
	HOUR_EVENT_11 int NOT NULL,
	HOUR_EVENT_12 int NOT NULL,
	HOUR_EVENT_13 int NOT NULL,
	HOUR_EVENT_14 int NOT NULL,
	HOUR_EVENT_15 int NOT NULL,
	HOUR_EVENT_16 int NOT NULL,
	HOUR_EVENT_17 int NOT NULL,
	HOUR_EVENT_18 int NOT NULL,
	HOUR_EVENT_19 int NOT NULL,
	HOUR_EVENT_20 int NOT NULL,
	HOUR_EVENT_21 int NOT NULL,
	HOUR_EVENT_22 int NOT NULL,
	HOUR_EVENT_23 int NOT NULL,
	HOUR_FAVORITE_0 int NOT NULL,
	HOUR_FAVORITE_1 int NOT NULL,
	HOUR_FAVORITE_2 int NOT NULL,
	HOUR_FAVORITE_3 int NOT NULL,
	HOUR_FAVORITE_4 int NOT NULL,
	HOUR_FAVORITE_5 int NOT NULL,
	HOUR_FAVORITE_6 int NOT NULL,
	HOUR_FAVORITE_7 int NOT NULL,
	HOUR_FAVORITE_8 int NOT NULL,
	HOUR_FAVORITE_9 int NOT NULL,
	HOUR_FAVORITE_10 int NOT NULL,
	HOUR_FAVORITE_11 int NOT NULL,
	HOUR_FAVORITE_12 int NOT NULL,
	HOUR_FAVORITE_13 int NOT NULL,
	HOUR_FAVORITE_14 int NOT NULL,
	HOUR_FAVORITE_15 int NOT NULL,
	HOUR_FAVORITE_16 int NOT NULL,
	HOUR_FAVORITE_17 int NOT NULL,
	HOUR_FAVORITE_18 int NOT NULL,
	HOUR_FAVORITE_19 int NOT NULL,
	HOUR_FAVORITE_20 int NOT NULL,
	HOUR_FAVORITE_21 int NOT NULL,
	HOUR_FAVORITE_22 int NOT NULL,
	HOUR_FAVORITE_23 int NOT NULL,
	WEEKDAY_HOST_0 int NOT NULL,
	WEEKDAY_HOST_1 int NOT NULL,
	WEEKDAY_HOST_2 int NOT NULL,
	WEEKDAY_HOST_3 int NOT NULL,
	WEEKDAY_HOST_4 int NOT NULL,
	WEEKDAY_HOST_5 int NOT NULL,
	WEEKDAY_HOST_6 int NOT NULL,
	WEEKDAY_GUEST_0 int NOT NULL,
	WEEKDAY_GUEST_1 int NOT NULL,
	WEEKDAY_GUEST_2 int NOT NULL,
	WEEKDAY_GUEST_3 int NOT NULL,
	WEEKDAY_GUEST_4 int NOT NULL,
	WEEKDAY_GUEST_5 int NOT NULL,
	WEEKDAY_GUEST_6 int NOT NULL,
	WEEKDAY_NEW_GUEST_0 int NOT NULL,
	WEEKDAY_NEW_GUEST_1 int NOT NULL,
	WEEKDAY_NEW_GUEST_2 int NOT NULL,
	WEEKDAY_NEW_GUEST_3 int NOT NULL,
	WEEKDAY_NEW_GUEST_4 int NOT NULL,
	WEEKDAY_NEW_GUEST_5 int NOT NULL,
	WEEKDAY_NEW_GUEST_6 int NOT NULL,
	WEEKDAY_SESSION_0 int NOT NULL,
	WEEKDAY_SESSION_1 int NOT NULL,
	WEEKDAY_SESSION_2 int NOT NULL,
	WEEKDAY_SESSION_3 int NOT NULL,
	WEEKDAY_SESSION_4 int NOT NULL,
	WEEKDAY_SESSION_5 int NOT NULL,
	WEEKDAY_SESSION_6 int NOT NULL,
	WEEKDAY_HIT_0 int NOT NULL,
	WEEKDAY_HIT_1 int NOT NULL,
	WEEKDAY_HIT_2 int NOT NULL,
	WEEKDAY_HIT_3 int NOT NULL,
	WEEKDAY_HIT_4 int NOT NULL,
	WEEKDAY_HIT_5 int NOT NULL,
	WEEKDAY_HIT_6 int NOT NULL,
	WEEKDAY_EVENT_0 int NOT NULL,
	WEEKDAY_EVENT_1 int NOT NULL,
	WEEKDAY_EVENT_2 int NOT NULL,
	WEEKDAY_EVENT_3 int NOT NULL,
	WEEKDAY_EVENT_4 int NOT NULL,
	WEEKDAY_EVENT_5 int NOT NULL,
	WEEKDAY_EVENT_6 int NOT NULL,
	WEEKDAY_FAVORITE_0 int NOT NULL,
	WEEKDAY_FAVORITE_1 int NOT NULL,
	WEEKDAY_FAVORITE_2 int NOT NULL,
	WEEKDAY_FAVORITE_3 int NOT NULL,
	WEEKDAY_FAVORITE_4 int NOT NULL,
	WEEKDAY_FAVORITE_5 int NOT NULL,
	WEEKDAY_FAVORITE_6 int NOT NULL,
	MONTH_HOST_1 int NOT NULL,
	MONTH_HOST_2 int NOT NULL,
	MONTH_HOST_3 int NOT NULL,
	MONTH_HOST_4 int NOT NULL,
	MONTH_HOST_5 int NOT NULL,
	MONTH_HOST_6 int NOT NULL,
	MONTH_HOST_7 int NOT NULL,
	MONTH_HOST_8 int NOT NULL,
	MONTH_HOST_9 int NOT NULL,
	MONTH_HOST_10 int NOT NULL,
	MONTH_HOST_11 int NOT NULL,
	MONTH_HOST_12 int NOT NULL,
	MONTH_GUEST_1 int NOT NULL,
	MONTH_GUEST_2 int NOT NULL,
	MONTH_GUEST_3 int NOT NULL,
	MONTH_GUEST_4 int NOT NULL,
	MONTH_GUEST_5 int NOT NULL,
	MONTH_GUEST_6 int NOT NULL,
	MONTH_GUEST_7 int NOT NULL,
	MONTH_GUEST_8 int NOT NULL,
	MONTH_GUEST_9 int NOT NULL,
	MONTH_GUEST_10 int NOT NULL,
	MONTH_GUEST_11 int NOT NULL,
	MONTH_GUEST_12 int NOT NULL,
	MONTH_NEW_GUEST_1 int NOT NULL,
	MONTH_NEW_GUEST_2 int NOT NULL,
	MONTH_NEW_GUEST_3 int NOT NULL,
	MONTH_NEW_GUEST_4 int NOT NULL,
	MONTH_NEW_GUEST_5 int NOT NULL,
	MONTH_NEW_GUEST_6 int NOT NULL,
	MONTH_NEW_GUEST_7 int NOT NULL,
	MONTH_NEW_GUEST_8 int NOT NULL,
	MONTH_NEW_GUEST_9 int NOT NULL,
	MONTH_NEW_GUEST_10 int NOT NULL,
	MONTH_NEW_GUEST_11 int NOT NULL,
	MONTH_NEW_GUEST_12 int NOT NULL,
	MONTH_SESSION_1 int NOT NULL,
	MONTH_SESSION_2 int NOT NULL,
	MONTH_SESSION_3 int NOT NULL,
	MONTH_SESSION_4 int NOT NULL,
	MONTH_SESSION_5 int NOT NULL,
	MONTH_SESSION_6 int NOT NULL,
	MONTH_SESSION_7 int NOT NULL,
	MONTH_SESSION_8 int NOT NULL,
	MONTH_SESSION_9 int NOT NULL,
	MONTH_SESSION_10 int NOT NULL,
	MONTH_SESSION_11 int NOT NULL,
	MONTH_SESSION_12 int NOT NULL,
	MONTH_HIT_1 int NOT NULL,
	MONTH_HIT_2 int NOT NULL,
	MONTH_HIT_3 int NOT NULL,
	MONTH_HIT_4 int NOT NULL,
	MONTH_HIT_5 int NOT NULL,
	MONTH_HIT_6 int NOT NULL,
	MONTH_HIT_7 int NOT NULL,
	MONTH_HIT_8 int NOT NULL,
	MONTH_HIT_9 int NOT NULL,
	MONTH_HIT_10 int NOT NULL,
	MONTH_HIT_11 int NOT NULL,
	MONTH_HIT_12 int NOT NULL,
	MONTH_EVENT_1 int NOT NULL,
	MONTH_EVENT_2 int NOT NULL,
	MONTH_EVENT_3 int NOT NULL,
	MONTH_EVENT_4 int NOT NULL,
	MONTH_EVENT_5 int NOT NULL,
	MONTH_EVENT_6 int NOT NULL,
	MONTH_EVENT_7 int NOT NULL,
	MONTH_EVENT_8 int NOT NULL,
	MONTH_EVENT_9 int NOT NULL,
	MONTH_EVENT_10 int NOT NULL,
	MONTH_EVENT_11 int NOT NULL,
	MONTH_EVENT_12 int NOT NULL,
	MONTH_FAVORITE_1 int NOT NULL,
	MONTH_FAVORITE_2 int NOT NULL,
	MONTH_FAVORITE_3 int NOT NULL,
	MONTH_FAVORITE_4 int NOT NULL,
	MONTH_FAVORITE_5 int NOT NULL,
	MONTH_FAVORITE_6 int NOT NULL,
	MONTH_FAVORITE_7 int NOT NULL,
	MONTH_FAVORITE_8 int NOT NULL,
	MONTH_FAVORITE_9 int NOT NULL,
	MONTH_FAVORITE_10 int NOT NULL,
	MONTH_FAVORITE_11 int NOT NULL,
	MONTH_FAVORITE_12 int NOT NULL
)
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT PK_B_STAT_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_C_HOSTS DEFAULT '0' FOR C_HOSTS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_GUESTS DEFAULT '0' FOR GUESTS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_FAVORITES DEFAULT '0' FOR FAVORITES
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_TOTAL_HOSTS DEFAULT '0' FOR TOTAL_HOSTS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_AVERAGE_TIME DEFAULT '0.00' FOR AM_AVERAGE_TIME
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_1 DEFAULT '0' FOR AM_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_1_3 DEFAULT '0' FOR AM_1_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_3_6 DEFAULT '0' FOR AM_3_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_6_9 DEFAULT '0' FOR AM_6_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_9_12 DEFAULT '0' FOR AM_9_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_12_15 DEFAULT '0' FOR AM_12_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_15_18 DEFAULT '0' FOR AM_15_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_18_21 DEFAULT '0' FOR AM_18_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_21_24 DEFAULT '0' FOR AM_21_24
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AM_24 DEFAULT '0' FOR AM_24
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_AVERAGE_HITS DEFAULT '0.00' FOR AH_AVERAGE_HITS
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_1 DEFAULT '0' FOR AH_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_2_5 DEFAULT '0' FOR AH_2_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_6_9 DEFAULT '0' FOR AH_6_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_10_13 DEFAULT '0' FOR AH_10_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_14_17 DEFAULT '0' FOR AH_14_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_18_21 DEFAULT '0' FOR AH_18_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_22_25 DEFAULT '0' FOR AH_22_25
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_26_29 DEFAULT '0' FOR AH_26_29
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_30_33 DEFAULT '0' FOR AH_30_33
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_AH_34 DEFAULT '0' FOR AH_34
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_0 DEFAULT '0' FOR HOUR_HOST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_1 DEFAULT '0' FOR HOUR_HOST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_2 DEFAULT '0' FOR HOUR_HOST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_3 DEFAULT '0' FOR HOUR_HOST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_4 DEFAULT '0' FOR HOUR_HOST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_5 DEFAULT '0' FOR HOUR_HOST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_6 DEFAULT '0' FOR HOUR_HOST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_7 DEFAULT '0' FOR HOUR_HOST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_8 DEFAULT '0' FOR HOUR_HOST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_9 DEFAULT '0' FOR HOUR_HOST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_10 DEFAULT '0' FOR HOUR_HOST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_11 DEFAULT '0' FOR HOUR_HOST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_12 DEFAULT '0' FOR HOUR_HOST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_13 DEFAULT '0' FOR HOUR_HOST_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_14 DEFAULT '0' FOR HOUR_HOST_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_15 DEFAULT '0' FOR HOUR_HOST_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_16 DEFAULT '0' FOR HOUR_HOST_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_17 DEFAULT '0' FOR HOUR_HOST_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_18 DEFAULT '0' FOR HOUR_HOST_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_19 DEFAULT '0' FOR HOUR_HOST_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_20 DEFAULT '0' FOR HOUR_HOST_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_21 DEFAULT '0' FOR HOUR_HOST_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_22 DEFAULT '0' FOR HOUR_HOST_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HOST_23 DEFAULT '0' FOR HOUR_HOST_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_0 DEFAULT '0' FOR HOUR_GUEST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_1 DEFAULT '0' FOR HOUR_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_2 DEFAULT '0' FOR HOUR_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_3 DEFAULT '0' FOR HOUR_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_4 DEFAULT '0' FOR HOUR_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_5 DEFAULT '0' FOR HOUR_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_6 DEFAULT '0' FOR HOUR_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_7 DEFAULT '0' FOR HOUR_GUEST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_8 DEFAULT '0' FOR HOUR_GUEST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_9 DEFAULT '0' FOR HOUR_GUEST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_10 DEFAULT '0' FOR HOUR_GUEST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_11 DEFAULT '0' FOR HOUR_GUEST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_12 DEFAULT '0' FOR HOUR_GUEST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_13 DEFAULT '0' FOR HOUR_GUEST_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_14 DEFAULT '0' FOR HOUR_GUEST_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_15 DEFAULT '0' FOR HOUR_GUEST_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_16 DEFAULT '0' FOR HOUR_GUEST_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_17 DEFAULT '0' FOR HOUR_GUEST_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_18 DEFAULT '0' FOR HOUR_GUEST_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_19 DEFAULT '0' FOR HOUR_GUEST_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_20 DEFAULT '0' FOR HOUR_GUEST_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_21 DEFAULT '0' FOR HOUR_GUEST_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_22 DEFAULT '0' FOR HOUR_GUEST_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_GUEST_23 DEFAULT '0' FOR HOUR_GUEST_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_0 DEFAULT '0' FOR HOUR_NEW_GUEST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_1 DEFAULT '0' FOR HOUR_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_2 DEFAULT '0' FOR HOUR_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_3 DEFAULT '0' FOR HOUR_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_4 DEFAULT '0' FOR HOUR_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_5 DEFAULT '0' FOR HOUR_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_6 DEFAULT '0' FOR HOUR_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_7 DEFAULT '0' FOR HOUR_NEW_GUEST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_8 DEFAULT '0' FOR HOUR_NEW_GUEST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_9 DEFAULT '0' FOR HOUR_NEW_GUEST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_10 DEFAULT '0' FOR HOUR_NEW_GUEST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_11 DEFAULT '0' FOR HOUR_NEW_GUEST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_12 DEFAULT '0' FOR HOUR_NEW_GUEST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_13 DEFAULT '0' FOR HOUR_NEW_GUEST_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_14 DEFAULT '0' FOR HOUR_NEW_GUEST_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_15 DEFAULT '0' FOR HOUR_NEW_GUEST_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_16 DEFAULT '0' FOR HOUR_NEW_GUEST_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_17 DEFAULT '0' FOR HOUR_NEW_GUEST_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_18 DEFAULT '0' FOR HOUR_NEW_GUEST_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_19 DEFAULT '0' FOR HOUR_NEW_GUEST_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_20 DEFAULT '0' FOR HOUR_NEW_GUEST_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_21 DEFAULT '0' FOR HOUR_NEW_GUEST_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_22 DEFAULT '0' FOR HOUR_NEW_GUEST_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_NEW_GUEST_23 DEFAULT '0' FOR HOUR_NEW_GUEST_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_0 DEFAULT '0' FOR HOUR_SESSION_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_1 DEFAULT '0' FOR HOUR_SESSION_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_2 DEFAULT '0' FOR HOUR_SESSION_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_3 DEFAULT '0' FOR HOUR_SESSION_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_4 DEFAULT '0' FOR HOUR_SESSION_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_5 DEFAULT '0' FOR HOUR_SESSION_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_6 DEFAULT '0' FOR HOUR_SESSION_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_7 DEFAULT '0' FOR HOUR_SESSION_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_8 DEFAULT '0' FOR HOUR_SESSION_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_9 DEFAULT '0' FOR HOUR_SESSION_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_10 DEFAULT '0' FOR HOUR_SESSION_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_11 DEFAULT '0' FOR HOUR_SESSION_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_12 DEFAULT '0' FOR HOUR_SESSION_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_13 DEFAULT '0' FOR HOUR_SESSION_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_14 DEFAULT '0' FOR HOUR_SESSION_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_15 DEFAULT '0' FOR HOUR_SESSION_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_16 DEFAULT '0' FOR HOUR_SESSION_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_17 DEFAULT '0' FOR HOUR_SESSION_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_18 DEFAULT '0' FOR HOUR_SESSION_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_19 DEFAULT '0' FOR HOUR_SESSION_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_20 DEFAULT '0' FOR HOUR_SESSION_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_21 DEFAULT '0' FOR HOUR_SESSION_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_22 DEFAULT '0' FOR HOUR_SESSION_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_SESSION_23 DEFAULT '0' FOR HOUR_SESSION_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_0 DEFAULT '0' FOR HOUR_HIT_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_1 DEFAULT '0' FOR HOUR_HIT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_2 DEFAULT '0' FOR HOUR_HIT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_3 DEFAULT '0' FOR HOUR_HIT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_4 DEFAULT '0' FOR HOUR_HIT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_5 DEFAULT '0' FOR HOUR_HIT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_6 DEFAULT '0' FOR HOUR_HIT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_7 DEFAULT '0' FOR HOUR_HIT_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_8 DEFAULT '0' FOR HOUR_HIT_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_9 DEFAULT '0' FOR HOUR_HIT_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_10 DEFAULT '0' FOR HOUR_HIT_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_11 DEFAULT '0' FOR HOUR_HIT_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_12 DEFAULT '0' FOR HOUR_HIT_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_13 DEFAULT '0' FOR HOUR_HIT_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_14 DEFAULT '0' FOR HOUR_HIT_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_15 DEFAULT '0' FOR HOUR_HIT_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_16 DEFAULT '0' FOR HOUR_HIT_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_17 DEFAULT '0' FOR HOUR_HIT_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_18 DEFAULT '0' FOR HOUR_HIT_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_19 DEFAULT '0' FOR HOUR_HIT_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_20 DEFAULT '0' FOR HOUR_HIT_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_21 DEFAULT '0' FOR HOUR_HIT_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_22 DEFAULT '0' FOR HOUR_HIT_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_HIT_23 DEFAULT '0' FOR HOUR_HIT_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_0 DEFAULT '0' FOR HOUR_EVENT_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_1 DEFAULT '0' FOR HOUR_EVENT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_2 DEFAULT '0' FOR HOUR_EVENT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_3 DEFAULT '0' FOR HOUR_EVENT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_4 DEFAULT '0' FOR HOUR_EVENT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_5 DEFAULT '0' FOR HOUR_EVENT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_6 DEFAULT '0' FOR HOUR_EVENT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_7 DEFAULT '0' FOR HOUR_EVENT_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_8 DEFAULT '0' FOR HOUR_EVENT_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_9 DEFAULT '0' FOR HOUR_EVENT_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_10 DEFAULT '0' FOR HOUR_EVENT_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_11 DEFAULT '0' FOR HOUR_EVENT_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_12 DEFAULT '0' FOR HOUR_EVENT_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_13 DEFAULT '0' FOR HOUR_EVENT_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_14 DEFAULT '0' FOR HOUR_EVENT_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_15 DEFAULT '0' FOR HOUR_EVENT_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_16 DEFAULT '0' FOR HOUR_EVENT_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_17 DEFAULT '0' FOR HOUR_EVENT_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_18 DEFAULT '0' FOR HOUR_EVENT_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_19 DEFAULT '0' FOR HOUR_EVENT_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_20 DEFAULT '0' FOR HOUR_EVENT_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_21 DEFAULT '0' FOR HOUR_EVENT_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_22 DEFAULT '0' FOR HOUR_EVENT_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_EVENT_23 DEFAULT '0' FOR HOUR_EVENT_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_0 DEFAULT '0' FOR HOUR_FAVORITE_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_1 DEFAULT '0' FOR HOUR_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_2 DEFAULT '0' FOR HOUR_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_3 DEFAULT '0' FOR HOUR_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_4 DEFAULT '0' FOR HOUR_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_5 DEFAULT '0' FOR HOUR_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_6 DEFAULT '0' FOR HOUR_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_7 DEFAULT '0' FOR HOUR_FAVORITE_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_8 DEFAULT '0' FOR HOUR_FAVORITE_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_9 DEFAULT '0' FOR HOUR_FAVORITE_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_10 DEFAULT '0' FOR HOUR_FAVORITE_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_11 DEFAULT '0' FOR HOUR_FAVORITE_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_12 DEFAULT '0' FOR HOUR_FAVORITE_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_13 DEFAULT '0' FOR HOUR_FAVORITE_13
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_14 DEFAULT '0' FOR HOUR_FAVORITE_14
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_15 DEFAULT '0' FOR HOUR_FAVORITE_15
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_16 DEFAULT '0' FOR HOUR_FAVORITE_16
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_17 DEFAULT '0' FOR HOUR_FAVORITE_17
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_18 DEFAULT '0' FOR HOUR_FAVORITE_18
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_19 DEFAULT '0' FOR HOUR_FAVORITE_19
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_20 DEFAULT '0' FOR HOUR_FAVORITE_20
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_21 DEFAULT '0' FOR HOUR_FAVORITE_21
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_22 DEFAULT '0' FOR HOUR_FAVORITE_22
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_HOUR_FAVORITE_23 DEFAULT '0' FOR HOUR_FAVORITE_23
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_0 DEFAULT '0' FOR WEEKDAY_HOST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_1 DEFAULT '0' FOR WEEKDAY_HOST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_2 DEFAULT '0' FOR WEEKDAY_HOST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_3 DEFAULT '0' FOR WEEKDAY_HOST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_4 DEFAULT '0' FOR WEEKDAY_HOST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_5 DEFAULT '0' FOR WEEKDAY_HOST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HOST_6 DEFAULT '0' FOR WEEKDAY_HOST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_0 DEFAULT '0' FOR WEEKDAY_GUEST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_1 DEFAULT '0' FOR WEEKDAY_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_2 DEFAULT '0' FOR WEEKDAY_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_3 DEFAULT '0' FOR WEEKDAY_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_4 DEFAULT '0' FOR WEEKDAY_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_5 DEFAULT '0' FOR WEEKDAY_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_GUEST_6 DEFAULT '0' FOR WEEKDAY_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_0 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_1 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_2 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_3 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_4 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_5 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_NEW_GUEST_6 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_0 DEFAULT '0' FOR WEEKDAY_SESSION_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_1 DEFAULT '0' FOR WEEKDAY_SESSION_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_2 DEFAULT '0' FOR WEEKDAY_SESSION_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_3 DEFAULT '0' FOR WEEKDAY_SESSION_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_4 DEFAULT '0' FOR WEEKDAY_SESSION_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_5 DEFAULT '0' FOR WEEKDAY_SESSION_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_SESSION_6 DEFAULT '0' FOR WEEKDAY_SESSION_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_0 DEFAULT '0' FOR WEEKDAY_HIT_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_1 DEFAULT '0' FOR WEEKDAY_HIT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_2 DEFAULT '0' FOR WEEKDAY_HIT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_3 DEFAULT '0' FOR WEEKDAY_HIT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_4 DEFAULT '0' FOR WEEKDAY_HIT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_5 DEFAULT '0' FOR WEEKDAY_HIT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_HIT_6 DEFAULT '0' FOR WEEKDAY_HIT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_0 DEFAULT '0' FOR WEEKDAY_EVENT_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_1 DEFAULT '0' FOR WEEKDAY_EVENT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_2 DEFAULT '0' FOR WEEKDAY_EVENT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_3 DEFAULT '0' FOR WEEKDAY_EVENT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_4 DEFAULT '0' FOR WEEKDAY_EVENT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_5 DEFAULT '0' FOR WEEKDAY_EVENT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_EVENT_6 DEFAULT '0' FOR WEEKDAY_EVENT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_0 DEFAULT '0' FOR WEEKDAY_FAVORITE_0
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_1 DEFAULT '0' FOR WEEKDAY_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_2 DEFAULT '0' FOR WEEKDAY_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_3 DEFAULT '0' FOR WEEKDAY_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_4 DEFAULT '0' FOR WEEKDAY_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_5 DEFAULT '0' FOR WEEKDAY_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_WEEKDAY_FAVORITE_6 DEFAULT '0' FOR WEEKDAY_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_1 DEFAULT '0' FOR MONTH_HOST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_2 DEFAULT '0' FOR MONTH_HOST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_3 DEFAULT '0' FOR MONTH_HOST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_4 DEFAULT '0' FOR MONTH_HOST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_5 DEFAULT '0' FOR MONTH_HOST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_6 DEFAULT '0' FOR MONTH_HOST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_7 DEFAULT '0' FOR MONTH_HOST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_8 DEFAULT '0' FOR MONTH_HOST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_9 DEFAULT '0' FOR MONTH_HOST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_10 DEFAULT '0' FOR MONTH_HOST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_11 DEFAULT '0' FOR MONTH_HOST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HOST_12 DEFAULT '0' FOR MONTH_HOST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_1 DEFAULT '0' FOR MONTH_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_2 DEFAULT '0' FOR MONTH_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_3 DEFAULT '0' FOR MONTH_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_4 DEFAULT '0' FOR MONTH_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_5 DEFAULT '0' FOR MONTH_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_6 DEFAULT '0' FOR MONTH_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_7 DEFAULT '0' FOR MONTH_GUEST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_8 DEFAULT '0' FOR MONTH_GUEST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_9 DEFAULT '0' FOR MONTH_GUEST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_10 DEFAULT '0' FOR MONTH_GUEST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_11 DEFAULT '0' FOR MONTH_GUEST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_GUEST_12 DEFAULT '0' FOR MONTH_GUEST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_1 DEFAULT '0' FOR MONTH_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_2 DEFAULT '0' FOR MONTH_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_3 DEFAULT '0' FOR MONTH_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_4 DEFAULT '0' FOR MONTH_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_5 DEFAULT '0' FOR MONTH_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_6 DEFAULT '0' FOR MONTH_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_7 DEFAULT '0' FOR MONTH_NEW_GUEST_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_8 DEFAULT '0' FOR MONTH_NEW_GUEST_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_9 DEFAULT '0' FOR MONTH_NEW_GUEST_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_10 DEFAULT '0' FOR MONTH_NEW_GUEST_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_11 DEFAULT '0' FOR MONTH_NEW_GUEST_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_NEW_GUEST_12 DEFAULT '0' FOR MONTH_NEW_GUEST_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_1 DEFAULT '0' FOR MONTH_SESSION_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_2 DEFAULT '0' FOR MONTH_SESSION_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_3 DEFAULT '0' FOR MONTH_SESSION_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_4 DEFAULT '0' FOR MONTH_SESSION_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_5 DEFAULT '0' FOR MONTH_SESSION_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_6 DEFAULT '0' FOR MONTH_SESSION_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_7 DEFAULT '0' FOR MONTH_SESSION_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_8 DEFAULT '0' FOR MONTH_SESSION_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_9 DEFAULT '0' FOR MONTH_SESSION_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_10 DEFAULT '0' FOR MONTH_SESSION_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_11 DEFAULT '0' FOR MONTH_SESSION_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_SESSION_12 DEFAULT '0' FOR MONTH_SESSION_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_1 DEFAULT '0' FOR MONTH_HIT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_2 DEFAULT '0' FOR MONTH_HIT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_3 DEFAULT '0' FOR MONTH_HIT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_4 DEFAULT '0' FOR MONTH_HIT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_5 DEFAULT '0' FOR MONTH_HIT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_6 DEFAULT '0' FOR MONTH_HIT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_7 DEFAULT '0' FOR MONTH_HIT_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_8 DEFAULT '0' FOR MONTH_HIT_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_9 DEFAULT '0' FOR MONTH_HIT_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_10 DEFAULT '0' FOR MONTH_HIT_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_11 DEFAULT '0' FOR MONTH_HIT_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_HIT_12 DEFAULT '0' FOR MONTH_HIT_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_1 DEFAULT '0' FOR MONTH_EVENT_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_2 DEFAULT '0' FOR MONTH_EVENT_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_3 DEFAULT '0' FOR MONTH_EVENT_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_4 DEFAULT '0' FOR MONTH_EVENT_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_5 DEFAULT '0' FOR MONTH_EVENT_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_6 DEFAULT '0' FOR MONTH_EVENT_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_7 DEFAULT '0' FOR MONTH_EVENT_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_8 DEFAULT '0' FOR MONTH_EVENT_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_9 DEFAULT '0' FOR MONTH_EVENT_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_10 DEFAULT '0' FOR MONTH_EVENT_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_11 DEFAULT '0' FOR MONTH_EVENT_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_EVENT_12 DEFAULT '0' FOR MONTH_EVENT_12
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_1 DEFAULT '0' FOR MONTH_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_2 DEFAULT '0' FOR MONTH_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_3 DEFAULT '0' FOR MONTH_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_4 DEFAULT '0' FOR MONTH_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_5 DEFAULT '0' FOR MONTH_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_6 DEFAULT '0' FOR MONTH_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_7 DEFAULT '0' FOR MONTH_FAVORITE_7
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_8 DEFAULT '0' FOR MONTH_FAVORITE_8
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_9 DEFAULT '0' FOR MONTH_FAVORITE_9
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_10 DEFAULT '0' FOR MONTH_FAVORITE_10
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_11 DEFAULT '0' FOR MONTH_FAVORITE_11
GO
ALTER TABLE B_STAT_DAY ADD CONSTRAINT DF_B_STAT_DAY_MONTH_FAVORITE_12 DEFAULT '0' FOR MONTH_FAVORITE_12
GO
CREATE UNIQUE INDEX UX_B_STAT_DAY_1 ON B_STAT_DAY (DATE_STAT)
GO


CREATE TABLE B_STAT_DAY_SITE
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_STAT datetime NOT NULL,
	SITE_ID char(2) NOT NULL,
	HITS int NOT NULL,
	C_HOSTS int NOT NULL,
	SESSIONS int NOT NULL,
	C_EVENTS int NOT NULL,
	GUESTS int NOT NULL,
	NEW_GUESTS int NOT NULL,
	FAVORITES int NOT NULL,
	TOTAL_HOSTS int NOT NULL,
	AM_AVERAGE_TIME decimal(18,2) NOT NULL,
	AM_1 int NOT NULL,
	AM_1_3 int NOT NULL,
	AM_3_6 int NOT NULL,
	AM_6_9 int NOT NULL,
	AM_9_12 int NOT NULL,
	AM_12_15 int NOT NULL,
	AM_15_18 int NOT NULL,
	AM_18_21 int NOT NULL,
	AM_21_24 int NOT NULL,
	AM_24 int NOT NULL,
	AH_AVERAGE_HITS decimal(18,2) NOT NULL,
	AH_1 int NOT NULL,
	AH_2_5 int NOT NULL,
	AH_6_9 int NOT NULL,
	AH_10_13 int NOT NULL,
	AH_14_17 int NOT NULL,
	AH_18_21 int NOT NULL,
	AH_22_25 int NOT NULL,
	AH_26_29 int NOT NULL,
	AH_30_33 int NOT NULL,
	AH_34 int NOT NULL,
	HOUR_HOST_0 int NOT NULL,
	HOUR_HOST_1 int NOT NULL,
	HOUR_HOST_2 int NOT NULL,
	HOUR_HOST_3 int NOT NULL,
	HOUR_HOST_4 int NOT NULL,
	HOUR_HOST_5 int NOT NULL,
	HOUR_HOST_6 int NOT NULL,
	HOUR_HOST_7 int NOT NULL,
	HOUR_HOST_8 int NOT NULL,
	HOUR_HOST_9 int NOT NULL,
	HOUR_HOST_10 int NOT NULL,
	HOUR_HOST_11 int NOT NULL,
	HOUR_HOST_12 int NOT NULL,
	HOUR_HOST_13 int NOT NULL,
	HOUR_HOST_14 int NOT NULL,
	HOUR_HOST_15 int NOT NULL,
	HOUR_HOST_16 int NOT NULL,
	HOUR_HOST_17 int NOT NULL,
	HOUR_HOST_18 int NOT NULL,
	HOUR_HOST_19 int NOT NULL,
	HOUR_HOST_20 int NOT NULL,
	HOUR_HOST_21 int NOT NULL,
	HOUR_HOST_22 int NOT NULL,
	HOUR_HOST_23 int NOT NULL,
	HOUR_GUEST_0 int NOT NULL,
	HOUR_GUEST_1 int NOT NULL,
	HOUR_GUEST_2 int NOT NULL,
	HOUR_GUEST_3 int NOT NULL,
	HOUR_GUEST_4 int NOT NULL,
	HOUR_GUEST_5 int NOT NULL,
	HOUR_GUEST_6 int NOT NULL,
	HOUR_GUEST_7 int NOT NULL,
	HOUR_GUEST_8 int NOT NULL,
	HOUR_GUEST_9 int NOT NULL,
	HOUR_GUEST_10 int NOT NULL,
	HOUR_GUEST_11 int NOT NULL,
	HOUR_GUEST_12 int NOT NULL,
	HOUR_GUEST_13 int NOT NULL,
	HOUR_GUEST_14 int NOT NULL,
	HOUR_GUEST_15 int NOT NULL,
	HOUR_GUEST_16 int NOT NULL,
	HOUR_GUEST_17 int NOT NULL,
	HOUR_GUEST_18 int NOT NULL,
	HOUR_GUEST_19 int NOT NULL,
	HOUR_GUEST_20 int NOT NULL,
	HOUR_GUEST_21 int NOT NULL,
	HOUR_GUEST_22 int NOT NULL,
	HOUR_GUEST_23 int NOT NULL,
	HOUR_NEW_GUEST_0 int NOT NULL,
	HOUR_NEW_GUEST_1 int NOT NULL,
	HOUR_NEW_GUEST_2 int NOT NULL,
	HOUR_NEW_GUEST_3 int NOT NULL,
	HOUR_NEW_GUEST_4 int NOT NULL,
	HOUR_NEW_GUEST_5 int NOT NULL,
	HOUR_NEW_GUEST_6 int NOT NULL,
	HOUR_NEW_GUEST_7 int NOT NULL,
	HOUR_NEW_GUEST_8 int NOT NULL,
	HOUR_NEW_GUEST_9 int NOT NULL,
	HOUR_NEW_GUEST_10 int NOT NULL,
	HOUR_NEW_GUEST_11 int NOT NULL,
	HOUR_NEW_GUEST_12 int NOT NULL,
	HOUR_NEW_GUEST_13 int NOT NULL,
	HOUR_NEW_GUEST_14 int NOT NULL,
	HOUR_NEW_GUEST_15 int NOT NULL,
	HOUR_NEW_GUEST_16 int NOT NULL,
	HOUR_NEW_GUEST_17 int NOT NULL,
	HOUR_NEW_GUEST_18 int NOT NULL,
	HOUR_NEW_GUEST_19 int NOT NULL,
	HOUR_NEW_GUEST_20 int NOT NULL,
	HOUR_NEW_GUEST_21 int NOT NULL,
	HOUR_NEW_GUEST_22 int NOT NULL,
	HOUR_NEW_GUEST_23 int NOT NULL,
	HOUR_SESSION_0 int NOT NULL,
	HOUR_SESSION_1 int NOT NULL,
	HOUR_SESSION_2 int NOT NULL,
	HOUR_SESSION_3 int NOT NULL,
	HOUR_SESSION_4 int NOT NULL,
	HOUR_SESSION_5 int NOT NULL,
	HOUR_SESSION_6 int NOT NULL,
	HOUR_SESSION_7 int NOT NULL,
	HOUR_SESSION_8 int NOT NULL,
	HOUR_SESSION_9 int NOT NULL,
	HOUR_SESSION_10 int NOT NULL,
	HOUR_SESSION_11 int NOT NULL,
	HOUR_SESSION_12 int NOT NULL,
	HOUR_SESSION_13 int NOT NULL,
	HOUR_SESSION_14 int NOT NULL,
	HOUR_SESSION_15 int NOT NULL,
	HOUR_SESSION_16 int NOT NULL,
	HOUR_SESSION_17 int NOT NULL,
	HOUR_SESSION_18 int NOT NULL,
	HOUR_SESSION_19 int NOT NULL,
	HOUR_SESSION_20 int NOT NULL,
	HOUR_SESSION_21 int NOT NULL,
	HOUR_SESSION_22 int NOT NULL,
	HOUR_SESSION_23 int NOT NULL,
	HOUR_HIT_0 int NOT NULL,
	HOUR_HIT_1 int NOT NULL,
	HOUR_HIT_2 int NOT NULL,
	HOUR_HIT_3 int NOT NULL,
	HOUR_HIT_4 int NOT NULL,
	HOUR_HIT_5 int NOT NULL,
	HOUR_HIT_6 int NOT NULL,
	HOUR_HIT_7 int NOT NULL,
	HOUR_HIT_8 int NOT NULL,
	HOUR_HIT_9 int NOT NULL,
	HOUR_HIT_10 int NOT NULL,
	HOUR_HIT_11 int NOT NULL,
	HOUR_HIT_12 int NOT NULL,
	HOUR_HIT_13 int NOT NULL,
	HOUR_HIT_14 int NOT NULL,
	HOUR_HIT_15 int NOT NULL,
	HOUR_HIT_16 int NOT NULL,
	HOUR_HIT_17 int NOT NULL,
	HOUR_HIT_18 int NOT NULL,
	HOUR_HIT_19 int NOT NULL,
	HOUR_HIT_20 int NOT NULL,
	HOUR_HIT_21 int NOT NULL,
	HOUR_HIT_22 int NOT NULL,
	HOUR_HIT_23 int NOT NULL,
	HOUR_EVENT_0 int NOT NULL,
	HOUR_EVENT_1 int NOT NULL,
	HOUR_EVENT_2 int NOT NULL,
	HOUR_EVENT_3 int NOT NULL,
	HOUR_EVENT_4 int NOT NULL,
	HOUR_EVENT_5 int NOT NULL,
	HOUR_EVENT_6 int NOT NULL,
	HOUR_EVENT_7 int NOT NULL,
	HOUR_EVENT_8 int NOT NULL,
	HOUR_EVENT_9 int NOT NULL,
	HOUR_EVENT_10 int NOT NULL,
	HOUR_EVENT_11 int NOT NULL,
	HOUR_EVENT_12 int NOT NULL,
	HOUR_EVENT_13 int NOT NULL,
	HOUR_EVENT_14 int NOT NULL,
	HOUR_EVENT_15 int NOT NULL,
	HOUR_EVENT_16 int NOT NULL,
	HOUR_EVENT_17 int NOT NULL,
	HOUR_EVENT_18 int NOT NULL,
	HOUR_EVENT_19 int NOT NULL,
	HOUR_EVENT_20 int NOT NULL,
	HOUR_EVENT_21 int NOT NULL,
	HOUR_EVENT_22 int NOT NULL,
	HOUR_EVENT_23 int NOT NULL,
	HOUR_FAVORITE_0 int NOT NULL,
	HOUR_FAVORITE_1 int NOT NULL,
	HOUR_FAVORITE_2 int NOT NULL,
	HOUR_FAVORITE_3 int NOT NULL,
	HOUR_FAVORITE_4 int NOT NULL,
	HOUR_FAVORITE_5 int NOT NULL,
	HOUR_FAVORITE_6 int NOT NULL,
	HOUR_FAVORITE_7 int NOT NULL,
	HOUR_FAVORITE_8 int NOT NULL,
	HOUR_FAVORITE_9 int NOT NULL,
	HOUR_FAVORITE_10 int NOT NULL,
	HOUR_FAVORITE_11 int NOT NULL,
	HOUR_FAVORITE_12 int NOT NULL,
	HOUR_FAVORITE_13 int NOT NULL,
	HOUR_FAVORITE_14 int NOT NULL,
	HOUR_FAVORITE_15 int NOT NULL,
	HOUR_FAVORITE_16 int NOT NULL,
	HOUR_FAVORITE_17 int NOT NULL,
	HOUR_FAVORITE_18 int NOT NULL,
	HOUR_FAVORITE_19 int NOT NULL,
	HOUR_FAVORITE_20 int NOT NULL,
	HOUR_FAVORITE_21 int NOT NULL,
	HOUR_FAVORITE_22 int NOT NULL,
	HOUR_FAVORITE_23 int NOT NULL,
	WEEKDAY_HOST_0 int NOT NULL,
	WEEKDAY_HOST_1 int NOT NULL,
	WEEKDAY_HOST_2 int NOT NULL,
	WEEKDAY_HOST_3 int NOT NULL,
	WEEKDAY_HOST_4 int NOT NULL,
	WEEKDAY_HOST_5 int NOT NULL,
	WEEKDAY_HOST_6 int NOT NULL,
	WEEKDAY_GUEST_0 int NOT NULL,
	WEEKDAY_GUEST_1 int NOT NULL,
	WEEKDAY_GUEST_2 int NOT NULL,
	WEEKDAY_GUEST_3 int NOT NULL,
	WEEKDAY_GUEST_4 int NOT NULL,
	WEEKDAY_GUEST_5 int NOT NULL,
	WEEKDAY_GUEST_6 int NOT NULL,
	WEEKDAY_NEW_GUEST_0 int NOT NULL,
	WEEKDAY_NEW_GUEST_1 int NOT NULL,
	WEEKDAY_NEW_GUEST_2 int NOT NULL,
	WEEKDAY_NEW_GUEST_3 int NOT NULL,
	WEEKDAY_NEW_GUEST_4 int NOT NULL,
	WEEKDAY_NEW_GUEST_5 int NOT NULL,
	WEEKDAY_NEW_GUEST_6 int NOT NULL,
	WEEKDAY_SESSION_0 int NOT NULL,
	WEEKDAY_SESSION_1 int NOT NULL,
	WEEKDAY_SESSION_2 int NOT NULL,
	WEEKDAY_SESSION_3 int NOT NULL,
	WEEKDAY_SESSION_4 int NOT NULL,
	WEEKDAY_SESSION_5 int NOT NULL,
	WEEKDAY_SESSION_6 int NOT NULL,
	WEEKDAY_HIT_0 int NOT NULL,
	WEEKDAY_HIT_1 int NOT NULL,
	WEEKDAY_HIT_2 int NOT NULL,
	WEEKDAY_HIT_3 int NOT NULL,
	WEEKDAY_HIT_4 int NOT NULL,
	WEEKDAY_HIT_5 int NOT NULL,
	WEEKDAY_HIT_6 int NOT NULL,
	WEEKDAY_EVENT_0 int NOT NULL,
	WEEKDAY_EVENT_1 int NOT NULL,
	WEEKDAY_EVENT_2 int NOT NULL,
	WEEKDAY_EVENT_3 int NOT NULL,
	WEEKDAY_EVENT_4 int NOT NULL,
	WEEKDAY_EVENT_5 int NOT NULL,
	WEEKDAY_EVENT_6 int NOT NULL,
	WEEKDAY_FAVORITE_0 int NOT NULL,
	WEEKDAY_FAVORITE_1 int NOT NULL,
	WEEKDAY_FAVORITE_2 int NOT NULL,
	WEEKDAY_FAVORITE_3 int NOT NULL,
	WEEKDAY_FAVORITE_4 int NOT NULL,
	WEEKDAY_FAVORITE_5 int NOT NULL,
	WEEKDAY_FAVORITE_6 int NOT NULL,
	MONTH_HOST_1 int NOT NULL,
	MONTH_HOST_2 int NOT NULL,
	MONTH_HOST_3 int NOT NULL,
	MONTH_HOST_4 int NOT NULL,
	MONTH_HOST_5 int NOT NULL,
	MONTH_HOST_6 int NOT NULL,
	MONTH_HOST_7 int NOT NULL,
	MONTH_HOST_8 int NOT NULL,
	MONTH_HOST_9 int NOT NULL,
	MONTH_HOST_10 int NOT NULL,
	MONTH_HOST_11 int NOT NULL,
	MONTH_HOST_12 int NOT NULL,
	MONTH_GUEST_1 int NOT NULL,
	MONTH_GUEST_2 int NOT NULL,
	MONTH_GUEST_3 int NOT NULL,
	MONTH_GUEST_4 int NOT NULL,
	MONTH_GUEST_5 int NOT NULL,
	MONTH_GUEST_6 int NOT NULL,
	MONTH_GUEST_7 int NOT NULL,
	MONTH_GUEST_8 int NOT NULL,
	MONTH_GUEST_9 int NOT NULL,
	MONTH_GUEST_10 int NOT NULL,
	MONTH_GUEST_11 int NOT NULL,
	MONTH_GUEST_12 int NOT NULL,
	MONTH_NEW_GUEST_1 int NOT NULL,
	MONTH_NEW_GUEST_2 int NOT NULL,
	MONTH_NEW_GUEST_3 int NOT NULL,
	MONTH_NEW_GUEST_4 int NOT NULL,
	MONTH_NEW_GUEST_5 int NOT NULL,
	MONTH_NEW_GUEST_6 int NOT NULL,
	MONTH_NEW_GUEST_7 int NOT NULL,
	MONTH_NEW_GUEST_8 int NOT NULL,
	MONTH_NEW_GUEST_9 int NOT NULL,
	MONTH_NEW_GUEST_10 int NOT NULL,
	MONTH_NEW_GUEST_11 int NOT NULL,
	MONTH_NEW_GUEST_12 int NOT NULL,
	MONTH_SESSION_1 int NOT NULL,
	MONTH_SESSION_2 int NOT NULL,
	MONTH_SESSION_3 int NOT NULL,
	MONTH_SESSION_4 int NOT NULL,
	MONTH_SESSION_5 int NOT NULL,
	MONTH_SESSION_6 int NOT NULL,
	MONTH_SESSION_7 int NOT NULL,
	MONTH_SESSION_8 int NOT NULL,
	MONTH_SESSION_9 int NOT NULL,
	MONTH_SESSION_10 int NOT NULL,
	MONTH_SESSION_11 int NOT NULL,
	MONTH_SESSION_12 int NOT NULL,
	MONTH_HIT_1 int NOT NULL,
	MONTH_HIT_2 int NOT NULL,
	MONTH_HIT_3 int NOT NULL,
	MONTH_HIT_4 int NOT NULL,
	MONTH_HIT_5 int NOT NULL,
	MONTH_HIT_6 int NOT NULL,
	MONTH_HIT_7 int NOT NULL,
	MONTH_HIT_8 int NOT NULL,
	MONTH_HIT_9 int NOT NULL,
	MONTH_HIT_10 int NOT NULL,
	MONTH_HIT_11 int NOT NULL,
	MONTH_HIT_12 int NOT NULL,
	MONTH_EVENT_1 int NOT NULL,
	MONTH_EVENT_2 int NOT NULL,
	MONTH_EVENT_3 int NOT NULL,
	MONTH_EVENT_4 int NOT NULL,
	MONTH_EVENT_5 int NOT NULL,
	MONTH_EVENT_6 int NOT NULL,
	MONTH_EVENT_7 int NOT NULL,
	MONTH_EVENT_8 int NOT NULL,
	MONTH_EVENT_9 int NOT NULL,
	MONTH_EVENT_10 int NOT NULL,
	MONTH_EVENT_11 int NOT NULL,
	MONTH_EVENT_12 int NOT NULL,
	MONTH_FAVORITE_1 int NOT NULL,
	MONTH_FAVORITE_2 int NOT NULL,
	MONTH_FAVORITE_3 int NOT NULL,
	MONTH_FAVORITE_4 int NOT NULL,
	MONTH_FAVORITE_5 int NOT NULL,
	MONTH_FAVORITE_6 int NOT NULL,
	MONTH_FAVORITE_7 int NOT NULL,
	MONTH_FAVORITE_8 int NOT NULL,
	MONTH_FAVORITE_9 int NOT NULL,
	MONTH_FAVORITE_10 int NOT NULL,
	MONTH_FAVORITE_11 int NOT NULL,
	MONTH_FAVORITE_12 int NOT NULL
)
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT PK_B_STAT_DAY_SITE PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_C_HOSTS DEFAULT '0' FOR C_HOSTS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_GUESTS DEFAULT '0' FOR GUESTS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_FAVORITES DEFAULT '0' FOR FAVORITES
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_TOTAL_HOSTS DEFAULT '0' FOR TOTAL_HOSTS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_AVERAGE_TIME DEFAULT '0.00' FOR AM_AVERAGE_TIME
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_1 DEFAULT '0' FOR AM_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_1_3 DEFAULT '0' FOR AM_1_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_3_6 DEFAULT '0' FOR AM_3_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_6_9 DEFAULT '0' FOR AM_6_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_9_12 DEFAULT '0' FOR AM_9_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_12_15 DEFAULT '0' FOR AM_12_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_15_18 DEFAULT '0' FOR AM_15_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_18_21 DEFAULT '0' FOR AM_18_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_21_24 DEFAULT '0' FOR AM_21_24
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AM_24 DEFAULT '0' FOR AM_24
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_AVERAGE_HITS DEFAULT '0.00' FOR AH_AVERAGE_HITS
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_1 DEFAULT '0' FOR AH_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_2_5 DEFAULT '0' FOR AH_2_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_6_9 DEFAULT '0' FOR AH_6_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_10_13 DEFAULT '0' FOR AH_10_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_14_17 DEFAULT '0' FOR AH_14_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_18_21 DEFAULT '0' FOR AH_18_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_22_25 DEFAULT '0' FOR AH_22_25
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_26_29 DEFAULT '0' FOR AH_26_29
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_30_33 DEFAULT '0' FOR AH_30_33
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_AH_34 DEFAULT '0' FOR AH_34
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_0 DEFAULT '0' FOR HOUR_HOST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_1 DEFAULT '0' FOR HOUR_HOST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_2 DEFAULT '0' FOR HOUR_HOST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_3 DEFAULT '0' FOR HOUR_HOST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_4 DEFAULT '0' FOR HOUR_HOST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_5 DEFAULT '0' FOR HOUR_HOST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_6 DEFAULT '0' FOR HOUR_HOST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_7 DEFAULT '0' FOR HOUR_HOST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_8 DEFAULT '0' FOR HOUR_HOST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_9 DEFAULT '0' FOR HOUR_HOST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_10 DEFAULT '0' FOR HOUR_HOST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_11 DEFAULT '0' FOR HOUR_HOST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_12 DEFAULT '0' FOR HOUR_HOST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_13 DEFAULT '0' FOR HOUR_HOST_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_14 DEFAULT '0' FOR HOUR_HOST_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_15 DEFAULT '0' FOR HOUR_HOST_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_16 DEFAULT '0' FOR HOUR_HOST_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_17 DEFAULT '0' FOR HOUR_HOST_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_18 DEFAULT '0' FOR HOUR_HOST_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_19 DEFAULT '0' FOR HOUR_HOST_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_20 DEFAULT '0' FOR HOUR_HOST_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_21 DEFAULT '0' FOR HOUR_HOST_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_22 DEFAULT '0' FOR HOUR_HOST_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HOST_23 DEFAULT '0' FOR HOUR_HOST_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_0 DEFAULT '0' FOR HOUR_GUEST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_1 DEFAULT '0' FOR HOUR_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_2 DEFAULT '0' FOR HOUR_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_3 DEFAULT '0' FOR HOUR_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_4 DEFAULT '0' FOR HOUR_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_5 DEFAULT '0' FOR HOUR_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_6 DEFAULT '0' FOR HOUR_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_7 DEFAULT '0' FOR HOUR_GUEST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_8 DEFAULT '0' FOR HOUR_GUEST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_9 DEFAULT '0' FOR HOUR_GUEST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_10 DEFAULT '0' FOR HOUR_GUEST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_11 DEFAULT '0' FOR HOUR_GUEST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_12 DEFAULT '0' FOR HOUR_GUEST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_13 DEFAULT '0' FOR HOUR_GUEST_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_14 DEFAULT '0' FOR HOUR_GUEST_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_15 DEFAULT '0' FOR HOUR_GUEST_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_16 DEFAULT '0' FOR HOUR_GUEST_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_17 DEFAULT '0' FOR HOUR_GUEST_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_18 DEFAULT '0' FOR HOUR_GUEST_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_19 DEFAULT '0' FOR HOUR_GUEST_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_20 DEFAULT '0' FOR HOUR_GUEST_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_21 DEFAULT '0' FOR HOUR_GUEST_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_22 DEFAULT '0' FOR HOUR_GUEST_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_GUEST_23 DEFAULT '0' FOR HOUR_GUEST_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_0 DEFAULT '0' FOR HOUR_NEW_GUEST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_1 DEFAULT '0' FOR HOUR_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_2 DEFAULT '0' FOR HOUR_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_3 DEFAULT '0' FOR HOUR_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_4 DEFAULT '0' FOR HOUR_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_5 DEFAULT '0' FOR HOUR_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_6 DEFAULT '0' FOR HOUR_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_7 DEFAULT '0' FOR HOUR_NEW_GUEST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_8 DEFAULT '0' FOR HOUR_NEW_GUEST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_9 DEFAULT '0' FOR HOUR_NEW_GUEST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_10 DEFAULT '0' FOR HOUR_NEW_GUEST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_11 DEFAULT '0' FOR HOUR_NEW_GUEST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_12 DEFAULT '0' FOR HOUR_NEW_GUEST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_13 DEFAULT '0' FOR HOUR_NEW_GUEST_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_14 DEFAULT '0' FOR HOUR_NEW_GUEST_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_15 DEFAULT '0' FOR HOUR_NEW_GUEST_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_16 DEFAULT '0' FOR HOUR_NEW_GUEST_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_17 DEFAULT '0' FOR HOUR_NEW_GUEST_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_18 DEFAULT '0' FOR HOUR_NEW_GUEST_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_19 DEFAULT '0' FOR HOUR_NEW_GUEST_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_20 DEFAULT '0' FOR HOUR_NEW_GUEST_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_21 DEFAULT '0' FOR HOUR_NEW_GUEST_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_22 DEFAULT '0' FOR HOUR_NEW_GUEST_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_NEW_GUEST_23 DEFAULT '0' FOR HOUR_NEW_GUEST_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_0 DEFAULT '0' FOR HOUR_SESSION_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_1 DEFAULT '0' FOR HOUR_SESSION_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_2 DEFAULT '0' FOR HOUR_SESSION_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_3 DEFAULT '0' FOR HOUR_SESSION_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_4 DEFAULT '0' FOR HOUR_SESSION_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_5 DEFAULT '0' FOR HOUR_SESSION_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_6 DEFAULT '0' FOR HOUR_SESSION_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_7 DEFAULT '0' FOR HOUR_SESSION_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_8 DEFAULT '0' FOR HOUR_SESSION_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_9 DEFAULT '0' FOR HOUR_SESSION_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_10 DEFAULT '0' FOR HOUR_SESSION_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_11 DEFAULT '0' FOR HOUR_SESSION_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_12 DEFAULT '0' FOR HOUR_SESSION_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_13 DEFAULT '0' FOR HOUR_SESSION_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_14 DEFAULT '0' FOR HOUR_SESSION_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_15 DEFAULT '0' FOR HOUR_SESSION_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_16 DEFAULT '0' FOR HOUR_SESSION_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_17 DEFAULT '0' FOR HOUR_SESSION_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_18 DEFAULT '0' FOR HOUR_SESSION_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_19 DEFAULT '0' FOR HOUR_SESSION_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_20 DEFAULT '0' FOR HOUR_SESSION_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_21 DEFAULT '0' FOR HOUR_SESSION_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_22 DEFAULT '0' FOR HOUR_SESSION_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_SESSION_23 DEFAULT '0' FOR HOUR_SESSION_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_0 DEFAULT '0' FOR HOUR_HIT_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_1 DEFAULT '0' FOR HOUR_HIT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_2 DEFAULT '0' FOR HOUR_HIT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_3 DEFAULT '0' FOR HOUR_HIT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_4 DEFAULT '0' FOR HOUR_HIT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_5 DEFAULT '0' FOR HOUR_HIT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_6 DEFAULT '0' FOR HOUR_HIT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_7 DEFAULT '0' FOR HOUR_HIT_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_8 DEFAULT '0' FOR HOUR_HIT_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_9 DEFAULT '0' FOR HOUR_HIT_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_10 DEFAULT '0' FOR HOUR_HIT_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_11 DEFAULT '0' FOR HOUR_HIT_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_12 DEFAULT '0' FOR HOUR_HIT_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_13 DEFAULT '0' FOR HOUR_HIT_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_14 DEFAULT '0' FOR HOUR_HIT_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_15 DEFAULT '0' FOR HOUR_HIT_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_16 DEFAULT '0' FOR HOUR_HIT_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_17 DEFAULT '0' FOR HOUR_HIT_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_18 DEFAULT '0' FOR HOUR_HIT_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_19 DEFAULT '0' FOR HOUR_HIT_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_20 DEFAULT '0' FOR HOUR_HIT_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_21 DEFAULT '0' FOR HOUR_HIT_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_22 DEFAULT '0' FOR HOUR_HIT_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_HIT_23 DEFAULT '0' FOR HOUR_HIT_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_0 DEFAULT '0' FOR HOUR_EVENT_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_1 DEFAULT '0' FOR HOUR_EVENT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_2 DEFAULT '0' FOR HOUR_EVENT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_3 DEFAULT '0' FOR HOUR_EVENT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_4 DEFAULT '0' FOR HOUR_EVENT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_5 DEFAULT '0' FOR HOUR_EVENT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_6 DEFAULT '0' FOR HOUR_EVENT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_7 DEFAULT '0' FOR HOUR_EVENT_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_8 DEFAULT '0' FOR HOUR_EVENT_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_9 DEFAULT '0' FOR HOUR_EVENT_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_10 DEFAULT '0' FOR HOUR_EVENT_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_11 DEFAULT '0' FOR HOUR_EVENT_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_12 DEFAULT '0' FOR HOUR_EVENT_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_13 DEFAULT '0' FOR HOUR_EVENT_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_14 DEFAULT '0' FOR HOUR_EVENT_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_15 DEFAULT '0' FOR HOUR_EVENT_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_16 DEFAULT '0' FOR HOUR_EVENT_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_17 DEFAULT '0' FOR HOUR_EVENT_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_18 DEFAULT '0' FOR HOUR_EVENT_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_19 DEFAULT '0' FOR HOUR_EVENT_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_20 DEFAULT '0' FOR HOUR_EVENT_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_21 DEFAULT '0' FOR HOUR_EVENT_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_22 DEFAULT '0' FOR HOUR_EVENT_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_EVENT_23 DEFAULT '0' FOR HOUR_EVENT_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_0 DEFAULT '0' FOR HOUR_FAVORITE_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_1 DEFAULT '0' FOR HOUR_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_2 DEFAULT '0' FOR HOUR_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_3 DEFAULT '0' FOR HOUR_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_4 DEFAULT '0' FOR HOUR_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_5 DEFAULT '0' FOR HOUR_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_6 DEFAULT '0' FOR HOUR_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_7 DEFAULT '0' FOR HOUR_FAVORITE_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_8 DEFAULT '0' FOR HOUR_FAVORITE_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_9 DEFAULT '0' FOR HOUR_FAVORITE_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_10 DEFAULT '0' FOR HOUR_FAVORITE_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_11 DEFAULT '0' FOR HOUR_FAVORITE_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_12 DEFAULT '0' FOR HOUR_FAVORITE_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_13 DEFAULT '0' FOR HOUR_FAVORITE_13
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_14 DEFAULT '0' FOR HOUR_FAVORITE_14
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_15 DEFAULT '0' FOR HOUR_FAVORITE_15
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_16 DEFAULT '0' FOR HOUR_FAVORITE_16
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_17 DEFAULT '0' FOR HOUR_FAVORITE_17
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_18 DEFAULT '0' FOR HOUR_FAVORITE_18
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_19 DEFAULT '0' FOR HOUR_FAVORITE_19
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_20 DEFAULT '0' FOR HOUR_FAVORITE_20
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_21 DEFAULT '0' FOR HOUR_FAVORITE_21
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_22 DEFAULT '0' FOR HOUR_FAVORITE_22
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_HOUR_FAVORITE_23 DEFAULT '0' FOR HOUR_FAVORITE_23
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_0 DEFAULT '0' FOR WEEKDAY_HOST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_1 DEFAULT '0' FOR WEEKDAY_HOST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_2 DEFAULT '0' FOR WEEKDAY_HOST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_3 DEFAULT '0' FOR WEEKDAY_HOST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_4 DEFAULT '0' FOR WEEKDAY_HOST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_5 DEFAULT '0' FOR WEEKDAY_HOST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HOST_6 DEFAULT '0' FOR WEEKDAY_HOST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_0 DEFAULT '0' FOR WEEKDAY_GUEST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_1 DEFAULT '0' FOR WEEKDAY_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_2 DEFAULT '0' FOR WEEKDAY_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_3 DEFAULT '0' FOR WEEKDAY_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_4 DEFAULT '0' FOR WEEKDAY_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_5 DEFAULT '0' FOR WEEKDAY_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_GUEST_6 DEFAULT '0' FOR WEEKDAY_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_0 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_1 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_2 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_3 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_4 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_5 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_NEW_GUEST_6 DEFAULT '0' FOR WEEKDAY_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_0 DEFAULT '0' FOR WEEKDAY_SESSION_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_1 DEFAULT '0' FOR WEEKDAY_SESSION_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_2 DEFAULT '0' FOR WEEKDAY_SESSION_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_3 DEFAULT '0' FOR WEEKDAY_SESSION_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_4 DEFAULT '0' FOR WEEKDAY_SESSION_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_5 DEFAULT '0' FOR WEEKDAY_SESSION_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_SESSION_6 DEFAULT '0' FOR WEEKDAY_SESSION_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_0 DEFAULT '0' FOR WEEKDAY_HIT_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_1 DEFAULT '0' FOR WEEKDAY_HIT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_2 DEFAULT '0' FOR WEEKDAY_HIT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_3 DEFAULT '0' FOR WEEKDAY_HIT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_4 DEFAULT '0' FOR WEEKDAY_HIT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_5 DEFAULT '0' FOR WEEKDAY_HIT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_HIT_6 DEFAULT '0' FOR WEEKDAY_HIT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_0 DEFAULT '0' FOR WEEKDAY_EVENT_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_1 DEFAULT '0' FOR WEEKDAY_EVENT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_2 DEFAULT '0' FOR WEEKDAY_EVENT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_3 DEFAULT '0' FOR WEEKDAY_EVENT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_4 DEFAULT '0' FOR WEEKDAY_EVENT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_5 DEFAULT '0' FOR WEEKDAY_EVENT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_EVENT_6 DEFAULT '0' FOR WEEKDAY_EVENT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_0 DEFAULT '0' FOR WEEKDAY_FAVORITE_0
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_1 DEFAULT '0' FOR WEEKDAY_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_2 DEFAULT '0' FOR WEEKDAY_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_3 DEFAULT '0' FOR WEEKDAY_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_4 DEFAULT '0' FOR WEEKDAY_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_5 DEFAULT '0' FOR WEEKDAY_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_WEEKDAY_FAVORITE_6 DEFAULT '0' FOR WEEKDAY_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_1 DEFAULT '0' FOR MONTH_HOST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_2 DEFAULT '0' FOR MONTH_HOST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_3 DEFAULT '0' FOR MONTH_HOST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_4 DEFAULT '0' FOR MONTH_HOST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_5 DEFAULT '0' FOR MONTH_HOST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_6 DEFAULT '0' FOR MONTH_HOST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_7 DEFAULT '0' FOR MONTH_HOST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_8 DEFAULT '0' FOR MONTH_HOST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_9 DEFAULT '0' FOR MONTH_HOST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_10 DEFAULT '0' FOR MONTH_HOST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_11 DEFAULT '0' FOR MONTH_HOST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HOST_12 DEFAULT '0' FOR MONTH_HOST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_1 DEFAULT '0' FOR MONTH_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_2 DEFAULT '0' FOR MONTH_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_3 DEFAULT '0' FOR MONTH_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_4 DEFAULT '0' FOR MONTH_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_5 DEFAULT '0' FOR MONTH_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_6 DEFAULT '0' FOR MONTH_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_7 DEFAULT '0' FOR MONTH_GUEST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_8 DEFAULT '0' FOR MONTH_GUEST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_9 DEFAULT '0' FOR MONTH_GUEST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_10 DEFAULT '0' FOR MONTH_GUEST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_11 DEFAULT '0' FOR MONTH_GUEST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_GUEST_12 DEFAULT '0' FOR MONTH_GUEST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_1 DEFAULT '0' FOR MONTH_NEW_GUEST_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_2 DEFAULT '0' FOR MONTH_NEW_GUEST_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_3 DEFAULT '0' FOR MONTH_NEW_GUEST_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_4 DEFAULT '0' FOR MONTH_NEW_GUEST_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_5 DEFAULT '0' FOR MONTH_NEW_GUEST_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_6 DEFAULT '0' FOR MONTH_NEW_GUEST_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_7 DEFAULT '0' FOR MONTH_NEW_GUEST_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_8 DEFAULT '0' FOR MONTH_NEW_GUEST_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_9 DEFAULT '0' FOR MONTH_NEW_GUEST_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_10 DEFAULT '0' FOR MONTH_NEW_GUEST_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_11 DEFAULT '0' FOR MONTH_NEW_GUEST_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_NEW_GUEST_12 DEFAULT '0' FOR MONTH_NEW_GUEST_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_1 DEFAULT '0' FOR MONTH_SESSION_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_2 DEFAULT '0' FOR MONTH_SESSION_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_3 DEFAULT '0' FOR MONTH_SESSION_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_4 DEFAULT '0' FOR MONTH_SESSION_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_5 DEFAULT '0' FOR MONTH_SESSION_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_6 DEFAULT '0' FOR MONTH_SESSION_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_7 DEFAULT '0' FOR MONTH_SESSION_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_8 DEFAULT '0' FOR MONTH_SESSION_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_9 DEFAULT '0' FOR MONTH_SESSION_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_10 DEFAULT '0' FOR MONTH_SESSION_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_11 DEFAULT '0' FOR MONTH_SESSION_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_SESSION_12 DEFAULT '0' FOR MONTH_SESSION_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_1 DEFAULT '0' FOR MONTH_HIT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_2 DEFAULT '0' FOR MONTH_HIT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_3 DEFAULT '0' FOR MONTH_HIT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_4 DEFAULT '0' FOR MONTH_HIT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_5 DEFAULT '0' FOR MONTH_HIT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_6 DEFAULT '0' FOR MONTH_HIT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_7 DEFAULT '0' FOR MONTH_HIT_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_8 DEFAULT '0' FOR MONTH_HIT_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_9 DEFAULT '0' FOR MONTH_HIT_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_10 DEFAULT '0' FOR MONTH_HIT_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_11 DEFAULT '0' FOR MONTH_HIT_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_HIT_12 DEFAULT '0' FOR MONTH_HIT_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_1 DEFAULT '0' FOR MONTH_EVENT_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_2 DEFAULT '0' FOR MONTH_EVENT_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_3 DEFAULT '0' FOR MONTH_EVENT_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_4 DEFAULT '0' FOR MONTH_EVENT_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_5 DEFAULT '0' FOR MONTH_EVENT_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_6 DEFAULT '0' FOR MONTH_EVENT_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_7 DEFAULT '0' FOR MONTH_EVENT_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_8 DEFAULT '0' FOR MONTH_EVENT_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_9 DEFAULT '0' FOR MONTH_EVENT_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_10 DEFAULT '0' FOR MONTH_EVENT_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_11 DEFAULT '0' FOR MONTH_EVENT_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_EVENT_12 DEFAULT '0' FOR MONTH_EVENT_12
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_1 DEFAULT '0' FOR MONTH_FAVORITE_1
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_2 DEFAULT '0' FOR MONTH_FAVORITE_2
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_3 DEFAULT '0' FOR MONTH_FAVORITE_3
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_4 DEFAULT '0' FOR MONTH_FAVORITE_4
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_5 DEFAULT '0' FOR MONTH_FAVORITE_5
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_6 DEFAULT '0' FOR MONTH_FAVORITE_6
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_7 DEFAULT '0' FOR MONTH_FAVORITE_7
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_8 DEFAULT '0' FOR MONTH_FAVORITE_8
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_9 DEFAULT '0' FOR MONTH_FAVORITE_9
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_10 DEFAULT '0' FOR MONTH_FAVORITE_10
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_11 DEFAULT '0' FOR MONTH_FAVORITE_11
GO
ALTER TABLE B_STAT_DAY_SITE ADD CONSTRAINT DF_B_STAT_DAY_SITE_MONTH_FAVORITE_12 DEFAULT '0' FOR MONTH_FAVORITE_12
GO
CREATE UNIQUE INDEX UX_B_STAT_DAY_SITE_1 ON B_STAT_DAY_SITE (SITE_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_EVENT
(
	ID int NOT NULL IDENTITY (1, 1),
	EVENT1 varchar(200) NULL,
	EVENT2 varchar(200) NULL,
	MONEY decimal(18,4) NOT NULL,
	DATE_ENTER datetime NULL,
	DATE_CLEANUP datetime NULL,
	C_SORT int NULL,
	COUNTER int NOT NULL,
	ADV_VISIBLE char(1) NOT NULL,
	NAME varchar(50) NULL,
	DESCRIPTION varchar(8000) NULL,
	KEEP_DAYS int NULL,
	DYNAMIC_KEEP_DAYS int NULL,
	DIAGRAM_DEFAULT char(1) NOT NULL
)
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT PK_B_STAT_EVENT PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT DF_B_STAT_EVENT_MONEY DEFAULT '0.0000' FOR MONEY
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT DF_B_STAT_EVENT_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT DF_B_STAT_EVENT_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT DF_B_STAT_EVENT_ADV_VISIBLE DEFAULT 'Y' FOR ADV_VISIBLE
GO
ALTER TABLE B_STAT_EVENT ADD CONSTRAINT DF_B_STAT_EVENT_DIAGRAM_DEFAULT DEFAULT 'Y' FOR DIAGRAM_DEFAULT
GO
CREATE INDEX IX_B_STAT_EVENT_1 ON B_STAT_EVENT (EVENT1, EVENT2)
GO
CREATE INDEX IX_B_STAT_EVENT_2 ON b_stat_event (KEEP_DAYS, ID)
GO

CREATE TABLE B_STAT_EVENT_DAY
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_STAT datetime NULL,
	DATE_LAST datetime NULL,
	EVENT_ID int NOT NULL,
	MONEY decimal(18,4) NOT NULL,
	COUNTER int NOT NULL
)
GO
ALTER TABLE B_STAT_EVENT_DAY ADD CONSTRAINT PK_B_STAT_EVENT_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_EVENT_DAY ADD CONSTRAINT DF_B_STAT_EVENT_DAY_EVENT_ID DEFAULT '0' FOR EVENT_ID
GO
ALTER TABLE B_STAT_EVENT_DAY ADD CONSTRAINT DF_B_STAT_EVENT_DAY_MONEY DEFAULT '0.0000' FOR MONEY
GO
ALTER TABLE B_STAT_EVENT_DAY ADD CONSTRAINT DF_B_STAT_EVENT_DAY_COUNTER DEFAULT '0' FOR COUNTER
GO
CREATE INDEX IX_B_STAT_EVENT_DAY_1 ON B_STAT_EVENT_DAY (EVENT_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_EVENT_LIST
(
	ID int NOT NULL IDENTITY (1, 1),
	EVENT_ID int NOT NULL,
	EVENT3 varchar(255) NULL,
	MONEY decimal(18,4) NOT NULL,
	DATE_ENTER datetime NOT NULL,
	REFERER_URL varchar(8000) NULL,
	URL varchar(8000) NULL,
	REDIRECT_URL varchar(8000) NULL,
	SESSION_ID int NULL,
	GUEST_ID int NULL,
	ADV_ID int NULL,
	ADV_BACK char(1) NOT NULL,
	HIT_ID int NULL,
	COUNTRY_ID char(2) NULL,
	KEEP_DAYS int NULL,
	CHARGEBACK char(1) NOT NULL,
	SITE_ID char(2) NULL,
	REFERER_SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT PK_B_STAT_EVENT_LIST PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT DF_B_STAT_EVENT_LIST_EVENT_ID DEFAULT '0' FOR EVENT_ID
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT DF_B_STAT_EVENT_LIST_MONEY DEFAULT '0.0000' FOR MONEY
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT DF_B_STAT_EVENT_LIST_DATE_ENTER DEFAULT GETDATE() FOR DATE_ENTER
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT DF_B_STAT_EVENT_LIST_ADV_BACK DEFAULT 'N' FOR ADV_BACK
GO
ALTER TABLE B_STAT_EVENT_LIST ADD CONSTRAINT DF_B_STAT_EVENT_LIST_CHARGEBACK DEFAULT 'N' FOR CHARGEBACK
GO
CREATE INDEX IX_B_STAT_EVENT_LIST_1 ON B_STAT_EVENT_LIST (GUEST_ID)
GO
CREATE INDEX IX_B_STAT_EVENT_LIST_2 ON b_stat_event_list (EVENT_ID, DATE_ENTER)
GO
CREATE INDEX IX_B_STAT_EVENT_LIST_3 ON b_stat_event_list (KEEP_DAYS, DATE_ENTER)
GO

CREATE TABLE B_STAT_GUEST
(
	ID int NOT NULL IDENTITY (1, 1),
	TIMESTAMP_X datetime NOT NULL,
	FAVORITES char(1) NOT NULL,
	C_EVENTS int NOT NULL,
	SESSIONS int NOT NULL,
	HITS int NOT NULL,
	REPAIR char(1) NOT NULL,
	FIRST_SESSION_ID int NULL,
	FIRST_DATE datetime NULL,
	FIRST_URL_FROM varchar(8000) NULL,
	FIRST_URL_TO varchar(8000) NULL,
	FIRST_URL_TO_404 char(1) NOT NULL,
	FIRST_SITE_ID char(2) NULL,
	FIRST_ADV_ID int NULL,
	FIRST_REFERER1 varchar(255) NULL,
	FIRST_REFERER2 varchar(255) NULL,
	FIRST_REFERER3 varchar(255) NULL,
	LAST_SESSION_ID int NULL,
	LAST_DATE datetime NULL,
	LAST_USER_ID int NULL,
	LAST_USER_AUTH char(1) NULL,
	LAST_URL_LAST varchar(8000) NULL,
	LAST_URL_LAST_404 char(1) NOT NULL,
	LAST_USER_AGENT varchar(8000) NULL,
	LAST_IP varchar(15) NULL,
	LAST_COOKIE varchar(8000) NULL,
	LAST_LANGUAGE varchar(255) NULL,
	LAST_ADV_ID int NULL,
	LAST_ADV_BACK char(1) NOT NULL,
	LAST_REFERER1 varchar(255) NULL,
	LAST_REFERER2 varchar(255) NULL,
	LAST_REFERER3 varchar(255) NULL,
	LAST_SITE_ID char(2) NULL,
	LAST_COUNTRY_ID char(2) NULL,
	LAST_CITY_ID int NULL,
	LAST_CITY_INFO varchar(8000) NULL
)
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT PK_B_STAT_GUEST PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_FAVORITES DEFAULT 'N' FOR FAVORITES
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_REPAIR DEFAULT 'N' FOR REPAIR
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_FIRST_URL_TO_404 DEFAULT 'N' FOR FIRST_URL_TO_404
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_LAST_URL_LAST_404 DEFAULT 'N' FOR LAST_URL_LAST_404
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_LAST_ADV_BACK DEFAULT 'N' FOR LAST_ADV_BACK
GO
ALTER TABLE B_STAT_GUEST ADD CONSTRAINT DF_B_STAT_GUEST_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO
CREATE INDEX IX_B_STAT_GUEST_0 ON B_STAT_GUEST(LAST_DATE)
GO

create trigger B_STAT_GUEST_UPDATE on B_STAT_GUEST for update as
if (not update(TIMESTAMP_X))
begin
	UPDATE B_STAT_GUEST SET
		TIMESTAMP_X = GETDATE()
	FROM
		B_STAT_GUEST U,
		INSERTED I,
		DELETED D
	WHERE
		U.ID = I.ID
	and U.ID = D.ID
end
GO


CREATE TABLE B_STAT_HIT
(
	ID int NOT NULL IDENTITY (1, 1),
	SESSION_ID int NOT NULL,
	DATE_HIT datetime NULL,
	GUEST_ID int NULL,
	NEW_GUEST char(1) NOT NULL,
	USER_ID int NULL,
	USER_AUTH char(1) NULL,
	URL varchar(8000) NULL,
	URL_404 char(1) NOT NULL,
	URL_FROM varchar(8000) NULL,
	IP varchar(15) NULL,
	METHOD varchar(10) NULL,
	COOKIES varchar(8000) NULL,
	USER_AGENT varchar(8000) NULL,
	STOP_LIST_ID int NULL,
	COUNTRY_ID char(2) NULL,
	CITY_ID int NULL,
	SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_HIT ADD CONSTRAINT PK_B_STAT_HIT PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_HIT ADD CONSTRAINT DF_B_STAT_HIT_SESSION_ID DEFAULT '0' FOR SESSION_ID
GO
ALTER TABLE B_STAT_HIT ADD CONSTRAINT DF_B_STAT_HIT_NEW_GUEST DEFAULT 'N' FOR NEW_GUEST
GO
ALTER TABLE B_STAT_HIT ADD CONSTRAINT DF_B_STAT_HIT_URL_404 DEFAULT 'N' FOR URL_404
GO
CREATE INDEX IX_B_STAT_HIT_0 ON B_STAT_HIT(DATE_HIT)
GO


CREATE TABLE B_STAT_SEARCHER_HIT
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_HIT datetime NULL,
	SEARCHER_ID int NOT NULL,
	URL varchar(8000) NOT NULL,
	URL_404 char(1) NOT NULL,
	IP varchar(15) NULL,
	USER_AGENT varchar(8000) NULL,
	HIT_KEEP_DAYS int NULL,
	SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_SEARCHER_HIT ADD CONSTRAINT PK_B_STAT_SEARCHER_HIT PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_SEARCHER_HIT ADD CONSTRAINT DF_B_STAT_SEARCHER_HIT_SEARCHER_ID DEFAULT '0' FOR SEARCHER_ID
GO
ALTER TABLE B_STAT_SEARCHER_HIT ADD CONSTRAINT DF_B_STAT_SEARCHER_HIT_URL_404 DEFAULT 'N' FOR URL_404
GO
CREATE INDEX IX_B_STAT_SEARCHER_HIT_1 ON b_stat_searcher_hit (SEARCHER_ID, DATE_HIT)
GO
CREATE INDEX IX_B_STAT_SEARCHER_HIT_2 ON b_stat_searcher_hit (HIT_KEEP_DAYS, DATE_HIT)
GO

CREATE TABLE B_STAT_PHRASE_LIST
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_HIT datetime NOT NULL,
	SEARCHER_ID int NULL,
	REFERER_ID int NULL,
	PHRASE varchar(255) NOT NULL,
	URL_FROM varchar(8000) NULL,
	URL_TO varchar(8000) NULL,
	URL_TO_404 char(1) NOT NULL,
	SESSION_ID int NULL,
	SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_PHRASE_LIST ADD CONSTRAINT PK_B_STAT_PHRASE_LIST PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PHRASE_LIST ADD CONSTRAINT DF_B_STAT_PHRASE_LIST_URL_TO_404 DEFAULT 'N' FOR URL_TO_404
GO
ALTER TABLE B_STAT_PHRASE_LIST ADD CONSTRAINT DF_B_STAT_PHRASE_LIST_DATE_HIT DEFAULT GETDATE() FOR DATE_HIT
GO
CREATE INDEX IX_B_STAT_PHRASE_LIST_0 ON B_STAT_PHRASE_LIST(DATE_HIT)
GO

CREATE TABLE B_STAT_REFERER
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_FIRST datetime NOT NULL,
	DATE_LAST datetime NOT NULL,
	SITE_NAME varchar(255) NOT NULL,
	SESSIONS int NOT NULL,
	HITS int NOT NULL
)
GO
ALTER TABLE B_STAT_REFERER ADD CONSTRAINT PK_B_STAT_REFERER PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_STAT_REFERER_1 ON B_STAT_REFERER (SITE_NAME)
GO
CREATE INDEX IX_B_STAT_REFERER_2 ON b_stat_referer(DATE_LAST, ID)
GO
ALTER TABLE B_STAT_REFERER ADD CONSTRAINT DF_B_STAT_REFERER_DATE_FIRST DEFAULT GETDATE() FOR DATE_FIRST
GO
ALTER TABLE B_STAT_REFERER ADD CONSTRAINT DF_B_STAT_REFERER_DATE_LAST DEFAULT GETDATE() FOR DATE_LAST
GO
ALTER TABLE B_STAT_REFERER ADD CONSTRAINT DF_B_STAT_REFERER_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_REFERER ADD CONSTRAINT DF_B_STAT_REFERER_HITS DEFAULT '0' FOR HITS
GO


CREATE TABLE B_STAT_REFERER_LIST
(
	ID int NOT NULL IDENTITY (1, 1),
	REFERER_ID int NULL,
	DATE_HIT datetime NULL,
	PROTOCOL varchar(10) NOT NULL,
	SITE_NAME varchar(255) NOT NULL,
	URL_FROM varchar(8000) NOT NULL,
	URL_TO varchar(8000) NULL,
	URL_TO_404 char(1) NOT NULL,
	SESSION_ID int NULL,
	ADV_ID int NULL,
	SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_REFERER_LIST ADD CONSTRAINT PK_B_STAT_REFERER_LIST PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_REFERER_LIST ADD CONSTRAINT DF_B_STAT_REFERER_LIST_URL_TO_404 DEFAULT 'N' FOR URL_TO_404
GO
CREATE INDEX IX_B_STAT_REFERER_LIST_0 ON B_STAT_REFERER_LIST(DATE_HIT)
GO
CREATE INDEX IX_B_STAT_REFERER_LIST_1 ON B_STAT_REFERER_LIST(SITE_NAME)
GO

CREATE TABLE B_STAT_SEARCHER
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_CLEANUP datetime NULL,
	TOTAL_HITS int NOT NULL,
	SAVE_STATISTIC char(1) NOT NULL,
	ACTIVE char(1) NOT NULL,
	NAME varchar(255) NOT NULL,
	USER_AGENT varchar(8000) NULL,
	DIAGRAM_DEFAULT char(1) NOT NULL,
	HIT_KEEP_DAYS int NULL,
	DYNAMIC_KEEP_DAYS int NULL,
	PHRASES int NOT NULL,
	PHRASES_HITS int NOT NULL,
	CHECK_ACTIVITY char(1) NOT NULL
)
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT PK_B_STAT_SEARCHER PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_TOTAL_HITS DEFAULT '0' FOR TOTAL_HITS
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_SAVE_STATISTIC DEFAULT 'Y' FOR SAVE_STATISTIC
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_DIAGRAM_DEFAULT DEFAULT 'N' FOR DIAGRAM_DEFAULT
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_PHRASES DEFAULT '0' FOR PHRASES
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_PHRASES_HITS DEFAULT '0' FOR PHRASES_HITS
GO
ALTER TABLE B_STAT_SEARCHER ADD CONSTRAINT DF_B_STAT_SEARCHER_CHECK_ACTIVITY DEFAULT 'Y' FOR CHECK_ACTIVITY
GO
CREATE INDEX IX_B_STAT_SEARCHER_1 ON b_stat_searcher (HIT_KEEP_DAYS, ID)
GO

CREATE TABLE B_STAT_SEARCHER_PARAMS
(
	ID int NOT NULL IDENTITY (1, 1),
	SEARCHER_ID int NOT NULL,
	DOMAIN varchar(255) NULL,
	VARIABLE varchar(255) NULL,
	CHAR_SET varchar(255) NULL
)
GO
ALTER TABLE B_STAT_SEARCHER_PARAMS ADD CONSTRAINT PK_B_STAT_SEARCHER_PARAMS PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_SEARCHER_PARAMS ADD CONSTRAINT DF_B_STAT_SEARCHER_PARAMS_SEARCHER_ID DEFAULT '0' FOR SEARCHER_ID
GO
CREATE INDEX IX_B_STAT_SEARCHER_PARAMS_1 ON B_STAT_SEARCHER_PARAMS (SEARCHER_ID, DOMAIN)
GO


CREATE TABLE B_STAT_SESSION
(
	ID int NOT NULL IDENTITY (1, 1),
	GUEST_ID int NULL,
	NEW_GUEST char(1) NOT NULL,
	USER_ID int NULL,
	USER_AUTH char(1) NULL,
	C_EVENTS int NOT NULL,
	HITS int NOT NULL,
	FAVORITES char(1) NOT NULL,
	URL_FROM varchar(8000) NULL,
	URL_TO varchar(8000) NULL,
	URL_TO_404 char(1) NOT NULL,
	URL_LAST varchar(8000) NULL,
	URL_LAST_404 char(1) NOT NULL,
	USER_AGENT varchar(8000) NULL,
	DATE_STAT datetime NULL,
	DATE_FIRST datetime NULL,
	DATE_LAST datetime NULL,
	IP_FIRST varchar(15) NULL,
	IP_FIRST_NUMBER bigint NULL,
	IP_LAST varchar(15) NULL,
	IP_LAST_NUMBER bigint NULL,
	FIRST_HIT_ID int NULL,
	LAST_HIT_ID int NULL,
	PHPSESSID varchar(255),
	ADV_ID int NULL,
	ADV_BACK char(1) NULL,
	REFERER1 varchar(255) NULL,
	REFERER2 varchar(255) NULL,
	REFERER3 varchar(255) NULL,
	STOP_LIST_ID int NULL,
	COUNTRY_ID char(2) NULL,
	CITY_ID int NULL,
	FIRST_SITE_ID char(2) NULL,
	LAST_SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT PK_B_STAT_SESSION PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_NEW_GUEST DEFAULT 'N' FOR NEW_GUEST
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_FAVORITES DEFAULT 'N' FOR FAVORITES
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_URL_TO_404 DEFAULT 'N' FOR URL_TO_404
GO
ALTER TABLE B_STAT_SESSION ADD CONSTRAINT DF_B_STAT_SESSION_URL_LAST_404 DEFAULT 'N' FOR URL_LAST_404
GO
CREATE INDEX IX_B_STAT_SESSION_2 ON B_STAT_SESSION (DATE_STAT)
GO
CREATE INDEX IX_B_STAT_SESSION_3 ON B_STAT_SESSION(IP_FIRST_NUMBER, DATE_STAT)
GO
CREATE INDEX IX_B_STAT_SESSION_4 ON B_STAT_SESSION(USER_ID, DATE_STAT)
GO
CREATE INDEX IX_B_STAT_SESSION_5 ON B_STAT_SESSION (DATE_LAST)
GO
CREATE INDEX IX_B_STAT_SESSION_6 ON B_STAT_SESSION (GUEST_ID)
GO

CREATE TABLE B_STAT_PAGE
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_STAT datetime NOT NULL,
	DIR char(1) NOT NULL,
	URL varchar(2000) NOT NULL,
	URL_404 char(1) NOT NULL,
	URL_HASH bigint NULL,
	SITE_ID char(2) NULL,
	COUNTER int NOT NULL,
	ENTER_COUNTER int NOT NULL,
	EXIT_COUNTER int NOT NULL
)
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT PK_B_STAT_PAGE PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT DF_B_STAT_PAGE_DIR DEFAULT 'N' FOR DIR
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT DF_B_STAT_PAGE_URL_404 DEFAULT 'N' FOR URL_404
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT DF_B_STAT_PAGE_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT DF_B_STAT_PAGE_ENTER_COUNTER DEFAULT '0' FOR ENTER_COUNTER
GO
ALTER TABLE B_STAT_PAGE ADD CONSTRAINT DF_B_STAT_PAGE_EXIT_COUNTER DEFAULT '0' FOR EXIT_COUNTER
GO
CREATE INDEX IX_B_STAT_PAGE_1 ON B_STAT_PAGE (DATE_STAT)
GO
CREATE INDEX IX_B_STAT_PAGE_2 ON B_STAT_PAGE (URL_HASH)
GO


CREATE TABLE B_STOP_LIST
(
	ID int NOT NULL IDENTITY (1, 1),
	TIMESTAMP_X datetime NOT NULL,
	DATE_START datetime NULL,
	DATE_END datetime NULL,
	ACTIVE char(1) NOT NULL,
	SAVE_STATISTIC char(1) NOT NULL,
	IP_1 int NULL,
	IP_2 int NULL,
	IP_3 int NULL,
	IP_4 int NULL,
	MASK_1 int NULL,
	MASK_2 int NULL,
	MASK_3 int NULL,
	MASK_4 int NULL,
	USER_AGENT varchar(8000) NULL,
	USER_AGENT_IS_NULL char(1) NOT NULL,
	URL_TO varchar(8000) NULL,
	URL_FROM varchar(8000) NULL,
	MESSAGE varchar(8000) NULL,
	MESSAGE_LID char(2) NOT NULL,
	URL_REDIRECT varchar(8000) NULL,
	COMMENTS varchar(8000) NULL,
	TEST char(1) NOT NULL,
	SITE_ID char(2) NULL
)
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT PK_B_STOP_LIST PRIMARY KEY (ID)
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_SAVE_STATISTIC DEFAULT 'N' FOR SAVE_STATISTIC
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_USER_AGENT_IS_NULL DEFAULT 'N' FOR USER_AGENT_IS_NULL
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_MESSAGE_LID DEFAULT 'en' FOR MESSAGE_LID
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_TEST DEFAULT 'N' FOR TEST
GO
ALTER TABLE B_STOP_LIST ADD CONSTRAINT DF_B_STOP_LIST_TIMESTAMP_X DEFAULT GETDATE() FOR TIMESTAMP_X
GO

create trigger B_STOP_LIST_UPDATE on B_STOP_LIST for update as
if (not update(TIMESTAMP_X))
begin
	UPDATE B_STOP_LIST SET
		TIMESTAMP_X = GETDATE()
	FROM
		B_STOP_LIST U,
		INSERTED I,
		DELETED D
	WHERE
		U.ID = I.ID
	and U.ID = D.ID
end
GO



CREATE TABLE B_STAT_BROWSER
(
	ID int NOT NULL IDENTITY (1, 1),
	USER_AGENT varchar(255) NOT NULL
)
GO
ALTER TABLE B_STAT_BROWSER ADD CONSTRAINT PK_B_STAT_BROWSER PRIMARY KEY (ID)
GO


CREATE TABLE B_STAT_ADV_DAY
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NOT NULL,
	DATE_STAT datetime NULL,
	GUESTS int NOT NULL,
	GUESTS_DAY int NOT NULL,
	NEW_GUESTS int NOT NULL,
	FAVORITES int NOT NULL,
	C_HOSTS int NOT NULL,
	C_HOSTS_DAY int NOT NULL,
	SESSIONS int NOT NULL,
	HITS int NOT NULL,
	GUESTS_BACK int NOT NULL,
	GUESTS_DAY_BACK int NOT NULL,
	FAVORITES_BACK int NOT NULL,
	HOSTS_BACK int NOT NULL,
	HOSTS_DAY_BACK int NOT NULL,
	SESSIONS_BACK int NOT NULL,
	HITS_BACK int NOT NULL
)
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT PK_B_STAT_ADV_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_GUESTS DEFAULT '0' FOR GUESTS
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_GUESTS_DAY DEFAULT '0' FOR GUESTS_DAY
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_FAVORITES DEFAULT '0' FOR FAVORITES
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_C_HOSTS DEFAULT '0' FOR C_HOSTS
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_C_HOSTS_DAY DEFAULT '0' FOR C_HOSTS_DAY
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_GUESTS_BACK DEFAULT '0' FOR GUESTS_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_GUESTS_DAY_BACK DEFAULT '0' FOR GUESTS_DAY_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_FAVORITES_BACK DEFAULT '0' FOR FAVORITES_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_HOSTS_BACK DEFAULT '0' FOR HOSTS_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_HOSTS_DAY_BACK DEFAULT '0' FOR HOSTS_DAY_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_SESSIONS_BACK DEFAULT '0' FOR SESSIONS_BACK
GO
ALTER TABLE B_STAT_ADV_DAY ADD CONSTRAINT DF_B_STAT_ADV_DAY_HITS_BACK DEFAULT '0' FOR HITS_BACK
GO
CREATE INDEX IX_B_STAT_ADV_DAY_0 ON B_STAT_ADV_DAY(DATE_STAT)
GO
CREATE INDEX IX_B_STAT_ADV_DAY_1 ON B_STAT_ADV_DAY (ADV_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_ADV_EVENT_DAY
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NULL,
	EVENT_ID int NULL,
	DATE_STAT datetime NULL,
	COUNTER int NOT NULL,
	COUNTER_BACK int NOT NULL,
	MONEY decimal(18,4) NOT NULL,
	MONEY_BACK decimal(18,4) NOT NULL
)
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT PK_B_STAT_ADV_EVENT_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_EVENT_ID DEFAULT '0' FOR EVENT_ID
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_COUNTER_BACK DEFAULT '0' FOR COUNTER_BACK
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_MONEY DEFAULT '0.0000' FOR MONEY
GO
ALTER TABLE B_STAT_ADV_EVENT_DAY ADD CONSTRAINT DF_B_STAT_ADV_EVENT_DAY_MONEY_BACK DEFAULT '0.0000' FOR MONEY_BACK
GO
CREATE INDEX IX_B_STAT_ADV_EVENT_DAY_0 ON B_STAT_ADV_EVENT_DAY(DATE_STAT)
GO
CREATE INDEX IX_B_STAT_ADV_EVENT_DAY_1 ON B_STAT_ADV_EVENT_DAY (ADV_ID, EVENT_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_SEARCHER_DAY
(
ID int NOT NULL IDENTITY (1, 1),
DATE_STAT datetime NULL,
DATE_LAST datetime NULL,
SEARCHER_ID int NOT NULL,
TOTAL_HITS int NOT NULL
)
GO
ALTER TABLE B_STAT_SEARCHER_DAY ADD CONSTRAINT PK_B_STAT_SEARCHER_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_SEARCHER_DAY ADD CONSTRAINT DF_B_STAT_SEARCHER_DAY_SEARCHER_ID DEFAULT '0' FOR SEARCHER_ID
GO
ALTER TABLE B_STAT_SEARCHER_DAY ADD CONSTRAINT DF_B_STAT_SEARCHER_DAY_TOTAL_HITS DEFAULT '0' FOR TOTAL_HITS
GO
CREATE INDEX IX_B_STAT_SEARCHER_DAY_1 ON B_STAT_SEARCHER_DAY (SEARCHER_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_COUNTRY
(
	ID char(2) NOT NULL,
	SHORT_NAME char(3) NULL,
	NAME varchar(50) NULL,
	SESSIONS int NOT NULL,
	NEW_GUESTS int NOT NULL,
	HITS int NOT NULL,
	C_EVENTS int NOT NULL
)
GO
ALTER TABLE B_STAT_COUNTRY ADD CONSTRAINT PK_B_STAT_COUNTRY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_COUNTRY ADD CONSTRAINT DF_B_STAT_COUNTRY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_COUNTRY ADD CONSTRAINT DF_B_STAT_COUNTRY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_COUNTRY ADD CONSTRAINT DF_B_STAT_COUNTRY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_COUNTRY ADD CONSTRAINT DF_B_STAT_COUNTRY_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO

CREATE TABLE B_STAT_CITY
(
    ID int NOT NULL IDENTITY (1, 1),
    COUNTRY_ID char(2) NOT NULL,
    REGION varchar(255) NULL,
    NAME varchar(255) NULL,
    XML_ID varchar(255) NULL,
    SESSIONS int NOT NULL,
    NEW_GUESTS int NOT NULL,
    HITS int NOT NULL,
    C_EVENTS int NOT NULL
)
GO
ALTER TABLE B_STAT_CITY ADD CONSTRAINT PK_B_STAT_CITY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_CITY ADD CONSTRAINT DF_B_STAT_CITY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_CITY ADD CONSTRAINT DF_B_STAT_CITY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_CITY ADD CONSTRAINT DF_B_STAT_CITY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_CITY ADD CONSTRAINT DF_B_STAT_CITY_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
CREATE INDEX UX_B_STAT_CITY ON B_STAT_CITY(COUNTRY_ID, REGION, NAME)
GO
CREATE INDEX IX_B_STAT_CITY_XML_ID ON B_STAT_CITY(XML_ID)
GO

CREATE TABLE B_STAT_CITY_DAY
(
    ID int NOT NULL IDENTITY (1, 1),
    CITY_ID int NOT NULL,
    DATE_STAT datetime NOT NULL,
    SESSIONS int NOT NULL,
    NEW_GUESTS int NOT NULL,
    HITS int NOT NULL,
    C_EVENTS int NOT NULL
)
GO
ALTER TABLE B_STAT_CITY_DAY ADD CONSTRAINT PK_B_STAT_CITY_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_CITY_DAY ADD CONSTRAINT DF_B_STAT_CITY_DAY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_CITY_DAY ADD CONSTRAINT DF_B_STAT_CITY_DAY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_CITY_DAY ADD CONSTRAINT DF_B_STAT_CITY_DAY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_CITY_DAY ADD CONSTRAINT DF_B_STAT_CITY_DAY_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
CREATE INDEX IX_B_STAT_CITY_DAY_1 ON B_STAT_CITY_DAY(CITY_ID, DATE_STAT)
GO
CREATE INDEX IX_B_STAT_CITY_DAY_2 ON B_STAT_CITY_DAY(DATE_STAT)
GO

CREATE TABLE B_STAT_CITY_IP
(
	START_IP bigint NOT NULL,
	END_IP bigint NOT NULL,
	COUNTRY_ID char(2) NOT NULL,
	CITY_ID int NOT NULL
)
GO
ALTER TABLE B_STAT_CITY_IP ADD CONSTRAINT PK_B_STAT_CITY_IP PRIMARY KEY (START_IP)
GO
CREATE INDEX IX_B_STAT_CITY_IP_END_IP on B_STAT_CITY_IP(END_IP)
GO

CREATE TABLE B_STAT_SESSION_DATA
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_FIRST datetime NULL,
	DATE_LAST datetime NULL,
	GUEST_MD5 varchar(255) NOT NULL,
	SESS_SESSION_ID int NULL,
	SESSION_DATA varchar(8000) NULL
)
GO
ALTER TABLE B_STAT_SESSION_DATA ADD CONSTRAINT PK_B_STAT_SESSION_DATA PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_STAT_SESSION_DATA_1 ON B_STAT_SESSION_DATA (GUEST_MD5)
GO


CREATE TABLE B_STAT_COUNTRY_DAY
(
	ID int NOT NULL IDENTITY (1, 1),
	COUNTRY_ID char(2) NOT NULL,
	DATE_STAT datetime NULL,
	SESSIONS int NOT NULL,
	NEW_GUESTS int NOT NULL,
	HITS int NOT NULL,
	C_EVENTS int NOT NULL
)
GO
ALTER TABLE B_STAT_COUNTRY_DAY ADD CONSTRAINT PK_B_STAT_COUNTRY_DAY PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_COUNTRY_DAY ADD CONSTRAINT DF_B_STAT_COUNTRY_DAY_SESSIONS DEFAULT '0' FOR SESSIONS
GO
ALTER TABLE B_STAT_COUNTRY_DAY ADD CONSTRAINT DF_B_STAT_COUNTRY_DAY_NEW_GUESTS DEFAULT '0' FOR NEW_GUESTS
GO
ALTER TABLE B_STAT_COUNTRY_DAY ADD CONSTRAINT DF_B_STAT_COUNTRY_DAY_HITS DEFAULT '0' FOR HITS
GO
ALTER TABLE B_STAT_COUNTRY_DAY ADD CONSTRAINT DF_B_STAT_COUNTRY_DAY_C_EVENTS DEFAULT '0' FOR C_EVENTS
GO
CREATE INDEX IX_B_STAT_COUNTRY_DAY_1 ON B_STAT_COUNTRY_DAY (COUNTRY_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_PATH
(
	ID int NOT NULL IDENTITY (1, 1),
	PATH_ID int NOT NULL,
	PARENT_PATH_ID int NULL,
	DATE_STAT datetime NULL,
	COUNTER int NOT NULL,
	COUNTER_ABNORMAL int NOT NULL,
	COUNTER_FULL_PATH int NOT NULL,
	PAGES varchar(8000) NULL,
	FIRST_PAGE varchar(255) NULL,
	FIRST_PAGE_404 char(1) NOT NULL,
	FIRST_PAGE_SITE_ID char(2) NULL,
	PREV_PAGE varchar(255) NULL,
	PREV_PAGE_HASH int NULL,
	LAST_PAGE varchar(255) NULL,
	LAST_PAGE_404 char(1) NOT NULL,
	LAST_PAGE_SITE_ID char(2) NULL,
	LAST_PAGE_HASH int NULL,
	STEPS int NOT NULL
)
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT PK_B_STAT_PATH PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_PATH_ID DEFAULT '0' FOR PATH_ID
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_COUNTER_ABNORMAL DEFAULT '0' FOR COUNTER_ABNORMAL
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_COUNTER_FULL_PATH DEFAULT '0' FOR COUNTER_FULL_PATH
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_FIRST_PAGE_404 DEFAULT 'N' FOR FIRST_PAGE_404
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_LAST_PAGE_404 DEFAULT 'N' FOR LAST_PAGE_404
GO
ALTER TABLE B_STAT_PATH ADD CONSTRAINT DF_B_STAT_PATH_STEPS DEFAULT '1' FOR STEPS
GO
CREATE INDEX IX_B_STAT_PATH_0 ON B_STAT_PATH(DATE_STAT)
GO
CREATE INDEX IX_B_STAT_PATH_3 ON B_STAT_PATH(PATH_ID, DATE_STAT)
GO
CREATE INDEX IX_B_STAT_PATH_2 ON B_STAT_PATH (PREV_PAGE_HASH, LAST_PAGE_HASH)
GO


CREATE TABLE B_STAT_PATH_ADV
(
	ID int NOT NULL IDENTITY (1, 1),
	ADV_ID int NOT NULL,
	PATH_ID int NOT NULL,
	DATE_STAT datetime NULL,
	COUNTER int NOT NULL,
	COUNTER_BACK int NOT NULL,
	COUNTER_FULL_PATH int NOT NULL,
	COUNTER_FULL_PATH_BACK int NOT NULL,
	STEPS int NOT NULL
)
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT PK_B_STAT_PATH_ADV PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_PATH_ID DEFAULT '0' FOR PATH_ID
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_COUNTER_BACK DEFAULT '0' FOR COUNTER_BACK
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_COUNTER_FULL_PATH DEFAULT '0' FOR COUNTER_FULL_PATH
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_COUNTER_FULL_PATH_BACK DEFAULT '0' FOR COUNTER_FULL_PATH_BACK
GO
ALTER TABLE B_STAT_PATH_ADV ADD CONSTRAINT DF_B_STAT_PATH_ADV_STEPS DEFAULT '0' FOR STEPS
GO
CREATE INDEX IX_B_STAT_PATH_ADV_0 ON B_STAT_PATH_ADV(DATE_STAT)
GO
CREATE INDEX IX_B_STAT_PATH_ADV_2 ON B_STAT_PATH_ADV(PATH_ID, ADV_ID, DATE_STAT)
GO


CREATE TABLE B_STAT_PATH_CACHE
(
	ID int NOT NULL IDENTITY (1, 1),
	SESSION_ID int NOT NULL,
	DATE_HIT datetime NULL,
	PATH_ID int NULL,
	PATH_PAGES varchar(8000) NULL,
	PATH_FIRST_PAGE varchar(255) NULL,
	PATH_FIRST_PAGE_404 char(1) NOT NULL,
	PATH_FIRST_PAGE_SITE_ID char(2) NULL,
	PATH_LAST_PAGE varchar(255) NULL,
	PATH_LAST_PAGE_404 char(1) NOT NULL,
	PATH_LAST_PAGE_SITE_ID char(2) NULL,
	PATH_STEPS int NOT NULL,
	IS_LAST_PAGE char(1) NOT NULL
)
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT PK_B_STAT_PATH_CACHE PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT DF_B_STAT_PATH_CACHE_SESSION_ID DEFAULT '0' FOR SESSION_ID
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT DF_B_STAT_PATH_CACHE_PATH_FIRST_PAGE_404 DEFAULT 'N' FOR PATH_FIRST_PAGE_404
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT DF_B_STAT_PATH_CACHE_PATH_LAST_PAGE_404 DEFAULT 'N' FOR PATH_LAST_PAGE_404
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT DF_B_STAT_PATH_CACHE_PATH_STEPS DEFAULT '1' FOR PATH_STEPS
GO
ALTER TABLE B_STAT_PATH_CACHE ADD CONSTRAINT DF_B_STAT_PATH_CACHE_IS_LAST_PAGE DEFAULT 'Y' FOR IS_LAST_PAGE
GO
CREATE INDEX IX_B_STAT_PATH_CACHE_1 ON B_STAT_PATH_CACHE (SESSION_ID)
GO


CREATE TABLE B_STAT_PAGE_ADV
(
	ID int NOT NULL IDENTITY (1, 1),
	DATE_STAT datetime NULL,
	PAGE_ID int NOT NULL,
	ADV_ID int NOT NULL,
	COUNTER int NOT NULL,
	ENTER_COUNTER int NOT NULL,
	EXIT_COUNTER int NOT NULL,
	COUNTER_BACK int NOT NULL,
	ENTER_COUNTER_BACK int NOT NULL,
	EXIT_COUNTER_BACK int NOT NULL
)
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT PK_B_STAT_PAGE_ADV PRIMARY KEY (ID)
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_PAGE_ID DEFAULT '0' FOR PAGE_ID
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_ADV_ID DEFAULT '0' FOR ADV_ID
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_COUNTER DEFAULT '0' FOR COUNTER
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_ENTER_COUNTER DEFAULT '0' FOR ENTER_COUNTER
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_EXIT_COUNTER DEFAULT '0' FOR EXIT_COUNTER
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_COUNTER_BACK DEFAULT '0' FOR COUNTER_BACK
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_ENTER_COUNTER_BACK DEFAULT '0' FOR ENTER_COUNTER_BACK
GO
ALTER TABLE B_STAT_PAGE_ADV ADD CONSTRAINT DF_B_STAT_PAGE_ADV_EXIT_COUNTER_BACK DEFAULT '0' FOR EXIT_COUNTER_BACK
GO
CREATE INDEX IX_B_STAT_PAGE_ADV_0 ON B_STAT_PAGE_ADV(DATE_STAT)
GO
CREATE INDEX IX_B_STAT_PAGE_ADV_2 ON B_STAT_PAGE_ADV(PAGE_ID, ADV_ID)
GO
CREATE TABLE B_STAT_DDL
(
	ID int NOT NULL IDENTITY (1, 1),
	SQL_TEXT varchar(255) NOT NULL
)
GO
ALTER TABLE B_STAT_DDL ADD CONSTRAINT PK_B_STAT_DDL PRIMARY KEY (ID)
GO
