CREATE TABLE B_STAT_ADV
(
    ID              NUMBER(18)     NOT NULL,
    REFERER1        VARCHAR2(255 CHAR)      NULL,
    REFERER2        VARCHAR2(255 CHAR)      NULL,
    COST            NUMBER(18,4)   DEFAULT 0 NOT NULL,
    REVENUE         NUMBER(18,4)   DEFAULT 0 NOT NULL,
    EVENTS_VIEW     VARCHAR2(255 CHAR)      NULL,
    GUESTS          NUMBER(18)     DEFAULT 0 NOT NULL,
    NEW_GUESTS      NUMBER(18)     DEFAULT 0 NOT NULL,
    FAVORITES       NUMBER(18)     DEFAULT 0 NOT NULL,
    C_HOSTS         NUMBER(18)     DEFAULT 0 NOT NULL,
    SESSIONS        NUMBER(18)     DEFAULT 0 NOT NULL,
    HITS            NUMBER(18)     DEFAULT 0 NOT NULL,
    DATE_FIRST      DATE               NULL,
    DATE_LAST       DATE               NULL,
    GUESTS_BACK     NUMBER(18)     DEFAULT 0 NOT NULL,
    FAVORITES_BACK  NUMBER(18)     DEFAULT 0 NOT NULL,
    HOSTS_BACK      NUMBER(18)     DEFAULT 0 NOT NULL,
    SESSIONS_BACK   NUMBER(18)     DEFAULT 0 NOT NULL,
    HITS_BACK       NUMBER(18)     DEFAULT 0 NOT NULL,
    DESCRIPTION     VARCHAR2(500 CHAR)      NULL,
    PRIORITY        NUMBER(18)     DEFAULT 100 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_ADV_1 ON B_STAT_ADV(REFERER1)
/
CREATE SEQUENCE SQ_B_STAT_ADV
/

CREATE TABLE B_STAT_ADV_DAY
(
    ID              NUMBER(18) NOT NULL,
    ADV_ID          NUMBER(18) NOT NULL,
    DATE_STAT       DATE           NULL,
    GUESTS          NUMBER(18) DEFAULT 0 NOT NULL,
    GUESTS_DAY      NUMBER(18) DEFAULT 0 NOT NULL,
    NEW_GUESTS      NUMBER(18) DEFAULT 0 NOT NULL,
    FAVORITES       NUMBER(18) DEFAULT 0 NOT NULL,
    C_HOSTS         NUMBER(18) DEFAULT 0 NOT NULL,
    C_HOSTS_DAY     NUMBER(18) DEFAULT 0 NOT NULL,
    SESSIONS        NUMBER(18) DEFAULT 0 NOT NULL,
    HITS            NUMBER(18) DEFAULT 0 NOT NULL,
    GUESTS_BACK     NUMBER(18) DEFAULT 0 NOT NULL,
    GUESTS_DAY_BACK NUMBER(18) DEFAULT 0 NOT NULL,
    FAVORITES_BACK  NUMBER(18) DEFAULT 0 NOT NULL,
    HOSTS_BACK      NUMBER(18) DEFAULT 0 NOT NULL,
    HOSTS_DAY_BACK  NUMBER(18) DEFAULT 0 NOT NULL,
    SESSIONS_BACK   NUMBER(18) DEFAULT 0 NOT NULL,
    HITS_BACK       NUMBER(18) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_ADV_DAY_0 ON B_STAT_ADV_DAY(DATE_STAT)
/
CREATE INDEX IX_B_STAT_ADV_DAY_ADV_ID_DATE_ ON B_STAT_ADV_DAY(ADV_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_ADV_DAY
/

CREATE TABLE B_STAT_ADV_EVENT
(
    ID           NUMBER(18)   NOT NULL,
    ADV_ID       NUMBER(18)       NULL,
    EVENT_ID     NUMBER(18)       NULL,
    COUNTER      NUMBER(18)   DEFAULT 0 NOT NULL,
    COUNTER_BACK NUMBER(18)   DEFAULT 0 NOT NULL,
    MONEY        NUMBER(18,4) DEFAULT 0 NOT NULL,
    MONEY_BACK   NUMBER(18,4) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_ADV_EVENT_ID ON B_STAT_ADV_EVENT(ADV_ID,EVENT_ID)
/
CREATE SEQUENCE SQ_B_STAT_ADV_EVENT
/

CREATE TABLE B_STAT_ADV_EVENT_DAY
(
    ID           NUMBER(18)   NOT NULL,
    ADV_ID       NUMBER(18)       NULL,
    EVENT_ID     NUMBER(18)       NULL,
    DATE_STAT    DATE             NULL,
    COUNTER      NUMBER(18)   DEFAULT 0 NOT NULL,
    COUNTER_BACK NUMBER(18)   DEFAULT 0 NOT NULL,
    MONEY        NUMBER(18,4) DEFAULT 0 NOT NULL,
    MONEY_BACK   NUMBER(18,4) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_ADV_EVENT_DAY_0 ON B_STAT_ADV_EVENT_DAY(DATE_STAT)
/
CREATE INDEX IX_B_STAT_ADV_EVENT_DAY_ADV_ID ON B_STAT_ADV_EVENT_DAY(ADV_ID,EVENT_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_ADV_EVENT_DAY
/

CREATE TABLE B_STAT_ADV_GUEST
(
    ID             NUMBER(18)   NOT NULL,
    ADV_ID         NUMBER(18)   NOT NULL,
    BACK           CHAR(1 CHAR)      DEFAULT 'N' NOT NULL,
    DATE_GUEST_HIT DATE             NULL,
    DATE_HOST_HIT  DATE             NULL,
    GUEST_ID       NUMBER(18)   NOT NULL,
    SESSION_ID     NUMBER(18)   NOT NULL,
    IP             VARCHAR2(15 CHAR)     NULL,
    IP_NUMBER      NUMBER(20)       NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_ADV_GUEST_ADV_GUEST ON B_STAT_ADV_GUEST(ADV_ID,GUEST_ID)
/
CREATE INDEX IX_B_STAT_ADV_GUEST_ADV_IP ON B_STAT_ADV_GUEST(ADV_ID,IP_NUMBER)
/
CREATE SEQUENCE SQ_B_STAT_ADV_GUEST
/

CREATE TABLE B_STAT_ADV_PAGE
(
    ID     NUMBER(18)     NOT NULL,
    ADV_ID NUMBER(18)     NOT NULL,
    PAGE   VARCHAR2(2000 CHAR) NOT NULL,
    C_TYPE VARCHAR2(5 CHAR)    DEFAULT 'TO' NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_ADV_PAGE_ADV_ID_TYPE ON B_STAT_ADV_PAGE(ADV_ID,C_TYPE)
/
CREATE SEQUENCE SQ_B_STAT_ADV_PAGE
/

CREATE TABLE B_STAT_ADV_SEARCHER
(
    ID          NUMBER(18) NOT NULL,
    ADV_ID      NUMBER(18) NOT NULL,
    SEARCHER_ID NUMBER(18) NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STAT_ADV_SEARCHER
/
CREATE OR REPLACE TRIGGER B_STAT_ADV_SEARCHER_INSERT
BEFORE INSERT
ON B_STAT_ADV_SEARCHER
FOR EACH ROW
BEGIN
	IF :NEW.ID IS NULL THEN
 		SELECT SQ_B_STAT_ADV_SEARCHER.NEXTVAL INTO :NEW.ID FROM dual;
	END IF;
END;
/


CREATE TABLE B_STAT_BROWSER
(
    ID         NUMBER(18)    NOT NULL,
    USER_AGENT VARCHAR2(255 CHAR) NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STAT_BROWSER
/
CREATE TABLE B_STAT_COUNTRY
(
    ID         CHAR(2 CHAR)      NOT NULL,
    SHORT_NAME VARCHAR2(3 CHAR)      NULL,
    NAME       VARCHAR2(50 CHAR)     NULL,
    SESSIONS   NUMBER(18)   DEFAULT 0 NOT NULL,
    NEW_GUESTS NUMBER(18)   DEFAULT 0 NOT NULL,
    HITS       NUMBER(18)   DEFAULT 0 NOT NULL,
    C_EVENTS   NUMBER(18)   DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/

CREATE TABLE B_STAT_CITY
(
    ID         NUMBER(18)   NOT NULL,
    COUNTRY_ID CHAR(2 CHAR)      NOT NULL,
    REGION     VARCHAR2(200 CHAR)    NULL,
    NAME       VARCHAR2(255 CHAR)    NULL,
    XML_ID     VARCHAR2(255 CHAR)    NULL,
    SESSIONS   NUMBER(18)   DEFAULT 0 NOT NULL,
    NEW_GUESTS NUMBER(18)   DEFAULT 0 NOT NULL,
    HITS       NUMBER(18)   DEFAULT 0 NOT NULL,
    C_EVENTS   NUMBER(18)   DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX UX_B_STAT_CITY on B_STAT_CITY(COUNTRY_ID, REGION, NAME)
/
CREATE INDEX IX_B_STAT_CITY_XML_ID on B_STAT_CITY(XML_ID)
/
CREATE SEQUENCE SQ_B_STAT_CITY
/
CREATE OR REPLACE TRIGGER B_STAT_CITY_INSERT
BEFORE INSERT
ON B_STAT_CITY
FOR EACH ROW
BEGIN
	IF :NEW.ID IS NULL THEN
 		SELECT SQ_B_STAT_CITY.NEXTVAL INTO :NEW.ID FROM dual;
	END IF;
END;
/

CREATE TABLE B_STAT_CITY_DAY
(
    ID         NUMBER(18)  NOT NULL,
    CITY_ID    NUMBER(18)  NOT NULL,
    DATE_STAT  DATE        NOT NULL,
    SESSIONS   NUMBER(18)  DEFAULT 0 NOT NULL,
    NEW_GUESTS NUMBER(18)  DEFAULT 0 NOT NULL,
    HITS       NUMBER(18)  DEFAULT 0 NOT NULL,
    C_EVENTS   NUMBER(18)  DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_CITY_DAY_1 ON B_STAT_CITY_DAY(CITY_ID, DATE_STAT)
/
CREATE INDEX IX_B_STAT_CITY_DAY_2 ON B_STAT_CITY_DAY(DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_CITY_DAY
/

CREATE TABLE B_STAT_CITY_IP
(
	START_IP NUMBER(18) NOT NULL,
	END_IP NUMBER(18) NOT NULL,
	COUNTRY_ID CHAR(2 CHAR) NOT NULL,
	CITY_ID NUMBER(18) NOT NULL,
	PRIMARY KEY (START_IP)
)
/
CREATE INDEX IX_B_STAT_CITY_IP_END_IP on B_STAT_CITY_IP(END_IP)
/

CREATE TABLE B_STAT_DAY
(
    ID                  NUMBER(18)   NOT NULL,
    DATE_STAT           DATE         NOT NULL,
    HITS                NUMBER(18)   DEFAULT 0 NOT NULL,
    C_HOSTS             NUMBER(18)   DEFAULT 0 NOT NULL,
    SESSIONS            NUMBER(18)   DEFAULT 0 NOT NULL,
    C_EVENTS            NUMBER(18)   DEFAULT 0 NOT NULL,
    GUESTS              NUMBER(18)   DEFAULT 0 NOT NULL,
    NEW_GUESTS          NUMBER(18)   DEFAULT 0 NOT NULL,
    FAVORITES           NUMBER(18)   DEFAULT 0 NOT NULL,
    TOTAL_HOSTS         NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_AVERAGE_TIME     NUMBER(18,2) DEFAULT 0 NOT NULL,
    AM_1                NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_1_3              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_3_6              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_6_9              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_9_12             NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_12_15            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_15_18            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_18_21            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_21_24            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_24               NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_AVERAGE_HITS     NUMBER(18,2) DEFAULT 0 NOT NULL,
    AH_1                NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_2_5              NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_6_9              NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_10_13            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_14_17            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_18_21            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_22_25            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_26_29            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_30_33            NUMBER(18)    DEFAULT 0 NOT NULL,
    AH_34               NUMBER(18)    DEFAULT 0 NOT NULL,
    HOUR_HOST_0         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_1         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_2         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_3         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_4         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_5         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_6         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_7         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_8         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_9         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_10        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_11        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_12        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_13        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_14        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_15        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_16        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_17        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_18        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_19        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_20        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_21        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_22        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_23        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_0        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_13       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_14       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_15       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_16       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_17       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_18       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_19       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_20       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_21       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_22       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_23       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_0    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_1    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_2    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_3    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_4    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_5    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_6    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_7    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_8    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_9    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_10   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_11   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_12   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_13   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_14   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_15   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_16   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_17   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_18   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_19   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_20   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_21   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_22   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_23   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_0      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_1      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_2      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_3      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_4      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_5      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_6      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_7      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_8      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_9      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_10     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_11     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_12     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_13     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_14     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_15     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_16     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_17     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_18     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_19     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_20     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_21     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_22     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_23     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_0          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_1          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_2          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_3          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_4          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_5          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_6          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_7          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_8          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_9          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_10         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_11         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_12         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_13         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_14         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_15         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_16         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_17         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_18         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_19         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_20         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_21         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_22         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_23         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_0        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_13       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_14       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_15       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_16       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_17       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_18       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_19       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_20       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_21       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_22       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_23       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_7     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_8     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_9     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_10    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_11    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_12    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_13    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_14    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_15    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_16    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_17    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_18    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_19    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_20    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_21    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_22    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_23    NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_0      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_1      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_2      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_3      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_4      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_5      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_6      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_0 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_1 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_2 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_3 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_4 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_5 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_6 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_0   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_1   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_2   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_3   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_4   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_5   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_6   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_0       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_0  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_1  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_2  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_3  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_4  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_5  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_6  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_7       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_8       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_9       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_10      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_11      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_12      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_1   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_2   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_3   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_4   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_5   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_6   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_7   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_8   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_9   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_10  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_11  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_12  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_7     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_8     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_9     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_10    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_11    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_12    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_1         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_2         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_3         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_4         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_5         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_6         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_7         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_8         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_9         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_10        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_11        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_12        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_7       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_8       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_9       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_10      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_11      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_12      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_1    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_2    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_3    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_4    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_5    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_6    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_7    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_8    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_9    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_10   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_11   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_12   NUMBER(18)   DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE UNIQUE INDEX IX_B_STAT_DAY_DATE_STAT ON B_STAT_DAY(DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_DAY
/

CREATE TABLE B_STAT_DAY_SITE
(
    ID                  NUMBER(18)   NOT NULL,
    DATE_STAT           DATE         NOT NULL,
    SITE_ID             CHAR(2 CHAR)      NOT NULL,
    HITS                NUMBER(18)   DEFAULT 0 NOT NULL,
    C_HOSTS             NUMBER(18)   DEFAULT 0 NOT NULL,
    SESSIONS            NUMBER(18)   DEFAULT 0 NOT NULL,
    C_EVENTS            NUMBER(18)   DEFAULT 0 NOT NULL,
    GUESTS              NUMBER(18)   DEFAULT 0 NOT NULL,
    NEW_GUESTS          NUMBER(18)   DEFAULT 0 NOT NULL,
    FAVORITES           NUMBER(18)   DEFAULT 0 NOT NULL,
    TOTAL_HOSTS         NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_AVERAGE_TIME     NUMBER(18,2) DEFAULT 0 NOT NULL,
    AM_1                NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_1_3              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_3_6              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_6_9              NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_9_12             NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_12_15            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_15_18            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_18_21            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_21_24            NUMBER(18)   DEFAULT 0 NOT NULL,
    AM_24               NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_AVERAGE_HITS     NUMBER(18,2) DEFAULT 0 NOT NULL,
    AH_1                NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_2_5              NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_6_9              NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_10_13            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_14_17            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_18_21            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_22_25            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_26_29            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_30_33            NUMBER(18)   DEFAULT 0 NOT NULL,
    AH_34               NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_0         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_1         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_2         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_3         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_4         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_5         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_6         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_7         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_8         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_9         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_10        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_11        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_12        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_13        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_14        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_15        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_16        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_17        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_18        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_19        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_20        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_21        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_22        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HOST_23        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_0        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_13       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_14       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_15       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_16       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_17       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_18       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_19       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_20       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_21       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_22       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_GUEST_23       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_0    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_1    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_2    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_3    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_4    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_5    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_6    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_7    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_8    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_9    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_10   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_11   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_12   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_13   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_14   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_15   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_16   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_17   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_18   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_19   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_20   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_21   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_22   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_NEW_GUEST_23   NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_0      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_1      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_2      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_3      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_4      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_5      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_6      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_7      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_8      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_9      NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_10     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_11     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_12     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_13     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_14     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_15     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_16     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_17     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_18     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_19     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_20     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_21     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_22     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_SESSION_23     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_0          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_1          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_2          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_3          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_4          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_5          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_6          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_7          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_8          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_9          NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_10         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_11         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_12         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_13         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_14         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_15         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_16         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_17         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_18         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_19         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_20         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_21         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_22         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_HIT_23         NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_0        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_13       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_14       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_15       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_16       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_17       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_18       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_19       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_20       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_21       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_22       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_EVENT_23       NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_7     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_8     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_9     NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_10    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_11    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_12    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_13    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_14    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_15    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_16    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_17    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_18    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_19    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_20    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_21    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_22    NUMBER(18)   DEFAULT 0 NOT NULL,
    HOUR_FAVORITE_23    NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_0      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_1      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_2      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_3      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_4      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_5      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HOST_6      NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_GUEST_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_0 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_1 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_2 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_3 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_4 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_5 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_NEW_GUEST_6 NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_0   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_1   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_2   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_3   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_4   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_5   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_SESSION_6   NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_0       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_HIT_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_0     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_EVENT_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_0  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_1  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_2  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_3  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_4  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_5  NUMBER(18)   DEFAULT 0 NOT NULL,
    WEEKDAY_FAVORITE_6  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_1        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_2        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_3        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_4        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_5        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_6        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_7        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_8        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_9        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_10       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_11       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HOST_12       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_7       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_8       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_9       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_10      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_11      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_GUEST_12      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_1   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_2   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_3   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_4   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_5   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_6   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_7   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_8   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_9   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_10  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_11  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_NEW_GUEST_12  NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_1     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_2     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_3     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_4     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_5     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_6     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_7     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_8     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_9     NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_10    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_11    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_SESSION_12    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_1         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_2         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_3         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_4         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_5         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_6         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_7         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_8         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_9         NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_10        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_11        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_HIT_12        NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_1       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_2       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_3       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_4       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_5       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_6       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_7       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_8       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_9       NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_10      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_11      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_EVENT_12      NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_1    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_2    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_3    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_4    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_5    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_6    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_7    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_8    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_9    NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_10   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_11   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONTH_FAVORITE_12   NUMBER(18)   DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE UNIQUE INDEX IX_B_STAT_DAY_SITE_SITE_ID_DAT ON B_STAT_DAY_SITE(SITE_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_DAY_SITE
/

CREATE TABLE B_STAT_EVENT
(
    ID                NUMBER(18)    NOT NULL,
    EVENT1            VARCHAR2(200 CHAR)     NULL,
    EVENT2            VARCHAR2(200 CHAR)     NULL,
    MONEY             NUMBER(18,4)   DEFAULT 0 NOT NULL,
    DATE_ENTER        DATE              NULL,
    DATE_CLEANUP      DATE              NULL,
    C_SORT            NUMBER(18)    DEFAULT 100     NULL,
    COUNTER           NUMBER(18)    DEFAULT 0 NOT NULL,
    ADV_VISIBLE       CHAR(1 CHAR)       DEFAULT 'Y' NOT NULL,
    NAME              VARCHAR2(50 CHAR)      NULL,
    DESCRIPTION       VARCHAR2(500 CHAR)     NULL,
    KEEP_DAYS         NUMBER(18)        NULL,
    DYNAMIC_KEEP_DAYS NUMBER(18)        NULL,
    DIAGRAM_DEFAULT   CHAR(1 CHAR)       DEFAULT 'Y' NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_EVENT1_EVENT2 ON B_STAT_EVENT(EVENT1,EVENT2)
/
CREATE INDEX IX_B_STAT_EVENT_2 ON b_stat_event (KEEP_DAYS, ID)
/
CREATE SEQUENCE SQ_B_STAT_EVENT
/

CREATE TABLE B_STAT_EVENT_DAY
(
    ID        NUMBER(18)   NOT NULL,
    DATE_STAT DATE             NULL,
    DATE_LAST DATE             NULL,
    EVENT_ID  NUMBER(18)   NOT NULL,
    COUNTER   NUMBER(18)   DEFAULT 0 NOT NULL,
    MONEY     NUMBER(18,4) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_EVENT_DAY_EVENT_ID_D ON B_STAT_EVENT_DAY(EVENT_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_EVENT_DAY
/

CREATE TABLE B_STAT_EVENT_LIST
(
    ID              NUMBER(18)     NOT NULL,
    EVENT_ID        NUMBER(18)     NOT NULL,
    EVENT3          VARCHAR2(255 CHAR)      NULL,
    DATE_ENTER      DATE           NOT NULL,
    MONEY           NUMBER(18,4)   DEFAULT 0 NOT NULL,
    REFERER_URL     VARCHAR2(2000 CHAR)     NULL,
    URL             VARCHAR2(2000 CHAR)     NULL,
    REDIRECT_URL    VARCHAR2(2000 CHAR)     NULL,
    SESSION_ID      NUMBER(18)         NULL,
    GUEST_ID        NUMBER(18)         NULL,
    ADV_ID          NUMBER(18)         NULL,
    ADV_BACK        CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    HIT_ID          NUMBER(18)         NULL,
    COUNTRY_ID      CHAR(2 CHAR)            NULL,
    KEEP_DAYS       NUMBER(18)         NULL,
    CHARGEBACK      CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    SITE_ID         CHAR(2 CHAR)            NULL,
    REFERER_SITE_ID CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STAT_EVENT_LIST
/
CREATE INDEX IX_B_STAT_EVENT_LIST_GUEST_ID ON B_STAT_EVENT_LIST(GUEST_ID)
/
CREATE INDEX IX_B_STAT_EVENT_LIST_2 ON b_stat_event_list (EVENT_ID, DATE_ENTER)
/
CREATE INDEX IX_B_STAT_EVENT_LIST_3 ON b_stat_event_list (KEEP_DAYS, DATE_ENTER)
/

CREATE TABLE B_STAT_GUEST
(
    ID                NUMBER(18)     NOT NULL,
    TIMESTAMP_X       DATE           DEFAULT SYSDATE NOT NULL,
    FAVORITES         CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    C_EVENTS          NUMBER(18)     DEFAULT 0 NOT NULL,
    SESSIONS          NUMBER(18)     DEFAULT 0 NOT NULL,
    HITS              NUMBER(18)     DEFAULT 0 NOT NULL,
    REPAIR            CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    FIRST_SESSION_ID  NUMBER(18)         NULL,
    FIRST_DATE        DATE               NULL,
    FIRST_URL_FROM    VARCHAR2(2000 CHAR)     NULL,
    FIRST_URL_TO      VARCHAR2(2000 CHAR)     NULL,
    FIRST_URL_TO_404  CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    FIRST_SITE_ID     CHAR(2 CHAR)            NULL,
    FIRST_ADV_ID      NUMBER(18)         NULL,
    FIRST_REFERER1    VARCHAR2(255 CHAR)      NULL,
    FIRST_REFERER2    VARCHAR2(255 CHAR)      NULL,
    FIRST_REFERER3    VARCHAR2(255 CHAR)      NULL,
    LAST_SESSION_ID   NUMBER(18)         NULL,
    LAST_DATE         DATE               NULL,
    LAST_USER_ID      NUMBER(18)         NULL,
    LAST_USER_AUTH    CHAR(1 CHAR)        DEFAULT NULL     NULL,
    LAST_URL_LAST     VARCHAR2(2000 CHAR)     NULL,
    LAST_URL_LAST_404 CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    LAST_USER_AGENT   VARCHAR2(500 CHAR)      NULL,
    LAST_IP           VARCHAR2(15 CHAR)       NULL,
    LAST_COOKIE       VARCHAR2(2000 CHAR)     NULL,
    LAST_LANGUAGE     VARCHAR2(255 CHAR)      NULL,
    LAST_ADV_ID       NUMBER(18)         NULL,
    LAST_ADV_BACK     CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    LAST_REFERER1     VARCHAR2(255 CHAR)      NULL,
    LAST_REFERER2     VARCHAR2(255 CHAR)      NULL,
    LAST_REFERER3     VARCHAR2(255 CHAR)      NULL,
    LAST_SITE_ID      CHAR(2 CHAR)            NULL,
    LAST_COUNTRY_ID   CHAR(2 CHAR)            NULL,
    LAST_CITY_ID      NUMBER(18)         NULL,
    LAST_CITY_INFO    VARCHAR2(2000 CHAR)     NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_GUEST_0 ON B_STAT_GUEST(LAST_DATE)
/
CREATE SEQUENCE SQ_B_STAT_GUEST
/

CREATE TABLE B_STAT_HIT
(
    ID           NUMBER(18)     NOT NULL,
    SESSION_ID   NUMBER(18)     NOT NULL,
    DATE_HIT     DATE               NULL,
    GUEST_ID     NUMBER(18)         NULL,
    NEW_GUEST    CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    USER_ID      NUMBER(18)         NULL,
    USER_AUTH    CHAR(1 CHAR)            NULL,
    URL          VARCHAR2(2000 CHAR)     NULL,
    URL_404      CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL_FROM     VARCHAR2(2000 CHAR)     NULL,
    IP           VARCHAR2(15 CHAR)       NULL,
    METHOD       VARCHAR2(10 CHAR)       NULL,
    COOKIES      VARCHAR2(2000 CHAR)     NULL,
    USER_AGENT   VARCHAR2(500 CHAR)      NULL,
    STOP_LIST_ID NUMBER(18)         NULL,
    COUNTRY_ID   CHAR(2 CHAR)            NULL,
    CITY_ID      NUMBER(18)         NULL,
    SITE_ID      CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_HIT_0 ON B_STAT_HIT(DATE_HIT)
/
CREATE SEQUENCE SQ_B_STAT_HIT
/
CREATE TABLE B_STAT_SEARCHER_HIT
(
    ID            NUMBER(18)     NOT NULL,
    DATE_HIT      DATE               NULL,
    SEARCHER_ID   NUMBER(18)     NOT NULL,
    URL           VARCHAR2(2000 CHAR) NOT NULL,
    URL_404       CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    IP            VARCHAR2(15 CHAR)       NULL,
    USER_AGENT    VARCHAR2(500 CHAR)      NULL,
    HIT_KEEP_DAYS NUMBER(18)         NULL,
    SITE_ID       CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STAT_SEARCHER_HIT
/
CREATE INDEX IX_B_STAT_SEARCHER_HIT_1 ON b_stat_searcher_hit (SEARCHER_ID, DATE_HIT)
/
CREATE INDEX IX_B_STAT_SEARCHER_HIT_2 ON b_stat_searcher_hit (HIT_KEEP_DAYS, DATE_HIT)
/

CREATE TABLE B_STAT_PHRASE_LIST
(
    ID          NUMBER(18)     NOT NULL,
    DATE_HIT    DATE               NULL,
    SEARCHER_ID NUMBER(18)         NULL,
    REFERER_ID  NUMBER(18)         NULL,
    PHRASE      VARCHAR2(255 CHAR)  NOT NULL,
    URL_FROM    VARCHAR2(2000 CHAR)     NULL,
    URL_TO      VARCHAR2(2000 CHAR)     NULL,
    URL_TO_404  CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    SESSION_ID  NUMBER(18)         NULL,
    SITE_ID     CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PHRASE_LIST_0 ON B_STAT_PHRASE_LIST(DATE_HIT)
/
CREATE INDEX IX_B_STAT_PHRASE_LIST_1 ON B_STAT_PHRASE_LIST(URL_TO, SEARCHER_ID)
/
CREATE SEQUENCE SQ_B_STAT_PHRASE_LIST
/
CREATE TABLE B_STAT_REFERER
(
    ID         NUMBER(18)    NOT NULL,
    DATE_FIRST DATE              NULL,
    DATE_LAST  DATE              NULL,
    SITE_NAME  VARCHAR2(255 CHAR) NOT NULL,
    SESSIONS   NUMBER(18)    DEFAULT 0 NOT NULL,
    HITS       NUMBER(18)    DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_REFERER_SITE_NAME ON B_STAT_REFERER(SITE_NAME)
/
CREATE INDEX IX_B_STAT_REFERER_2 ON b_stat_referer(DATE_LAST, ID)
/
CREATE SEQUENCE SQ_B_STAT_REFERER
/
CREATE TABLE B_STAT_REFERER_LIST
(
    ID           NUMBER(18)     NOT NULL,
    REFERER_ID   NUMBER(18)         NULL,
    DATE_HIT     DATE               NULL,
    PROTOCOL     VARCHAR2(10 CHAR)       NULL,
    SITE_NAME    VARCHAR2(255 CHAR)      NULL,
    URL_FROM     VARCHAR2(2000 CHAR) NOT NULL,
    URL_TO       VARCHAR2(2000 CHAR)     NULL,
    URL_TO_404   CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    SESSION_ID   NUMBER(18)         NULL,
    ADV_ID       NUMBER(18)         NULL,
    SITE_ID      CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_REFERER_LIST_0 ON B_STAT_REFERER_LIST(DATE_HIT)
/
CREATE INDEX IX_B_STAT_REFERER_LIST_1 ON B_STAT_REFERER_LIST(SITE_NAME, URL_TO)
/
CREATE SEQUENCE SQ_B_STAT_REFERER_LIST
/
CREATE TABLE B_STAT_SEARCHER
(
    ID                 NUMBER(18)    NOT NULL,
    DATE_CLEANUP       DATE              NULL,
    TOTAL_HITS         NUMBER(18)    DEFAULT 0 NOT NULL,
    SAVE_STATISTIC     CHAR(1 CHAR)       DEFAULT 'Y' NOT NULL,
    ACTIVE             CHAR(1 CHAR)       DEFAULT 'Y' NOT NULL,
    NAME               VARCHAR2(255 CHAR) NOT NULL,
    USER_AGENT         VARCHAR2(500 CHAR)     NULL,
    DIAGRAM_DEFAULT    CHAR(1 CHAR)       DEFAULT 'N' NOT NULL,
    HIT_KEEP_DAYS      NUMBER(18)        NULL,
    DYNAMIC_KEEP_DAYS  NUMBER(18)        NULL,
    PHRASES            NUMBER(18)    DEFAULT 0 NOT NULL,
    PHRASES_HITS       NUMBER(18)    DEFAULT 0 NOT NULL,
    CHECK_ACTIVITY     CHAR(1 CHAR)       DEFAULT 'Y' NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_SEARCHER_1 ON b_stat_searcher (HIT_KEEP_DAYS, ID)
/
CREATE SEQUENCE SQ_B_STAT_SEARCHER
/

CREATE TABLE B_STAT_SEARCHER_DAY
(
    ID          NUMBER(18) NOT NULL,
    DATE_STAT   DATE           NULL,
    DATE_LAST   DATE           NULL,
    SEARCHER_ID NUMBER(18) NOT NULL,
    TOTAL_HITS  NUMBER(18) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_SEARCHER_DAY_SEARCHE ON B_STAT_SEARCHER_DAY(SEARCHER_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_SEARCHER_DAY
/

CREATE TABLE B_STAT_SEARCHER_PARAMS
(
    ID          NUMBER(18)    NOT NULL,
    SEARCHER_ID NUMBER(18)    NOT NULL,
    DOMAIN      VARCHAR2(255 CHAR)     NULL,
    VARIABLE    VARCHAR2(255 CHAR)     NULL,
    CHAR_SET    VARCHAR2(255 CHAR)     NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_SEARCHER_DOMAIN ON B_STAT_SEARCHER_PARAMS(SEARCHER_ID,DOMAIN)
/
CREATE SEQUENCE SQ_B_STAT_SEARCHER_PARAMS
/

CREATE TABLE B_STAT_SESSION
(
    ID              NUMBER(18)     NOT NULL,
    GUEST_ID        NUMBER(18)         NULL,
    NEW_GUEST       CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    USER_ID         NUMBER(18)         NULL,
    USER_AUTH       CHAR(1 CHAR)            NULL,
    C_EVENTS        NUMBER(18)     DEFAULT 0 NOT NULL,
    HITS            NUMBER(18)     DEFAULT 0 NOT NULL,
    FAVORITES       CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL_FROM        VARCHAR2(2000 CHAR)     NULL,
    URL_TO          VARCHAR2(2000 CHAR)     NULL,
    URL_TO_404      CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL_LAST        VARCHAR2(2000 CHAR)     NULL,
    URL_LAST_404    CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    USER_AGENT      VARCHAR2(500 CHAR)      NULL,
    DATE_STAT       DATE               NULL,
    DATE_FIRST      DATE               NULL,
    DATE_LAST       DATE               NULL,
    IP_FIRST        VARCHAR2(15 CHAR)       NULL,
    IP_LAST         VARCHAR2(15 CHAR)       NULL,
    FIRST_HIT_ID    NUMBER(18)         NULL,
    LAST_HIT_ID     NUMBER(18)         NULL,
    PHPSESSID       VARCHAR2(255 CHAR)      NULL,
    ADV_ID          NUMBER(18)         NULL,
    ADV_BACK        CHAR(1 CHAR)            NULL,
    REFERER1        VARCHAR2(255 CHAR)      NULL,
    REFERER2        VARCHAR2(255 CHAR)      NULL,
    REFERER3        VARCHAR2(255 CHAR)      NULL,
    STOP_LIST_ID    NUMBER(18)         NULL,
    COUNTRY_ID      CHAR(2 CHAR)            NULL,
    CITY_ID         NUMBER(18)         NULL,
    FIRST_SITE_ID   CHAR(2 CHAR)            NULL,
    LAST_SITE_ID    CHAR(2 CHAR)            NULL,
    IP_FIRST_NUMBER NUMBER(20)         NULL,
    IP_LAST_NUMBER  NUMBER(20)         NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_SESSION_DATE_STAT ON B_STAT_SESSION(DATE_STAT)
/
CREATE INDEX IX_B_STAT_SESSION_3 ON B_STAT_SESSION(IP_FIRST_NUMBER, DATE_STAT)
/
CREATE INDEX IX_B_STAT_SESSION_4 ON B_STAT_SESSION(UPPER(TO_CHAR("USER_ID")), DATE_STAT)
/
CREATE INDEX IX_B_STAT_SESSION_5 ON B_STAT_SESSION (DATE_LAST)
/
CREATE INDEX IX_B_STAT_SESSION_6 ON B_STAT_SESSION (GUEST_ID)
/
CREATE SEQUENCE SQ_B_STAT_SESSION
/

CREATE TABLE B_STAT_SESSION_DATA
(
    ID              NUMBER(18)     NOT NULL,
    DATE_FIRST      DATE               NULL,
    DATE_LAST       DATE               NULL,
    GUEST_MD5       VARCHAR2(255 CHAR)  NOT NULL,
    SESS_SESSION_ID NUMBER(18)         NULL,
    SESSION_DATA    VARCHAR2(2000 CHAR)     NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_SESSION_DATA_GUEST_M ON B_STAT_SESSION_DATA(GUEST_MD5)
/
CREATE SEQUENCE SQ_B_STAT_SESSION_DATA
/
CREATE TABLE B_STAT_PAGE
(
    ID            NUMBER(18)     NOT NULL,
    DATE_STAT     DATE           NOT NULL,
    DIR           CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL           VARCHAR2(2000 CHAR) NOT NULL,
    URL_404       CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL_HASH      NUMBER(32)         NULL,
    SITE_ID       CHAR(2 CHAR)            NULL,
    COUNTER       NUMBER(18)     DEFAULT 0 NOT NULL,
    ENTER_COUNTER NUMBER(18)     DEFAULT 0 NOT NULL,
    EXIT_COUNTER  NUMBER(18)     DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PAGE_DATE_STAT ON B_STAT_PAGE(DATE_STAT)
/
CREATE INDEX IX_B_STAT_PAGE_URL_HASH ON B_STAT_PAGE(URL_HASH)
/
CREATE SEQUENCE SQ_B_STAT_PAGE
/
CREATE TABLE B_STOP_LIST
(
    ID                 NUMBER(18)     NOT NULL,
    TIMESTAMP_X        DATE           DEFAULT SYSDATE NOT NULL,
    DATE_START         DATE               NULL,
    DATE_END           DATE               NULL,
    ACTIVE             CHAR(1 CHAR)        DEFAULT 'Y' NOT NULL,
    SAVE_STATISTIC     CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    IP_1               NUMBER(3)          NULL,
    IP_2               NUMBER(3)          NULL,
    IP_3               NUMBER(3)          NULL,
    IP_4               NUMBER(3)          NULL,
    MASK_1             NUMBER(3)          NULL,
    MASK_2             NUMBER(3)          NULL,
    MASK_3             NUMBER(3)          NULL,
    MASK_4             NUMBER(3)          NULL,
    USER_AGENT         VARCHAR2(500 CHAR)      NULL,
    USER_AGENT_IS_NULL CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    URL_TO             VARCHAR2(2000 CHAR)     NULL,
    URL_FROM           VARCHAR2(2000 CHAR)     NULL,
    MESSAGE            VARCHAR2(500 CHAR)      NULL,
    MESSAGE_LID        CHAR(2 CHAR)        DEFAULT 'en' NOT NULL,
    URL_REDIRECT       VARCHAR2(2000 CHAR)     NULL,
    COMMENTS           VARCHAR2(2000 CHAR)     NULL,
    TEST               CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    SITE_ID            CHAR(2 CHAR)            NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STOP_LIST
/

CREATE TABLE B_STAT_COUNTRY_DAY
(
    ID         NUMBER(18)  NOT NULL,
    COUNTRY_ID VARCHAR2(2 CHAR) NOT NULL,
    DATE_STAT  DATE        NOT NULL,
    SESSIONS   NUMBER(18)  DEFAULT 0 NOT NULL,
    NEW_GUESTS NUMBER(18)  DEFAULT 0 NOT NULL,
    HITS       NUMBER(18)  DEFAULT 0 NOT NULL,
    C_EVENTS   NUMBER(18)  DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_COUNTRY_DAY_COUNTRY_ ON B_STAT_COUNTRY_DAY(COUNTRY_ID,DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_COUNTRY_DAY
/

CREATE TABLE B_STAT_PATH
(
    ID                 NUMBER(18)     NOT NULL,
    PATH_ID            NUMBER(32)     NOT NULL,
    PARENT_PATH_ID     NUMBER(32)         NULL,
    DATE_STAT          DATE           NOT NULL,
    COUNTER            NUMBER(18)     DEFAULT 0 NOT NULL,
    COUNTER_ABNORMAL   NUMBER(18)     DEFAULT 0 NOT NULL,
    COUNTER_FULL_PATH  NUMBER(18)     DEFAULT 0 NOT NULL,
    PAGES              VARCHAR2(2000 CHAR)     NULL,
    FIRST_PAGE         VARCHAR2(255 CHAR)      NULL,
    FIRST_PAGE_404     CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    FIRST_PAGE_SITE_ID CHAR(2 CHAR)            NULL,
    PREV_PAGE          VARCHAR2(255 CHAR)      NULL,
    PREV_PAGE_HASH     NUMBER(32)         NULL,
    LAST_PAGE          VARCHAR2(255 CHAR)      NULL,
    LAST_PAGE_404      CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    LAST_PAGE_SITE_ID  CHAR(2 CHAR)            NULL,
    LAST_PAGE_HASH     NUMBER(32)         NULL,
    STEPS              NUMBER(18)     DEFAULT 1 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PATH_0 ON B_STAT_PATH(DATE_STAT)
/
CREATE INDEX IX_B_STAT_PATH_3 ON B_STAT_PATH(PATH_ID, DATE_STAT)
/
CREATE INDEX IX_B_STAT_PATH_PREV_PAGE_LAST ON B_STAT_PATH(PREV_PAGE_HASH, LAST_PAGE_HASH)
/
CREATE SEQUENCE SQ_B_STAT_PATH
/
CREATE TABLE B_STAT_PATH_ADV
(
    ID                     NUMBER(18) NOT NULL,
    ADV_ID                 NUMBER(18) NOT NULL,
    PATH_ID                NUMBER(18) NOT NULL,
    DATE_STAT              DATE           NULL,
    COUNTER                NUMBER(18) DEFAULT 0 NOT NULL,
    COUNTER_BACK           NUMBER(18) DEFAULT 0 NOT NULL,
    COUNTER_FULL_PATH      NUMBER(18) DEFAULT 0 NOT NULL,
    COUNTER_FULL_PATH_BACK NUMBER(18) DEFAULT 0 NOT NULL,
    STEPS                  NUMBER(18) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PATH_ADV_0 ON B_STAT_PATH_ADV(DATE_STAT)
/
CREATE INDEX IX_B_STAT_PATH_ADV_2 ON B_STAT_PATH_ADV(PATH_ID, ADV_ID, DATE_STAT)
/
CREATE SEQUENCE SQ_B_STAT_PATH_ADV
/
CREATE TABLE B_STAT_PATH_CACHE
(
    ID                      NUMBER(18)     NOT NULL,
    SESSION_ID              NUMBER(18)     NOT NULL,
    DATE_HIT                DATE               NULL,
    PATH_ID                 NUMBER(32)         NULL,
    PATH_PAGES              VARCHAR2(2000 CHAR)     NULL,
    PATH_FIRST_PAGE         VARCHAR2(255 CHAR)      NULL,
    PATH_FIRST_PAGE_404     CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    PATH_FIRST_PAGE_SITE_ID CHAR(2 CHAR)            NULL,
    PATH_LAST_PAGE          VARCHAR2(255 CHAR)      NULL,
    PATH_LAST_PAGE_404      CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    PATH_LAST_PAGE_SITE_ID  CHAR(2 CHAR)            NULL,
    PATH_STEPS              NUMBER(18)     DEFAULT 1 NOT NULL,
    IS_LAST_PAGE            CHAR(1 CHAR)        DEFAULT 'Y' NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PATH_CACHE ON B_STAT_PATH_CACHE(SESSION_ID)
/
CREATE SEQUENCE SQ_B_STAT_PATH_CACHE
/

CREATE TABLE B_STAT_PAGE_ADV
(
    ID                 NUMBER(18) NOT NULL,
    DATE_STAT          DATE           NULL,
    PAGE_ID            NUMBER(18) NOT NULL,
    ADV_ID             NUMBER(18) NOT NULL,
    COUNTER            NUMBER(18) DEFAULT 0 NOT NULL,
    ENTER_COUNTER      NUMBER(18) DEFAULT 0 NOT NULL,
    EXIT_COUNTER       NUMBER(18) DEFAULT 0 NOT NULL,
    COUNTER_BACK       NUMBER(18) DEFAULT 0 NOT NULL,
    ENTER_COUNTER_BACK NUMBER(18) DEFAULT 0 NOT NULL,
    EXIT_COUNTER_BACK  NUMBER(18) DEFAULT 0 NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_STAT_PAGE_ADV_0 ON B_STAT_PAGE_ADV(DATE_STAT)
/
CREATE INDEX IX_B_STAT_PAGE_ADV_2 ON B_STAT_PAGE_ADV(PAGE_ID, ADV_ID)
/
CREATE SEQUENCE SQ_B_STAT_PAGE_ADV
/
CREATE TABLE B_STAT_DDL
(
    ID              NUMBER(18)     NOT NULL,
    SQL_TEXT        VARCHAR2(255 CHAR)  NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_B_STAT_DDL
/
CREATE OR REPLACE TRIGGER B_STAT_DDL_INSERT
BEFORE INSERT
ON B_STAT_DDL
FOR EACH ROW
BEGIN
	IF :NEW.ID IS NULL THEN
 		SELECT SQ_B_STAT_DDL.NEXTVAL INTO :NEW.ID FROM dual;
	END IF;
END;
/
