CREATE TABLE B_TICKET 
(
    ID                           NUMBER(18)     NOT NULL,
    SITE_ID                      CHAR(2 CHAR)        NOT NULL,
    DATE_CREATE                  DATE               NULL,
    DAY_CREATE                   DATE               NULL,
    TIMESTAMP_X                  DATE               NULL,
    DATE_CLOSE                   DATE               NULL,
    AUTO_CLOSED                  CHAR(1 CHAR)            NULL,
    AUTO_CLOSE_DAYS              NUMBER(3)          NULL,
    SLA_ID                       NUMBER(18)     DEFAULT 1 NOT NULL,
    NOTIFY_AGENT_ID              NUMBER(18)         NULL,
    EXPIRE_AGENT_ID              NUMBER(18)         NULL,
    OVERDUE_MESSAGES             NUMBER(18)     DEFAULT 0 NOT NULL,
    IS_NOTIFIED                  CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    IS_OVERDUE                   CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    CATEGORY_ID                  NUMBER(18)         NULL,
    CRITICALITY_ID               NUMBER(18)         NULL,
    STATUS_ID                    NUMBER(18)         NULL,
    MARK_ID                      NUMBER(18)         NULL,
    SOURCE_ID                    NUMBER(18)         NULL,
    DIFFICULTY_ID               NUMBER(18)         NULL,
    TITLE                        VARCHAR2(2000 CHAR)  NOT NULL,
    MESSAGES                     NUMBER(18)     DEFAULT 0 NOT NULL,
    IS_SPAM                      CHAR(1 CHAR)            NULL,
    OWNER_USER_ID                NUMBER(18)         NULL,
    OWNER_GUEST_ID               NUMBER(18)         NULL,
    OWNER_SID                    VARCHAR2(2000 CHAR)     NULL,
    RESPONSIBLE_USER_ID          NUMBER(18)         NULL,
    CREATED_USER_ID              NUMBER(18)         NULL,
    CREATED_GUEST_ID             NUMBER(18)         NULL,
    CREATED_MODULE_NAME          VARCHAR2(255 CHAR)      NULL,
    MODIFIED_USER_ID             NUMBER(18)         NULL,
    MODIFIED_GUEST_ID            NUMBER(18)         NULL,
    MODIFIED_MODULE_NAME         VARCHAR2(255 CHAR)      NULL,
    LAST_MESSAGE_USER_ID         NUMBER(18)         NULL,
    LAST_MESSAGE_GUEST_ID        NUMBER(18)         NULL,
    LAST_MESSAGE_SID             VARCHAR2(2000 CHAR)     NULL,
    LAST_MESSAGE_BY_SUPPORT_TEAM CHAR(1 CHAR)        DEFAULT 'N' NOT NULL,
    LAST_MESSAGE_DATE DATE NULL,
    SUPPORT_COMMENTS             VARCHAR2(2000 CHAR)     NULL,
    PROBLEM_TIME NUMBER(18) NULL,
    HOLD_ON CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
    REOPEN CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
    COUPON 				        VARCHAR2(255 CHAR)      NULL,
	SUPPORT_DEADLINE DATE NULL,
	SUPPORT_DEADLINE_NOTIFY DATE NULL,
	D_1_USER_M_AFTER_SUP_M DATE NULL,
	ID_1_USER_M_AFTER_SUP_M NUMBER(18) NULL,
	DEADLINE_SOURCE_DATE DATE NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_TICKET_OWNER ON B_TICKET(OWNER_USER_ID, TIMESTAMP_X)
/
CREATE INDEX IX_B_TICKET_RESPONSIBLE ON B_TICKET(RESPONSIBLE_USER_ID)
/

CREATE TABLE B_TICKET_DICTIONARY 
(
    ID                  NUMBER(18)     NOT NULL,
    FIRST_SITE_ID        CHAR(2 CHAR)            NULL,
    C_TYPE              VARCHAR2(5 CHAR)    NOT NULL,
    SID                 VARCHAR2(255 CHAR)      NULL,
    SET_AS_DEFAULT      CHAR(1 CHAR)            NULL,
    C_SORT              NUMBER(18)     DEFAULT 100     NULL,
    NAME                VARCHAR2(255 CHAR)  NOT NULL,
    DESCR               VARCHAR2(2000 CHAR)     NULL,
    RESPONSIBLE_USER_ID NUMBER(18)         NULL,
    EVENT1              VARCHAR2(255 CHAR)  DEFAULT 'ticket'     NULL,
    EVENT2              VARCHAR2(255 CHAR)      NULL,
    EVENT3              VARCHAR2(255 CHAR)      NULL,
    PRIMARY KEY (ID)
)
/

CREATE TABLE B_TICKET_DICTIONARY_2_SITE 
(
    DICTIONARY_ID NUMBER(18) NOT NULL,
    SITE_ID    CHAR(2 CHAR)    NOT NULL,
    PRIMARY KEY (DICTIONARY_ID,SITE_ID)
)
/

CREATE TABLE B_TICKET_MESSAGE 
(
    ID                          NUMBER(18)         NULL,
    TIMESTAMP_X                 DATE               NULL,
    DATE_CREATE                 DATE               NULL,
    DAY_CREATE                  DATE               NULL,
    C_NUMBER                    NUMBER(18)         NULL,
    TICKET_ID                   NUMBER(18)     NOT NULL,
    IS_HIDDEN                   CHAR(1 CHAR)        DEFAULT 'N'     NULL,
    IS_LOG                      CHAR(1 CHAR)        DEFAULT 'N'     NULL,
    IS_OVERDUE                  CHAR(1 CHAR)        DEFAULT 'N'     NULL,
    CURRENT_RESPONSIBLE_USER_ID NUMBER(18)         NULL,
    NOTIFY_AGENT_DONE           CHAR(1 CHAR)        DEFAULT 'N'     NULL,
    EXPIRE_AGENT_DONE           CHAR(1 CHAR)        DEFAULT 'N'     NULL,
    MESSAGE                     CLOB               NULL,
    MESSAGE_SEARCH              CLOB               NULL,
    IS_SPAM                     CHAR(1 CHAR)            NULL,
    EXTERNAL_ID                 NUMBER(18)         NULL,
    EXTERNAL_FIELD_1            VARCHAR2(2000 CHAR)     NULL,
    IMAGE                       NUMBER(18)         NULL,
    OWNER_USER_ID               NUMBER(18)         NULL,
    OWNER_GUEST_ID              NUMBER(18)         NULL,
    OWNER_SID                   VARCHAR2(2000 CHAR)     NULL,
    SOURCE_ID                   NUMBER(18)         NULL,
    CREATED_USER_ID             NUMBER(18)         NULL,
    CREATED_GUEST_ID            NUMBER(18)         NULL,
    CREATED_MODULE_NAME         VARCHAR2(255 CHAR)      NULL,
    MODIFIED_USER_ID            NUMBER(18)         NULL,
    MODIFIED_GUEST_ID           NUMBER(18)         NULL,
    MESSAGE_BY_SUPPORT_TEAM     CHAR(1 CHAR)            NULL,
    TASK_TIME NUMBER(18) NULL,
    NOT_CHANGE_STATUS CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_TICKET_MESSAGE_TID ON B_TICKET_MESSAGE(TICKET_ID)
/

CREATE TABLE B_TICKET_MESSAGE_2_FILE 
(
    ID               NUMBER(18)    NOT NULL,
    HASH             VARCHAR2(255 CHAR)     NULL,
    MESSAGE_ID       NUMBER(18)    NOT NULL,
    FILE_ID          NUMBER(18)    NOT NULL,
    TICKET_ID        NUMBER(18)    NOT NULL,
    EXTENSION_SUFFIX VARCHAR2(255 CHAR)     NULL,
    PRIMARY KEY (ID)
)
/
CREATE INDEX IX_B_TICKET_MESSAGE_2_FILE_MID ON B_TICKET_MESSAGE_2_FILE(MESSAGE_ID)
/
CREATE UNIQUE INDEX IX_B_TICKET_MESSAGE_2_FILE_HSH ON B_TICKET_MESSAGE_2_FILE(HASH)
/

CREATE TABLE B_TICKET_ONLINE 
(
    ID           NUMBER(18) NOT NULL,
    TIMESTAMP_X  DATE           NULL,
    TICKET_ID    NUMBER(18)     NULL,
    USER_ID      NUMBER(18)     NULL,
    CURRENT_MODE VARCHAR2(20 CHAR)   NULL,
    PRIMARY KEY (ID)
)
/

CREATE INDEX IX_B_TICKET_ONLINE_TICKET_ID ON B_TICKET_ONLINE(TICKET_ID)
/

CREATE TABLE B_TICKET_SLA 
(
    ID                  NUMBER(18)     NOT NULL,
    PRIORITY            NUMBER(18)     DEFAULT 0 NOT NULL,
    FIRST_SITE_ID       VARCHAR2(5 CHAR)        NULL,
    NAME                VARCHAR2(255 CHAR)  NOT NULL,
    DESCRIPTION         VARCHAR2(2000 CHAR)     NULL,
    RESPONSE_TIME       NUMBER(18)         NULL,
    RESPONSE_TIME_UNIT  VARCHAR2(10 CHAR)   DEFAULT 'hour' NOT NULL,
    NOTICE_TIME         NUMBER(18)         NULL,
    NOTICE_TIME_UNIT    VARCHAR2(10 CHAR)   DEFAULT 'hour' NOT NULL,
    RESPONSIBLE_USER_ID NUMBER(18)         NULL,
    DATE_CREATE         DATE               NULL,
    CREATED_USER_ID     NUMBER(18)         NULL,
    CREATED_GUEST_ID    NUMBER(18)         NULL,
    DATE_MODIFY         DATE               NULL,
    MODIFIED_USER_ID    NUMBER(18)         NULL,
    MODIFIED_GUEST_ID   NUMBER(18)         NULL,
	TIMETABLE_ID NUMBER(18) NULL,
    PRIMARY KEY (ID)
)
/

CREATE TABLE B_TICKET_SLA_SHEDULE 
(
    ID             NUMBER(18)   NOT NULL,
    SLA_ID         NUMBER(18)   NOT NULL,
    WEEKDAY_NUMBER NUMBER(2)    DEFAULT 0 NOT NULL,
    OPEN_TIME      VARCHAR2(10 CHAR) DEFAULT '24H' NOT NULL,
    MINUTE_FROM    NUMBER(18)       NULL,
    MINUTE_TILL    NUMBER(18)       NULL,
	TIMETABLE_ID NUMBER(18) NULL,
    PRIMARY KEY (ID)
)
/

CREATE INDEX IX_B_TICKET_SLA_SHEDULE_SLA_ID ON B_TICKET_SLA_SHEDULE(SLA_ID)
/

CREATE TABLE B_TICKET_SLA_2_SITE 
(
    SLA_ID  NUMBER(18)  NOT NULL,
    SITE_ID VARCHAR2(5 CHAR) NOT NULL,
    PRIMARY KEY (SLA_ID,SITE_ID)
)
/

CREATE TABLE B_TICKET_SLA_2_CATEGORY 
(
    SLA_ID      NUMBER(18) NOT NULL,
    CATEGORY_ID NUMBER(18) NOT NULL,
    PRIMARY KEY (SLA_ID,CATEGORY_ID)
)
/

CREATE TABLE B_TICKET_SLA_2_CRITICALITY 
(
    SLA_ID          NUMBER(18) NOT NULL,
    CRITICALITY_ID  NUMBER(18) NOT NULL,
    PRIMARY KEY (SLA_ID,CRITICALITY_ID)
)
/

CREATE TABLE B_TICKET_SLA_2_MARK
(
    SLA_ID      NUMBER(18) NOT NULL,
    MARK_ID     NUMBER(18) NOT NULL,
    PRIMARY KEY (SLA_ID,MARK_ID)
)
/

CREATE TABLE B_TICKET_SLA_2_USER_GROUP
(
    SLA_ID      NUMBER(18) NOT NULL,
    GROUP_ID    NUMBER(18) NOT NULL,
    PRIMARY KEY (SLA_ID,GROUP_ID)
)
/

CREATE TABLE B_TICKET_UGROUPS
(
    ID             NUMBER(18)   NOT NULL,
    NAME           VARCHAR2(255 CHAR)  NOT NULL,
    XML_ID         VARCHAR2(255 CHAR)  NULL,
    SORT           NUMBER(18)     DEFAULT 100 NOT NULL,
    IS_TEAM_GROUP CHAR(1 CHAR)    DEFAULT 'N' NOT NULL,
    PRIMARY KEY (ID)
)
/

CREATE TABLE B_TICKET_USER_UGROUP
(
    GROUP_ID                    NUMBER(18) NOT NULL,
    USER_ID                     NUMBER(18) NOT NULL,
    CAN_VIEW_GROUP_MESSAGES     CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
    CAN_MAIL_GROUP_MESSAGES     CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
	CAN_MAIL_UPDATE_GROUP_MESSAGES CHAR(1 CHAR) DEFAULT 'N' NOT NULL,
    PRIMARY KEY (GROUP_ID,USER_ID)
)
/

CREATE TABLE B_TICKET_SUPERCOUPONS
(
  ID NUMBER(18)   NOT NULL,
  COUNT_TICKETS NUMBER(18)     DEFAULT 0 NOT NULL,
  COUPON VARCHAR2(255 CHAR)  NOT NULL,
  TIMESTAMP_X DATE NOT NULL,
  DATE_CREATE DATE NOT NULL,
  CREATED_USER_ID NUMBER(18) NULL,
  UPDATED_USER_ID NUMBER(18) NULL,
  ACTIVE char(1 CHAR) DEFAULT 'Y' NOT NULL,
  ACTIVE_FROM DATE NULL,
  ACTIVE_TO DATE NULL,
  SLA_ID NUMBER(18) NULL,
  COUNT_USED NUMBER(18)     DEFAULT 0 NOT NULL,
  PRIMARY KEY  (ID)
)
/
CREATE UNIQUE INDEX IX_B_TICKET_SUPERCOUPONS_COUPO ON B_TICKET_SUPERCOUPONS(COUPON)
/

CREATE TABLE B_TICKET_SUPERCOUPONS_LOG
(
  TIMESTAMP_X DATE NOT NULL,
  COUPON_ID NUMBER(18) DEFAULT 0 NOT NULL,
  USER_ID NUMBER(18) NULL,
  SUCCESS char(1 CHAR) DEFAULT 'N' NOT NULL,
  AFTER_COUNT NUMBER(18)     DEFAULT 0 NOT NULL,
  SESSION_ID NUMBER(18) NULL,
  GUEST_ID NUMBER(18) NULL,
  AFFECTED_ROWS NUMBER(18) NULL,
  COUPON VARCHAR2(255 CHAR) NULL
)
/
CREATE INDEX IX_B_TICKET_SUPCOUPONS_LOG_CID ON B_TICKET_SUPERCOUPONS_LOG(COUPON_ID)
/

CREATE SEQUENCE SQ_B_TICKET START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_DICTIONARY START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_MESSAGE START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_MESSAGE_2_FILE START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_ONLINE START WITH 1 INCREMENT BY 1  NOMINVALUE  NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_SLA START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_SLA_SHEDULE START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_UGROUPS START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE SEQUENCE SQ_B_TICKET_SUPERCOUPONS START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/


CREATE TABLE b_ticket_timetable
(
ID NUMBER(18) NOT NULL,
NAME VARCHAR2(255 CHAR) NULL,
DESCRIPTION CLOB NULL,
PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_b_ticket_timetable START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE b_ticket_holidays
(
ID NUMBER(18) NOT NULL,
NAME VARCHAR2(255 CHAR) NULL,
DESCRIPTION CLOB NULL,
OPEN_TIME VARCHAR2(10 CHAR) DEFAULT ('HOLIDAY') NOT NULL,
DATE_FROM DATE NOT NULL,
DATE_TILL DATE NOT NULL,
PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_b_ticket_holidays START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE TABLE b_ticket_sla_2_holidays
(
SLA_ID NUMBER(18) NOT NULL,
HOLIDAYS_ID NUMBER(18) NOT NULL
)
/

CREATE TABLE b_ticket_search
(
TICKET_ID NUMBER(18) NOT NULL,
SEARCH_WORD VARCHAR2(70 CHAR) NULL
)
/

CREATE INDEX IX_B_TICKET_SEARCH ON b_ticket_search(SEARCH_WORD, TICKET_ID)
/

CREATE INDEX IX_B_TICKET_SEARCH_T ON b_ticket_search(TICKET_ID)
/

CREATE TABLE b_ticket_timetable_cache
(
ID NUMBER(18) NOT NULL,
SLA_ID NUMBER(18) NOT NULL,
DATE_FROM DATE NOT NULL,
DATE_TILL DATE NOT NULL,
W_TIME NUMBER(18) NOT NULL,
W_TIME_INC NUMBER(18) NOT NULL,
PRIMARY KEY (ID)
)
/
CREATE SEQUENCE SQ_b_ticket_timetable_cache START WITH 1 INCREMENT BY 1 NOMINVALUE NOMAXVALUE NOCYCLE NOCACHE NOORDER
/

CREATE INDEX IX_B_TICKET_TIMETABLE_CACHE_S ON b_ticket_timetable_cache(SLA_ID)
/