CREATE TABLE B_WORKFLOW_DOCUMENT
(
	ID int NOT NULL IDENTITY (1, 1),
	STATUS_ID int NOT NULL,
	DATE_ENTER datetime NULL,
	DATE_MODIFY datetime NULL,
	DATE_LOCK datetime NULL,
	ENTERED_BY int NULL,
	MODIFIED_BY int NULL,
	LOCKED_BY int NULL,
	FILENAME varchar(255) NOT NULL,
	SITE_ID char(2) NULL,
	TITLE varchar(255) NULL,
	BODY text NULL,
	BODY_TYPE varchar(4) NOT NULL,
	PROLOG text NULL,
	EPILOG text NULL,
	COMMENTS varchar(8000) NULL
)
GO
ALTER TABLE B_WORKFLOW_DOCUMENT ADD CONSTRAINT PK_B_WORKFLOW_DOCUMENT PRIMARY KEY (ID)
GO
ALTER TABLE B_WORKFLOW_DOCUMENT ADD CONSTRAINT DF_B_WORKFLOW_DOCUMENT_BODY_TYPE DEFAULT 'html' FOR BODY_TYPE
GO


CREATE TABLE B_WORKFLOW_FILE
(
   ID int NOT NULL IDENTITY (1, 1),
   DOCUMENT_ID int NULL,
   TIMESTAMP_X datetime NULL,
   MODIFIED_BY int NULL,
   TEMP_FILENAME varchar(255) NULL,
   FILENAME varchar(255) NULL,
   FILESIZE int NULL
)
GO
ALTER TABLE B_WORKFLOW_FILE ADD CONSTRAINT PK_B_WORKFLOW_FILE PRIMARY KEY (ID)
GO
CREATE UNIQUE INDEX IX_B_WORKFLOW_FILE_1 ON B_WORKFLOW_FILE (TEMP_FILENAME)
GO


CREATE TABLE B_WORKFLOW_LOG
(
   ID int NOT NULL IDENTITY (1, 1),
   DOCUMENT_ID int NOT NULL,
   TIMESTAMP_X datetime NULL,
   MODIFIED_BY int NULL,
   TITLE varchar(255) NULL,
   FILENAME varchar(255) NULL,
   SITE_ID char(2) NULL,
   BODY text NULL,
   BODY_TYPE varchar(4) NOT NULL,
   STATUS_ID int NOT NULL,
   COMMENTS varchar(8000) NULL
)
GO
ALTER TABLE B_WORKFLOW_LOG ADD CONSTRAINT PK_B_WORKFLOW_LOG PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_WORKFLOW_LOG_1 ON B_WORKFLOW_LOG (DOCUMENT_ID)
GO
ALTER TABLE B_WORKFLOW_LOG ADD CONSTRAINT DF_B_WORKFLOW_LOG_BODY_TYPE DEFAULT 'html' FOR BODY_TYPE
GO


CREATE TABLE B_WORKFLOW_MOVE
(
   ID int NOT NULL IDENTITY (1, 1),
   TIMESTAMP_X datetime NOT NULL,
   DOCUMENT_ID int NULL,
   IBLOCK_ELEMENT_ID int NULL,
   OLD_STATUS_ID int NOT NULL,
   STATUS_ID int NOT NULL,
   LOG_ID int NULL,
   USER_ID int NULL
)
GO
ALTER TABLE B_WORKFLOW_MOVE ADD CONSTRAINT PK_B_WORKFLOW_MOVE PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_WORKFLOW_MOVE_1 ON B_WORKFLOW_MOVE (DOCUMENT_ID)
GO


CREATE TABLE B_WORKFLOW_PREVIEW
(
   ID int NOT NULL IDENTITY (1, 1),
   DOCUMENT_ID int NOT NULL,
   TIMESTAMP_X datetime NULL,
   FILENAME varchar(255) NULL
)
GO
ALTER TABLE B_WORKFLOW_PREVIEW ADD CONSTRAINT PK_B_WORKFLOW_PREVIEW PRIMARY KEY (ID)
GO


CREATE TABLE B_WORKFLOW_STATUS
(
   ID int NOT NULL IDENTITY (1, 1),
   TIMESTAMP_X datetime NULL,
   C_SORT int NULL,
   ACTIVE char(1) NOT NULL,
   TITLE varchar(255) NOT NULL,
   DESCRIPTION varchar(8000) NULL,
   IS_FINAL char(1) NOT NULL,
   NOTIFY char(1) NOT NULL
)
GO
ALTER TABLE B_WORKFLOW_STATUS ADD CONSTRAINT PK_B_WORKFLOW_STATUS PRIMARY KEY (ID)
GO
ALTER TABLE B_WORKFLOW_STATUS ADD CONSTRAINT DF_B_WORKFLOW_STATUS_C_SORT DEFAULT '100' FOR C_SORT
GO
ALTER TABLE B_WORKFLOW_STATUS ADD CONSTRAINT DF_B_WORKFLOW_STATUS_ACTIVE DEFAULT 'Y' FOR ACTIVE
GO
ALTER TABLE B_WORKFLOW_STATUS ADD CONSTRAINT DF_B_WORKFLOW_STATUS_IS_FINAL DEFAULT 'N' FOR IS_FINAL
GO
ALTER TABLE B_WORKFLOW_STATUS ADD CONSTRAINT DF_B_WORKFLOW_STATUS_NOTIFY DEFAULT 'Y' FOR NOTIFY
GO


CREATE TABLE B_WORKFLOW_STATUS2GROUP
(
   ID int NOT NULL IDENTITY (1, 1),
   STATUS_ID int NOT NULL,
   GROUP_ID int NOT NULL,
   PERMISSION_TYPE int NOT NULL
)
GO
ALTER TABLE B_WORKFLOW_STATUS2GROUP ADD CONSTRAINT PK_B_WORKFLOW_STATUS2GROUP PRIMARY KEY (ID)
GO
CREATE INDEX IX_B_WORKFLOW_STATUS2GROUP_1 ON B_WORKFLOW_STATUS2GROUP (STATUS_ID)
GO
